/* This program is free software: you can redistribute it and/or modify
 *
 * Copyright (C) 2014 Stefan Canzar, Sandro Andreotti
 *
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 2 of the License, or
 * (at your option) any later version.
 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

#ifndef FUNCTIONSPREPROC_H
#define FUNCTIONSPREPROC_H

#include <vector>

#include <Structures.h>
#include <Functions.h>


/** @defgroup Preprocess Functions to preprocess (filter, normalize) input data *
 *  @{
 */

/*!
 * \brief  Preprocessing function
 *
 *         This function preprocesses transcripts and covers. First all possible transcripts are generated. Those that are not supported by data get removed
 *
 *
 * \param	covers        The Segment covers read from the data.
 * \param	transcripts   The supported transcripts
 * \param locus         The locus (ordered set of segments)
 *
 */
void preprocessData(std::vector<SegmentCover>& covers,
                    std::vector<Transcript>& transcripts,
                    const std::vector<UInt>& locus,
                    const TAllSegmentsMap& segments);

/*!
 * \brief  compute connected components according to read mappings
 *
 * \param segment_covers                 Holds the read segment covers.
 * \param	components                     The connected components (all segments in the same component are accessed by component Id)
 * \param	loci                           known loci (also used for clustering the segments)
 */
void computeConnectedComponents(const std::vector<SegmentCover> &segment_covers,
                                const std::map<UInt, std::vector<UInt> > & all_loci,
                                std::map<UInt, std::vector<UInt> > &loci_cluster,
                                const std::vector<SuperSegmentCover> &all_segment_super_covers);

void clusterLoci(const std::map<UInt, std::vector<UInt> > & all_loci, std::map<UInt, std::vector<UInt> >& loci_clusters);


//infer TSS/TES information from read mappings (without annotation and known transcripts)
void identifyTssTes (const std::vector<SegmentCover> &all_covers,
                     TAllSegmentsMap &allSegments,
                     double threshold = 0,
                     bool onlyCoveredTerminals = false);


//infer TSS/TES information from known Transcripts
void getTssTesFromAnnotation (TAllSegmentsMap& allSegments,
                              const TKnownTranscriptsMap& knownTranscripts);



void regroupLoci(const std::vector<SegmentCover>& segment_covers,
                 TAllLociMap& all_loci,
                 const TAllSegmentsMap& all_segments);





#endif // FUNCTIONSPREPROC_H
