/* This program is free software: you can redistribute it and/or modify
 *
 * Copyright (C) 2014 Stefan Canzar, Sandro Andreotti
 *
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 2 of the License, or
 * (at your option) any later version.
 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

//Seqan stuff

#include <seqan/graph_algorithms.h>
#include <seqan/graph_types.h>
#include <seqan/graph_align.h>

// ILOG stuff
#include <ilcplex/ilocplex.h>
#include <ilconcert/iloalg.h>
#include <ilconcert/iloexpression.h>

#include <Functions.h>
#include <Parameters.h>
#include <Ilp.h>

#include <gsl/gsl_cdf.h>

#include <assert.h>
#include <map>

#include <sys/time.h>

#include <glmnet.h>

#include <priceilp.h>

using namespace std;
//const IloInt M = 1; //BigM for switching. We should better go for normalization
const IloInt delta_penalty = 1.0;

int buildILP2(const vector<Transcript>&transcripts, const vector<UInt>&locus, const vector<SegmentCover>& covers_in, const TAllSegmentsMap& segments, UInt read_length, UInt insert_size, bool de_novo)
{
  //vector<SegmentCover> covers(covers_in);
  vector<SegmentCover> covers;
  for (size_t i = 0; i < covers_in.size(); i++)
    if (covers_in[i].exons_1.size() <= 2) {
      covers.push_back(covers_in[i]);
    }

  //normalize the intensity of the covers to 1
  //   double max_intens=-1.0;
  //   for(size_t i=0; i<covers.size();++i)
  //   {
  //     max_intens=max(max_intens, covers[i].intensity);
  //   }
  //
  //   for(size_t i=0; i<covers.size();++i)
  //   {
  //     covers[i].intensity=covers[i].intensity/max_intens;
  //   }

  
  //as preprocessing we search for all junctions (edges in splice graph) that are not part of some cover. for all theses junctions we generate a node cover with
  //intensity 0, So selection of transcripts containing junctions not covered by any reads will be penalized
  std::set<pair<UInt, UInt> >abundant_junctions;
  std::set<UInt>abundant_singles;
  for(UInt i=0; i<covers.size(); ++i)
  {
    if(covers[i].exons_1.size()==1)
    {
      abundant_singles.insert(covers[i].exons_1.front());
    }
    for(int j=0; j<(int)covers[i].exons_1.size()-1; ++j)
    {
      abundant_junctions.insert(make_pair(covers[i].exons_1[j], covers[i].exons_1[j+1]));
    }

    // 		if(covers[i].exons_2.size()==1)
    // 		{
    // 			abundant_singles.insert(covers[i].exons_2.front());
    // 		}
    // 		for(int j=0; j<(int)covers[i].exons_2.size()-1; ++j)
    // 		{
    // 			abundant_junctions.insert(make_pair(covers[i].exons_2[j], covers[i].exons_2[j+1]));
    // 		}
  }
  for(UInt i=0; i<locus.size()-1; ++i)
  {
    if(abundant_singles.find(locus[i])==abundant_singles.end())
    {
      SegmentCover tmp;
      tmp.exons_1.push_back(locus[i]);
      tmp.intensity=0.0;
      covers.push_back(tmp);
    }
    for(UInt j=i+1; j<locus.size(); ++j)
    {
      if(abundant_junctions.find(make_pair(locus[i], locus[j])) == abundant_junctions.end())
      {
        SegmentCover tmp;
        tmp.exons_1.push_back(locus[i]);
        tmp.exons_1.push_back(locus[j]);
        tmp.intensity=0.0;
        covers.push_back(tmp);
      }
    }
  }
  if(abundant_singles.find(locus[locus.size()-1])==abundant_singles.end())
  {
    SegmentCover tmp;
    tmp.exons_1.push_back(locus[locus.size()-1]);
    tmp.intensity=0.0;
    covers.push_back(tmp);
  }
  
  std::cout << "aha: " << covers.size() << std::endl;
  //find all transcripts that contain the junction
  // 	for(UInt i=0; i<transcripts.size(); ++i)
  // 	{
  // 		for(UInt j=0; j<transcripts[i].nodes.size(); ++j)
  // 		{
  // 			if(j<transcripts[i].nodes.size()-1 && abundant_junctions.find(make_pair(transcripts[i].nodes[j], transcripts[i].nodes[j+1]))==abundant_junctions.end())
  // 			{
  //         SegmentCover tmp;
  // 				tmp.exons_1.push_back(transcripts[i].nodes[j]);
  // 				tmp.exons_1.push_back(transcripts[i].nodes[j+1]);
  // 				tmp.intensity=0.0;
  // 				covers.push_back(tmp);
  // 				abundant_junctions.insert(make_pair(transcripts[i].nodes[j], transcripts[i].nodes[j+1]));
  // 			}
  // 			if(abundant_singles.find(transcripts[i].nodes[j])==abundant_singles.end())
  // 			{
  //         SegmentCover tmp;
  // 				tmp.exons_1.push_back(transcripts[i].nodes[j]);
  // 				tmp.intensity=0.0;
  // 				covers.push_back(tmp);
  // 				abundant_singles.insert(transcripts[i].nodes[j]);
  // 			}
  // 		}
  //	}
  

  IloEnv env; // get an ILOG environment
  try {
    //ILP variables for directed edges
    IloModel model(env); // get an empty ILOG model

    //----------------------------------------------------
    //----------------Variables Section-------------------
    //----------------------------------------------------

    //binary variable for every transcript representing the abundant/missing status
    IloBoolVarArray trannscript_active(env, transcripts.size());

    //numerical variable for every transcript representing the intensity for that transcript
    IloNumVarArray transcript_intens(env, transcripts.size(),0.0, IloInfinity);

    //one numeric variable for every node cover denoting the error between measured and computed COVERAGE
    //this is a small hack. actually the last transcript is the one containing all nodes
    IloNumVarArray errors(env,covers.size(),0.0, IloInfinity);


    //----------------------------------------------------
    //----------------Objective Function------------------
    //----------------------------------------------------
    //--The objective function is to minimize the total---
    //----------number of selected Transcripts------------
    //----------------------------------------------------

    IloExpr obj(env);
    //keep the number of transcripts small
    // !! ONLY FOR DE NOVO !!
    if(de_novo)
    {
      //       for (int i = 0; i < trannscript_active.getSize(); ++i)
      //       {
      //         obj += trannscript_active[i];
      //       }
    }

    //keep the errors small for each node_cover
    for (size_t i = 0; i < covers.size(); ++i)
    {
      double norm = max(1., covers[i].intensity);
      //double norm = covers[i].intensity;
      //double norm = covers[i].intensity/sum_intens;
      obj+=(delta_penalty*errors[i])/(sqrt(norm));
      //double norm = max(0.1, covers[i].intensity);
      //obj+=delta_penalty*errors[i]/norm;
    }

    model.add(IloMinimize(env, obj));
    obj.end();

    //----------------------------------------------------
    //--------------------Constraints---------------------
    //----------------------------------------------------

    //first constraint assures for all NodeCovers that the intensities of associated transcripts
    //add up to the measured Coverage (one row for each coverage)
    //actually mate pair data are not used for this since there seems to be a huge bias for the mate data (very low abundance)
    IloExpr constr_1(env);
    for(UInt i = 0; i < covers.size(); ++i)
    {
      //			cout<<"cover "<<i<<"  "<<covers[i]<<"  "<<covers[i].intensity<<endl;
      bool add_row=false;
      //add all transcripts that support this cover
      for(int j = 0; j < transcript_intens.getSize(); ++j)
      {
        if(isCoverSupported(covers[i], vector<Transcript>(1,transcripts[j])) && covers[i].exons_2.empty())
        {
          constr_1+=transcript_intens[j] * getCoverLength(covers[i], segments, read_length);
          //constr_1+=transcript_intens[j] * getNormFactor(covers[i], transcripts[j], node_lengths, read_length, insert_size);
          add_row=true;
        }
      }
      if(add_row)
      {
        model.add(constr_1<= errors[i] + covers[i].intensity);
        model.add(constr_1>= covers[i].intensity - errors[i]);
        constr_1.clear();
      }
    }
    constr_1.end();


    //second constraint couples the intensities for each transcript to the binary switch variable (one row per transcript)
    // !! ONLY FOR DE NOVO !!
    if(de_novo)
    {
      //       for (int i = 0; i < trannscript_active.getSize(); ++i)
      //       {
      //         model.add(transcript_intens[i] <= trannscript_active[i]);
      //       }
    }

    //third constraint forces to support all registered mate pair data (since the mate pair counts are not taken into account in first constraint)
    // !!  ONLY FOR DE NOVO !!
    //@TODO This makes also sense for non de novo. But actually we don't want to use the binary variables "transcript_active". we can also use the intensities and force them to be at some minimal vaue
    //     if(de_novo)
    //     {
    //       IloExpr constr_3(env);
    //       for(UInt i = 0; i < covers.size(); ++i)
    //       {
    //         bool add_row=false;
    //         //add all transcripts that support this cover
    //         for(int j = 0; j < transcript_intens.getSize(); ++j)
    //         {
    //           if(isCoverSupported(covers[i], vector<Transcript>(1,transcripts[j])) && !covers[i].exons_2.empty() &&
    //             getNormFactor(covers[i], transcripts[j], node_lengths, read_length, insert_size)>0)
    //           {
    //             constr_3+=trannscript_active[j];
    //             add_row=true;
    //           }
    //         }
    //         if(add_row)
    //         {
    //           model.add(constr_3>= 1);
    //           constr_3.clear();
    //         }
    //       }
    //       constr_3.end();
    //     }

    //solve the ilp model
    IloCplex cplex(model);
    cplex.exportModel("full_lp18.lp");
    cplex.setParam(IloCplex::RootAlg, IloCplex::Primal);
    cplex.solve();

    cout<<endl<<"SCORE:  "<<cplex.getObjValue()<<endl<<endl;

    cplex.end();
    model.end();
    /*
    for(int i=0; i<transcript_intens.getSize(); ++i)
    {
      if(cplex.getValue(transcript_intens[i])!=0.0)
      {
        cout<<"  "<<cplex.getValue(transcript_intens[i]);
    for(int t=0; t<transcripts[i].nodes.size(); ++t)
    {
     cout<<"  "<<transcripts[i].nodes[t];
    }
      }
      cout<<endl;
    }

    for(UInt i = 0; i < covers.size(); ++i)
    {
      float calc_intens=0.0;
      for(int j = 0; j < transcript_intens.getSize(); ++j)
      {
        if(isCoverSupported(covers[i], vector<Transcript>(1,transcripts[j])) && covers[i].exons_2.empty() &&
     getNormFactor(covers[i], transcripts[j], node_lengths, read_length, insert_size)>0)
        {
          calc_intens+=cplex.getValue(transcript_intens[j]) * getNormFactor(covers[i], transcripts[j], node_lengths, read_length, insert_size);
        }
      }
   cout<<covers[i]<<"  orig-value: "<<covers[i].intensity<<"   comp-value:  "<<calc_intens<<endl;
    } */
  }
  catch (IloException& ex)
  {
    cerr << "Error: " << ex << endl;
  }
  catch (...)
  {
    cerr << "Error" << endl;
  }

  env.end();

  return 0;
}


int buildILP(const vector<Transcript>&transcripts,
             const vector<SegmentCover>& covers_in,
             const TAllSegmentsMap& segments,
             UInt read_length,
             UInt insert_size,
             bool de_novo)
{
  vector<SegmentCover> covers(covers_in);

  //normalize the intensity of the covers to 1
  //   double max_intens=-1.0;
  //   for(size_t i=0; i<covers.size();++i)
  //   {
  //     max_intens=max(max_intens, covers[i].intensity);
  //   }
  //
  //   for(size_t i=0; i<covers.size();++i)
  //   {
  //     covers[i].intensity=covers[i].intensity/max_intens;
  //   }

  
  //as preprocessing we search for all junctions (edges in splice graph) that are not part of some cover. for all theses junctions we generate a node cover with
  //intensity 0, So selection of transcripts containing junctions not covered by any reads will be penalized
  std::set<pair<UInt, UInt> >abundant_junctions;
  std::set<UInt>abundant_singles;
  for(UInt i=0; i<covers.size(); ++i)
  {
    if(covers[i].exons_1.size()==1)
    {
      abundant_singles.insert(covers[i].exons_1.front());
    }
    for(int j=0; j<(int)covers[i].exons_1.size()-1; ++j)
    {
      abundant_junctions.insert(make_pair(covers[i].exons_1[j], covers[i].exons_1[j+1]));
    }

    // 		if(covers[i].exons_2.size()==1)
    // 		{
    // 			abundant_singles.insert(covers[i].exons_2.front());
    // 		}
    // 		for(int j=0; j<(int)covers[i].exons_2.size()-1; ++j)
    // 		{
    // 			abundant_junctions.insert(make_pair(covers[i].exons_2[j], covers[i].exons_2[j+1]));
    // 		}
  }

  
  //find all transcripts that contain the junction
  for(UInt i=0; i<transcripts.size(); ++i)
  {
    for(UInt j=0; j<transcripts[i].nodes.size(); ++j)
    {
      if(j<transcripts[i].nodes.size()-1 && abundant_junctions.find(make_pair(transcripts[i].nodes[j], transcripts[i].nodes[j+1]))==abundant_junctions.end())
      {
        SegmentCover tmp;
        tmp.exons_1.push_back(transcripts[i].nodes[j]);
        tmp.exons_1.push_back(transcripts[i].nodes[j+1]);
        tmp.intensity=0.0;
        covers.push_back(tmp);
        abundant_junctions.insert(make_pair(transcripts[i].nodes[j], transcripts[i].nodes[j+1]));
      }
      if(abundant_singles.find(transcripts[i].nodes[j])==abundant_singles.end())
      {
        SegmentCover tmp;
        tmp.exons_1.push_back(transcripts[i].nodes[j]);
        tmp.intensity=0.0;
        covers.push_back(tmp);
        abundant_singles.insert(transcripts[i].nodes[j]);
      }
    }
  }
  

  IloEnv env; // get an ILOG environment
  try {
    //ILP variables for directed edges
    IloModel model(env); // get an empty ILOG model

    //----------------------------------------------------
    //----------------Variables Section-------------------
    //----------------------------------------------------

    //binary variable for every transcript representing the abundant/missing status
    IloBoolVarArray trannscript_active(env, transcripts.size());

    //numerical variable for every transcript representing the intensity for that transcript
    IloNumVarArray transcript_intens(env, transcripts.size(),0.0, IloInfinity);

    //one numeric variable for every node cover denoting the error between measured and computed COVERAGE
    //this is a small hack. actually the last transcript is the one containing all nodes
    IloNumVarArray errors(env,covers.size(),0.0, IloInfinity);


    //----------------------------------------------------
    //----------------Objective Function------------------
    //----------------------------------------------------
    //--The objective function is to minimize the total---
    //----------number of selected Transcripts------------
    //----------------------------------------------------

    IloExpr obj(env);
    //keep the number of transcripts small
    // !! ONLY FOR DE NOVO !!
    if(de_novo)
    {
      //       for (int i = 0; i < trannscript_active.getSize(); ++i)
      //       {
      //         obj += trannscript_active[i];
      //       }
    }

    //keep the errors small for each node_cover
    for (size_t i = 0; i < covers.size(); ++i)
    {
      double norm = max(1., covers[i].intensity);
      //double norm = covers[i].intensity;
      //double norm = covers[i].intensity/sum_intens;
      obj+=(delta_penalty*errors[i])/(sqrt(norm));
      //double norm = max(0.1, covers[i].intensity);
      //obj+=delta_penalty*errors[i]/norm;
    }

    model.add(IloMinimize(env, obj));
    obj.end();

    //----------------------------------------------------
    //--------------------Constraints---------------------
    //----------------------------------------------------

    //first constraint assures for all NodeCovers that the intensities of associated transcripts
    //add up to the measured Coverage (one row for each coverage)
    //actually mate pair data are not used for this since there seems to be a huge bias for the mate data (very low abundance)
    IloExpr constr_1(env);
    for(UInt i = 0; i < covers.size(); ++i)
    {
      //			cout<<"cover "<<i<<"  "<<covers[i]<<"  "<<covers[i].intensity<<endl;
      bool add_row=false;
      //add all transcripts that support this cover
      for(int j = 0; j < transcript_intens.getSize(); ++j)
      {
        if(isCoverSupported(covers[i], vector<Transcript>(1,transcripts[j])) && covers[i].exons_2.empty())
          if(isCoverSupported(covers[i], vector<Transcript>(1,transcripts[j])) && !covers[i].exons_2.empty() &&
             getNormFactor(covers[i], transcripts[j], segments)>0)
          {
            constr_1+=transcript_intens[j] * getCoverLength(covers[i], segments, read_length);
            //constr_1+=transcript_intens[j] * getNormFactor(covers[i], transcripts[j], node_lengths, read_length, insert_size);
            add_row=true;
          }
      }
      if(add_row)
      {
        model.add(constr_1<= errors[i] + covers[i].intensity);
        model.add(constr_1>= covers[i].intensity - errors[i]);
        constr_1.clear();
      }
    }
    constr_1.end();


    //second constraint couples the intensities for each transcript to the binary switch variable (one row per transcript)
    // !! ONLY FOR DE NOVO !!
    if(de_novo)
    {
      //       for (int i = 0; i < trannscript_active.getSize(); ++i)
      //       {
      //         model.add(transcript_intens[i] <= trannscript_active[i]);
      //       }
    }

    //third constraint forces to support all registered mate pair data (since the mate pair counts are not taken into account in first constraint)
    // !!  ONLY FOR DE NOVO !!
    //@TODO This makes also sense for non de novo. But actually we don't want to use the binary variables "transcript_active". we can also use the intensities and force them to be at some minimal vaue
    //     if(de_novo)
    //     {
    //       IloExpr constr_3(env);
    //       for(UInt i = 0; i < covers.size(); ++i)
    //       {
    //         bool add_row=false;
    //         //add all transcripts that support this cover
    //         for(int j = 0; j < transcript_intens.getSize(); ++j)
    //         {
    //           if(isCoverSupported(covers[i], vector<Transcript>(1,transcripts[j])) && !covers[i].exons_2.empty() &&
    //             getNormFactor(covers[i], transcripts[j], node_lengths, read_length, insert_size)>0)
    //           {
    //             constr_3+=trannscript_active[j];
    //             add_row=true;
    //           }
    //         }
    //         if(add_row)
    //         {
    //           model.add(constr_3>= 1);
    //           constr_3.clear();
    //         }
    //       }
    //       constr_3.end();
    //     }

    //solve the ilp model
    IloCplex cplex(model);
    //cplex.exportModel("transcript_lp.lp");
    cplex.solve();

    cout<<endl<<"SCORE:  "<<cplex.getObjValue()<<endl<<endl;
    /*
    for(int i=0; i<transcript_intens.getSize(); ++i)
    {
      if(cplex.getValue(transcript_intens[i])!=0.0)
      {
        cout<<"  "<<cplex.getValue(transcript_intens[i]);
    for(int t=0; t<transcripts[i].nodes.size(); ++t)
    {
     cout<<"  "<<transcripts[i].nodes[t];
    }
      }
      cout<<endl;
    }

    for(UInt i = 0; i < covers.size(); ++i)
    {
      float calc_intens=0.0;
      for(int j = 0; j < transcript_intens.getSize(); ++j)
      {
        if(isCoverSupported(covers[i], vector<Transcript>(1,transcripts[j])) && covers[i].exons_2.empty() &&
     getNormFactor(covers[i], transcripts[j], node_lengths, read_length, insert_size)>0)
        {
          calc_intens+=cplex.getValue(transcript_intens[j]) * getNormFactor(covers[i], transcripts[j], node_lengths, read_length, insert_size);
        }
      }
   cout<<covers[i]<<"  orig-value: "<<covers[i].intensity<<"   comp-value:  "<<calc_intens<<endl;
    } */
  }
  catch (IloException& ex)
  {
    cerr << "Error: " << ex << endl;
  }
  catch (...)
  {
    cerr << "Error" << endl;
  }

  env.end();

  return 0;
}


//similar to previous buildILP method, but returns computed intensities
//minor changes: squared norm in denominator, creates fake covers, no normalization of intensities
//------------------------------------------------------------------------------------------------
float buildILP(const vector<Transcript>&transcripts,
             map<UInt, double>& computed_intens,
             const vector<SegmentCover>& all_covers,
             const vector<UInt>& selected_cover_ids,
             const vector<SegmentCover>& fake_covers,
             const TAllSegmentsMap& segments,
             bool de_novo)

{

  if (selected_cover_ids.size() == 0) {
	  cerr << "no covers selected, nothing to do." << endl;
	  return 0;
  }

  //SANDRO?
  std::vector<UInt> effective_length(transcripts.size(), 0);
  
/*
  vector<UInt> selected_cover_ids;
  for (size_t i = 0; i < selected_cover_iids.size(); i++)
  {
    //if (all_covers[selected_cover_iids[i]].exons_1.size() < 3 && all_covers[selected_cover_iids[i]].exons_2.size() < 3)
    //{
    //}

      if(all_covers[selected_cover_iids[i]].exons_2.front() < all_covers[selected_cover_iids[i]].exons_1.front())
    	  continue;
      if(all_covers[selected_cover_iids[i]].exons_1.back() > all_covers[selected_cover_iids[i]].exons_2.back())
    	  continue;

      if(all_covers[selected_cover_iids[i]].exons_2.front() <= all_covers[selected_cover_iids[i]].exons_1.back()) {
    	  vector<UInt>::const_iterator intersect_it = find(all_covers[selected_cover_iids[i]].exons_1.begin(), all_covers[selected_cover_iids[i]].exons_1.end(), all_covers[selected_cover_iids[i]].exons_2.front());
    	  if(intersect_it == all_covers[selected_cover_iids[i]].exons_1.end() )
    		  continue;

    	  bool invalid = false;
    	  for(int j = 0; intersect_it != all_covers[selected_cover_iids[i]].exons_1.end(); ++intersect_it, ++j)
    	  {
    		  if(j > all_covers[selected_cover_iids[i]].exons_2.size()-1 || all_covers[selected_cover_iids[i]].exons_2[j] != *intersect_it) {
    			  invalid = true;
    			  break;
    		  }
    	  }
    	  if(invalid)
    		  continue;
      }

      selected_cover_ids.push_back(selected_cover_iids[i]);


  }
*/

  int c = 0;
  for(size_t i = 0; i < selected_cover_ids.size(); i++)
  {
    if(all_covers[selected_cover_ids[i]].exons_1.size()>2 || all_covers[selected_cover_ids[i]].exons_2.size()>2)
    {
      c++;
    }
  }

/*
  std::cout << "number of large covers: " << c << std::endl;

  cout << endl << "selected covers: " << endl;
  for(size_t i = 0; i < selected_cover_ids.size(); i++)
  {
	  cout << "next: " << all_covers[selected_cover_ids[i]].intensity << endl;
	  for(size_t j = 0; j<all_covers[selected_cover_ids[i]].exons_1.size(); j++)
		  cout << all_covers[selected_cover_ids[i]].exons_1[j] << " ";
	  cout << endl;
	  for(size_t j = 0; j<all_covers[selected_cover_ids[i]].exons_2.size(); j++)
	  		  cout << all_covers[selected_cover_ids[i]].exons_2[j] << " ";
	  cout << endl;
  }
  cout << endl << "candidate transcripts: " << endl;
  for(size_t i = 0; i<transcripts.size(); i++)
  {
	  for(size_t j = 0; j<transcripts[i].nodes.size(); j++)
		  cout << transcripts[i].nodes[j] << " " ;
	  cout << endl;
  }
*/

  /*
  std::vector<SegmentCover> fake_covers;
  generateFakeCovers(all_covers, selected_cover_ids, transcripts, fake_covers, Parameters::fake_mode);
  */

/*
  for(std::vector<SegmentCover>::iterator fit = fake_covers.begin(); fit!=fake_covers.end(); fit++) {
        cout << "fake cover:" << endl;
      	for(int j = 0; j<(*fit).exons_1.size(); j++)
      		cout << (*fit).exons_1[j] << " ";
      	cout << " _ ";
      	for(int j = 0; j<(*fit).exons_2.size(); j++)
      	    cout << (*fit).exons_2[j] << " ";
      	cout << endl;
   }
exit(0);
*/

  //std::cout << "total number of covers: " << selected_cover_ids.size() << "+" << fake_covers.size() << std::endl;
  
  
  //normalize the intensity of the covers to 1  
/*
  //double max_intens=-1.0;
  //double sum_intens = 0.0;
  for(size_t i=0; i<covers.size();++i)
  {
    //sum_intens += covers[i].intensity;
    //max_intens = max(max_intens, covers[i].intensity);
    min_intens = min(min_intens, covers[i].intensity);
    std::cout << covers[i].intensity << std::endl;
  }

  for(size_t i=0; i<covers.size();++i)
  {
    //covers[i].intensity=covers[i].intensity/max_intens;
  }
*/ 
  
  float score = -1;
  IloEnv env; // get an ILOG environment
  try {
    
    IloModel model(env); // get an empty ILOG model

    //----------------------------------------------------
    //----------------Variables Section-------------------
    //----------------------------------------------------

    //binary variable for every transcript representing the abundant/missing status
    IloBoolVarArray transcript_active(env, transcripts.size());

    //numerical variable for every transcript representing the intensity for that transcript
    IloNumVarArray transcript_intens(env, transcripts.size(),0.0, IloInfinity);

    //one numeric variable for every node cover denoting the error between measured and computed COVERAGE
    //this is a small hack. actually the last transcript is the one containing all nodes

    //IloNumVarArray errors(env, selected_cover_ids.size(), 0.0, IloInfinity);
    IloNumVarArray errors(env, selected_cover_ids.size());
    for(size_t i=0; i<selected_cover_ids.size(); ++i) {
    	if(Parameters::quad_error || Parameters::pw_lin)
    		errors[i] = IloNumVar(env, -IloInfinity, IloInfinity);
    	else
    		errors[i] = IloNumVar(env, 0.0, IloInfinity);
    }

    //for piecewise linear approximation
    IloNumVarArray z(env, selected_cover_ids.size(), 0.0, IloInfinity);
    IloNumVarArray z_fake(env, fake_covers.size(), 0.0, IloInfinity);
    vector<bool> cover_constr_ex(selected_cover_ids.size(), false);
    vector<bool> fake_cover_constr_ex(fake_covers.size(), false);
 
    IloNumVarArray errors_div(env, selected_cover_ids.size() * selected_cover_ids.size(), 0.0, IloInfinity);
    //IloNumVarArray errors(env, selected_cover_ids.size(), -IloInfinity, IloInfinity);
    IloNumVarArray errors_fake(env, fake_covers.size());
    for(size_t i=0; i<fake_covers.size(); ++i) {
    	if(Parameters::quad_error || Parameters::pw_lin)
    		errors_fake[i] = IloNumVar(env, -IloInfinity, IloInfinity);
    	else
    		errors_fake[i] = IloNumVar(env, 0.0, IloInfinity);
    }

    std::vector<double> weights(selected_cover_ids.size(), 1.);
    std::vector<double> avg_len(selected_cover_ids.size(), 1.);
    std::vector<double> weights_fake(fake_covers.size(), 1.);

    //----------------------------------------------------
    //--------------------Constraints---------------------
    //----------------------------------------------------

    //first constraint assures for all NodeCovers that the intensities of associated transcripts
    //add up to the measured Coverage (one row for each coverage)
    //actually mate pair data are not used for this since there seems to be a huge bias for the mate data (very low abundance)
    IloExpr constr_1(env);
    Size id = 0;
    vector<UInt>::const_iterator cov_id_iter;
    for(cov_id_iter = selected_cover_ids.begin(); cov_id_iter != selected_cover_ids.end(); ++cov_id_iter)
    {
    	/*
    	cout << "cover:" << endl;
    	for(int j = 0; j<all_covers[*cov_id_iter].exons_1.size(); j++)
    		cout << all_covers[*cov_id_iter].exons_1[j] << " ";
    	cout << " _ ";
    	for(int j = 0; j<all_covers[*cov_id_iter].exons_2.size(); j++)
    	    cout << all_covers[*cov_id_iter].exons_2[j] << " ";
    	cout << endl;
		*/
      //cout << "cover: " << all_covers[*cov_id_iter] << " " << all_covers[*cov_id_iter].intensity << endl;
      bool add_row = false;
      float summed_nf = 0.;
      int supporters = 0;
      //add all transcripts that support this cover
      double confidence;
      for(int j = 0; j < transcript_intens.getSize(); ++j)
      {
        if(isCoverSupported(all_covers[*cov_id_iter], vector<Transcript>(1,transcripts[j])))
        {
	  //cout << j << endl;
          float normf = getNormFactor(all_covers[*cov_id_iter], transcripts[j], segments);
	  //cout << "normf=" << normf << endl;
          //float normf = getCoverLength(all_covers[*cov_id_iter], segments, read_length);
	  //cout << normf << endl;
          summed_nf += normf;
          //effective_length[j] += normf;
          {
            //if(all_covers[*cov_id_iter].intensity > 0 || Parameters::fake_mode)
            //{
              //cout<<"cover: "<<covers[i]<<"  count: "<<covers[i].intensity<<" factor: "<<covers[i].intensity / normf <<std::endl;
              constr_1 += transcript_intens[j] * normf;
              ++supporters;
              add_row = true;
            //}            
          }
        }
      }
      //use average length for confidence
      confidence = 1 - exp((-summed_nf/supporters)/200);
      avg_len[id] = summed_nf/supporters;
      weights[id] = confidence / supporters;      
     
      if(supporters == 1)
      {	
        if (confidence > 0.4 && (all_covers[*cov_id_iter].exons_1.size() > 1 || all_covers[*cov_id_iter].exons_2.size() > 1))
        {
          //weights[id] *= 2;   //discriminative junction
        }
        else if (confidence > 0.5)
        {
          weights[id] *= 2;   //discriminative single
        }
      }

      if(add_row)
      {
      if(!Parameters::quad_error && !Parameters::pw_lin)
      {
    		model.add(constr_1 <= errors[id] + all_covers[*cov_id_iter].intensity);
    		model.add(constr_1 >= all_covers[*cov_id_iter].intensity - errors[id]);
      } else
      { //qp or pw linear
    		model.add(errors[id] == constr_1 - all_covers[*cov_id_iter].intensity);
    	}
      if(Parameters::pw_lin)
      {
    		double d = max(1.,all_covers[*cov_id_iter].intensity);
    		double delta = sqrt(d*d*Parameters::epsilon);
    		for (int k=0; k*delta < d; k++)
    			model.add(z[id] >= k*delta*k*delta/d +  (2*k*delta/d)*(errors[id]-(k*delta)));
    		for (int k=0; k*delta < d; k++) {
    			if(k==0)
    				continue;
    			model.add(z[id] >= k*delta*k*delta/d +  (-2*k*delta/d)*(errors[id]+(k*delta)));
    		}
/*
    		double delta2 = sqrt(d*d*Parameters::epsilon);
    		double delta1 = sqrt(d*d*Parameters::epsilon/2.);
    		double delta3 = sqrt(d*d*Parameters::epsilon*2);
    		//double delta = sqrt(d*Parameters::epsilon);
    		for (int k=0; k*delta1 < (d/3.)+delta1; k++) {
    			model.add(z[id] >= k*delta1*k*delta1/d +  (2*k*delta1/d)*(errors[id]-(k*delta1)));
    		}
    		for (int k = ceil( d/(3.*delta2) ); k*delta2 < (2*d/3.)+delta2; k++) {
    			model.add(z[id] >= k*delta2*k*delta2/d +  (2*k*delta2/d)*(errors[id]-(k*delta2)));
    		}
    		for (int k = ceil( (2*d)/(3*delta3) ); k*delta3 < d+delta3; k++) {
    			model.add(z[id] >= k*delta3*k*delta3/d +  (2*k*delta3/d)*(errors[id]-(k*delta3)));
    		}
    		for (int k=0; k*delta1 < (d/3.)+delta1; k++) {
    			if(k==0)
    				continue;
    			model.add(z[id] >= k*delta1*k*delta1/d +  (-2*k*delta1/d)*(errors[id]+(k*delta1)));
    		}
    		for (int k = ceil( d/(3.*delta2) ); k*delta2 < (2*d/3.)+delta2; k++) {
    			if(k==0)
    				continue;
    			model.add(z[id] >= k*delta2*k*delta2/d +  (-2*k*delta2/d)*(errors[id]+(k*delta2)));
    		}
    		for (int k = ceil( (2*d)/(3*delta3) ); k*delta3 < d+delta3; k++) {
    			if(k==0)
    				continue;
    			model.add(z[id] >= k*delta3*k*delta3/d +  (-2*k*delta3/d)*(errors[id]+(k*delta3)));
    		}*/
    	}
    	cover_constr_ex[id] = true;
        constr_1.clear();
      }
      ++id;
    }
    constr_1.end();

    //CONSTRAINT
    //Constraints for fake covers
    if(Parameters::fake_mode)
    {
      id = 0;
      IloExpr constr_fake(env);
      for(UInt i = 0; i < fake_covers.size(); ++i)
      {
/*
    	cout << "fake:" << endl;
    	for(int j = 0; j<fake_covers[i].exons_1.size(); j++)
    		cout << fake_covers[i].exons_1[j] << " ";
    	cout << " _ ";
    	for(int j = 0; j<fake_covers[i].exons_2.size(); j++)
    	    		cout << fake_covers[i].exons_2[j] << " ";
    	cout << endl;
*/
        bool add_row = false;
        //add all transcripts that support this cover
        double confidence;
        for(int j = 0; j < transcript_intens.getSize(); ++j)
        {
          if(isCoverSupported(fake_covers[i], vector<Transcript>(1,transcripts[j])))
          {
            float normf = getNormFactor(fake_covers[i], transcripts[j], segments);
            //cout << "normf " << normf << endl;
            //float normf = getCoverLength(fake_covers[i], segments, read_length, insert_size);
            effective_length[j] += normf;
            confidence = 1 - exp(-normf/100);
            constr_fake += transcript_intens[j] * normf;
            add_row = true;
          }
        }
        if(add_row)
        {
          if(!Parameters::quad_error && !Parameters::pw_lin)
          {
        	  model.add(constr_fake <= errors_fake[id] + fake_covers[i].intensity);
        	  model.add(constr_fake >= fake_covers[i].intensity - errors_fake[id]);
          }
          else
          { //qp or pw linear
        	  model.add(errors_fake[id] == constr_fake - fake_covers[i].intensity);
          }
          if(Parameters::pw_lin)
          {
        	  double d = max(1.,fake_covers[i].intensity);
        	  double delta = sqrt(d*d*Parameters::epsilon);
        	  for (int k=0; k*delta < d; k++)
        		  model.add(z_fake[id] >= k*delta*k*delta/d +  (2*k*delta/d)*(errors_fake[id]-(k*delta)));

            for (int k=0; k*delta < d; k++)
            {
        		  if(k==0)
        			  continue;
        		  model.add(z_fake[id] >= k*delta*k*delta/d +  (-2*k*delta/d)*(errors_fake[id]+(k*delta)));
        	  }
/*
        	  double delta2 = sqrt(d*d*Parameters::epsilon);
        	  double delta1 = sqrt(d*d*Parameters::epsilon/2.);
        	  double delta3 = sqrt(d*d*Parameters::epsilon*2.);
        	  for (int k=0; k*delta1 < (d/3.)+delta1; k++) {
        		  model.add(z_fake[id] >= k*delta1*k*delta1/d +  (2*k*delta1/d)*(errors_fake[id]-(k*delta1)));
        	  }
        	  for (int k = ceil( d/(3.*delta2) ); k*delta2 < (2*d/3.)+delta2; k++) {
        		  model.add(z_fake[id] >= k*delta2*k*delta2/d +  (2*k*delta2/d)*(errors_fake[id]-(k*delta2)));
        	  }
        	  for (int k = ceil( (2*d)/(3*delta3) ); k*delta3 < d+delta3; k++) {
        		  model.add(z_fake[id] >= k*delta3*k*delta3/d +  (2*k*delta3/d)*(errors_fake[id]-(k*delta3)));
        	  }
        	  for (int k=0; k*delta1 < (d/3.)+delta1; k++) {
        		  if(k==0)
        			  continue;
        		  model.add(z_fake[id] >= k*delta1*k*delta1/d +  (-2*k*delta1/d)*(errors_fake[id]+(k*delta1)));
        	  }
        	  for (int k = ceil( d/(3.*delta2) ); k*delta2 < (2*d/3.)+delta2; k++) {
        		  if(k==0)
        			  continue;
        		  model.add(z_fake[id] >= k*delta2*k*delta2/d +  (-2*k*delta2/d)*(errors_fake[id]+(k*delta2)));
        	  }
        	  for (int k = ceil( (2*d)/(3*delta3) ); k*delta3 < d+delta3; k++) {
        		  if(k==0)
        			  continue;
        		  model.add(z_fake[id] >= k*delta3*k*delta3/d +  (-2*k*delta3/d)*(errors_fake[id]+(k*delta3)));
        	  }
*/
          }
          fake_cover_constr_ex[id] = true;
          constr_fake.clear();
        }
        ++id;
      }
      constr_fake.end();
    }

    //second constraint couples the intensities for each transcript to the binary switch variable (one row per transcript)
    // !! ONLY FOR DE NOVO !!

    /*
    if(de_novo)
    {
      for (int i = 0; i < transcript_active.getSize(); ++i)
      {
        model.add(transcript_intens[i] <= transcript_active[i]);
      }
    }
    */

    //third constraint forces to support all registered mate pair data (since the mate pair counts are not taken into account in first constraint)
    // !!  ONLY FOR DE NOVO !!
    //@TODO This makes also sense for non de novo. But actually we don't want to use the binary variables "transcript_active". we can also use the intensities and force them to be at some minimal vaue
    //    if(de_novo)
    //    {
    //      IloExpr constr_3(env);
    //      for(UInt i = 0; i < covers.size(); ++i)
    //      {
    //        bool add_row = false;
    //        //add all transcripts that support this cover
    //        for(int j = 0; j < transcript_intens.getSize(); ++j)
    //        {
    //          if(isCoverSupported(covers[i], vector<Transcript>(1,transcripts[j])) && !covers[i].exons_2.empty() &&
    //             getNormFactor(covers[i], transcripts[j], segments, read_length, insert_size)>0)
    //          {
    //            constr_3 += trannscript_active[j];
    //            add_row = true;
    //          }
    //        }
    //        if(add_row)
    //        {
    //          model.add(constr_3 >= 1);
    //          constr_3.clear();
    //        }
    //      }
    //      constr_3.end();
    //    }



    //----------------------------------------------------
    //----------------Objective Function------------------
    //----------------------------------------------------
    //--The objective function is to minimize the total---
    //-----error and number of selected Transcripts-------
    //----------------------------------------------------


    IloExpr obj(env);
    //keep the number of transcripts small

    // !! ONLY FOR DE NOVO !!

    /*
    if(de_novo)
    {
      for (int i = 0; i < transcript_active.getSize(); ++i)
      {
        obj += transcript_active[i];
      }
    }
    */


    if(de_novo)
    {
      for(int i=0; i<transcript_intens.getSize(); ++i)
        obj += Parameters::theta*transcript_intens[i];
      //obj += transcript_intens[i]/transcripts[i].nodes.size();
    }


/*
    //SANDRO?
    for(int i = 0; i < transcript_intens.getSize(); ++i)
    {
      Transcript tmp_trans;
      tmp_trans.nodes.push_back(1);
      SegmentCover tmp_cover;
      tmp_cover.exons_1.push_back(1);
      tmp_cover.exons_2.push_back(1);
      std::map<UInt, Segment>tmp_map;
      Segment tmp_segment;
      int length = 0;
      for(int l = 0; l < transcripts[i].nodes.size(); ++l)
      {
        length += segments.find(transcripts[i].nodes[l])->second.length;
      }
      tmp_segment.length = length;
      tmp_map[1] = tmp_segment;

      double len_correction = getNormFactor(tmp_cover, tmp_trans, tmp_map, Parameters::read_length_global, Parameters::insert_size_global);
      obj += transcript_intens[i] * len_correction;
    }
*/

    double total_norm = 0;
    for(cov_id_iter = selected_cover_ids.begin(); cov_id_iter != selected_cover_ids.end(); ++cov_id_iter)
    {
    	total_norm += 1./max(1.,all_covers[*cov_id_iter].intensity);
    }
    if(Parameters::fake_mode) {
    	for (size_t i = 0; i < fake_covers.size(); ++i)
    	{
    		total_norm += 1./max(1., fake_covers[i].intensity);
    	}
    }
                                
    //keep the errors small for each node_cover
    id = 0;
    for(cov_id_iter = selected_cover_ids.begin(); cov_id_iter != selected_cover_ids.end(); ++cov_id_iter)
    {
      //double norm = max(5., all_covers[*cov_id_iter].intensity);
      //double norm = max(1.,all_covers[*cov_id_iter].intensity);
      //double norm = 2*selected_cover_ids.size();
/*
      int nof_obs = selected_cover_ids.size();
      if(Parameters::fake_mode)
    	  nof_obs += fake_covers.size();
      double normfac = 1./(2*nof_obs);
*/
      //double normfac = 0.5 * (1. / total_norm) * max(1.,all_covers[*cov_id_iter].intensity);
      //double normfac = 1./max(1.,all_covers[*cov_id_iter].intensity);
      double normfac = 1./max(Parameters::pseudoCount, all_covers[*cov_id_iter].intensity);

      if(!Parameters::weights)
      {
         if(Parameters::pw_lin)
         {
        	 if(cover_constr_ex[id])
        		 obj += z[id];
         }
         else if(!Parameters::quad_error)
         {
        	 //obj += (delta_penalty * errors[id]) / sqrt(norm);
        	 obj += sqrt(normfac)*errors[id];
         }
         else
         { //qp
        	 obj += normfac*errors[id]*errors[id];
             //obj += (delta_penalty * errors[id] * errors[id]) / norm;
         }
      }
      else
      {
    	  obj += sqrt(normfac)*errors[id];
        //obj += (weights[id] * delta_penalty * errors[id])/sqrt(norm);
        //obj += (weights[id] * delta_penalty * errors[id] * errors[id])/norm;
      }
      ++id;
    }

    if(Parameters::fake_mode)
    {
      for (size_t i = 0; i < fake_covers.size(); ++i)
      {
        //double norm = max(1., fake_covers[i].intensity);
    	//double normfac = 1./(2*(selected_cover_ids.size()+fake_covers.size()));

    	//double normfac = 0.5 * (1. / total_norm) * max(1., fake_covers[i].intensity);
      double normfac = 1./max(Parameters::pseudoCount, fake_covers[i].intensity);

        if(!Parameters::weights)
        {
        	if(Parameters::pw_lin) {
        		if(fake_cover_constr_ex[i])
        			obj += z_fake[i];
        	} else if(!Parameters::quad_error) {
        		//obj+=(delta_penalty * errors_fake[i])/(sqrt(norm));
        		obj += sqrt(normfac)*errors_fake[i];
        	} else {
        		//obj += (delta_penalty * errors_fake[i] * errors_fake[i]) / norm;
        		obj += normfac*errors_fake[i]*errors_fake[i];
        	}
        }
        else
        {
          //obj += (weights_fake[i] * delta_penalty * errors_fake[i])/(sqrt(norm));
          obj += sqrt(normfac)*errors_fake[i];
        }
      }
    }

    model.add(IloMinimize(env, obj));
    obj.end();
/*
    for(int i=0; i<transcript_intens.getSize(); ++i)
    {
    	cout << computed_intens[transcripts[i].id] << endl;
    	model.add(transcript_intens[i] == computed_intens[transcripts[i].id]);
    }
*/
/*
    model.add(transcript_intens[0]==0);
    model.add(transcript_intens[2]==0.0684928);
    model.add(transcript_intens[1]==0);
*/
    //solve the ilp model
    IloCplex cplex(model);
    cplex.setOut(env.getNullStream());
    //cplex.exportModel("transcript_lp.lp");
    cplex.solve();   

    if(cplex.getCplexStatus()==IloCplex::Infeasible)
    	exit(0);

    /*
   	double qp_score = 0.;
    cout << "----------" << endl;
    for(int i=0; i<selected_cover_ids.size(); i++)
    	if(cplex.isExtracted(errors[i])) {
    		cout << all_covers[selected_cover_ids[i]].intensity << " " << cplex.getValue(errors[i]) << endl;
    		qp_score += cplex.getValue(errors[i]) * cplex.getValue(errors[i]) / max(1.,all_covers[selected_cover_ids[i]].intensity);
    	}
    cout << "-----------" << endl;
	*/

    for(int i=0; i<transcript_intens.getSize(); ++i)
    {
      if(!cplex.isExtracted(transcript_intens[i]))
      {
    	//cout << i << ": " << 0 << endl;
        computed_intens[transcripts[i].id] = 0;
      }
      else
      {
    	//cout << i << ": " << cplex.getValue(transcript_intens[i]) << endl;
        computed_intens[transcripts[i].id] = cplex.getValue(transcript_intens[i]);
        //cout << cplex.getValue(transcript_intens[i]) << endl;
        //qp_score += Parameters::theta*cplex.getValue(transcript_intens[i]);
        //debug
/*
  if(cplex.getValue(transcript_intens[i])>0) {
   for(int t=0; t<transcripts[i].nodes.size(); t++)
     std::cout << transcripts[i].nodes[t] << " ";
   std::cout << std::endl;
   std::cout << computed_intens[transcripts[i].id] << std::endl;

   vector<UInt>::const_iterator cov_id_iter;
   int count_covers = 0;
   for(cov_id_iter = selected_cover_ids.begin(); cov_id_iter != selected_cover_ids.end(); ++cov_id_iter)
   {
     if(isCoverSupported(all_covers[*cov_id_iter], vector<Transcript>(1,transcripts[i])))
     {
       count_covers++;
     }
   }
   for(UInt j = 0; j < fake_covers.size(); ++j)
   {
     if(isCoverSupported(fake_covers[j], vector<Transcript>(1,transcripts[i])))
     {
       count_covers++;
     }
   }
   std::cout << "contained in covers: " << count_covers << std::endl;
*/

/*
   double tot_error = 0;
   std::cout <<  "errors: " << std::endl;
   for(int j=0; j<selected_cover_ids.size(); j++) {
	 cout << "=======" << endl;
	 cout << all_covers[selected_cover_ids[j]].intensity << endl;
	 cout <<  1./max(1.,all_covers[selected_cover_ids[j]].intensity) << endl;
	 std::cout << cplex.getValue(errors[j]) << std::endl;
     std::cout << cplex.getValue(errors[j])*cplex.getValue(errors[j]) << std::endl;
     tot_error += (1./max(1.,all_covers[selected_cover_ids[j]].intensity)) * cplex.getValue(errors[j])*cplex.getValue(errors[j]);
   }
   std::cout << "fake errors: " << std::endl;
   for(int j=0; j<fake_covers.size(); j++) {
     std::cout << cplex.getValue(errors_fake[j]) << std::endl;
     tot_error += cplex.getValue(errors_fake[j])*cplex.getValue(errors_fake[j]);
   }
   cout << "total error: " << tot_error << endl;
*/

      }
    }
    
    //std::cout.precision(10);
    score = cplex.getObjValue();
    if (Parameters::verbose)
    {
      cout<<endl<<"SCORE:  "<<cplex.getObjValue()<<endl;
      cout << "rows: " << cplex.getNrows() << endl<<endl;
    }
    //cout << "qp score: " << qp_score << endl;

    //refine intensities
/*
    //SANDRO?
    std::map<UInt, double> trans_pred_global;
    for(cov_id_iter = selected_cover_ids.begin(); cov_id_iter != selected_cover_ids.end(); ++cov_id_iter)
    {
      std::map<UInt, double> trans_pred_local;
      double local_pred = 0.;
      for(int j = 0; j < transcript_intens.getSize(); ++j)
      {
        if(isCoverSupported(all_covers[*cov_id_iter], vector<Transcript>(1,transcripts[j])))
        {
          //float normf = getNormFactor(all_covers[*cov_id_iter], transcripts[j], segments, read_length, insert_size);
          float normf = getCoverLength(all_covers[*cov_id_iter], segments, read_length, insert_size);
          trans_pred_local[transcripts[j].id] = normf * computed_intens[transcripts[j].id];
          local_pred += trans_pred_local[transcripts[j].id];
        }
      }

      if(local_pred > 0)
      {
        double factor = all_covers[*cov_id_iter].intensity / local_pred;
        for(int j = 0; j < transcript_intens.getSize(); ++j)
        {
          if(isCoverSupported(all_covers[*cov_id_iter], vector<Transcript>(1,transcripts[j])))
          {
            trans_pred_global[transcripts[j].id] += trans_pred_local[transcripts[j].id] * factor;
          }
        }
      }
    }

    for(int i=0; i<transcript_intens.getSize(); ++i)
    {
      Size trans_len = 0;
      for(Size l = 0; l < transcripts[i].nodes.size(); ++l)
      {
        trans_len += segments.find(transcripts[i].nodes[l])->second.length;
      }
      trans_len = max(1lu, trans_len - insert_size + 1);
      //cout << computed_intens[transcripts[i].id] <<"  " << trans_pred_global[transcripts[i].id] / trans_len << endl;
      computed_intens[transcripts[i].id] = trans_pred_global[transcripts[i].id] / trans_len;
    }
    //debug
    if(transcript_intens.getSize() == 1)
    {
      double km_factor = 1000 / Parameters::M_global;
      cout << transcripts[0].id <<"  "<< trans_pred_global[transcripts[0].id] << "  "
           << computed_intens[transcripts[0].id] <<"  "
           << computed_intens[transcripts[0].id] * km_factor
           << std::endl;
    }
*/


    //SANDRO?
    //    for(int i=0; i<transcript_intens.getSize(); ++i)
    //    {
    //      if(!cplex.isExtracted(transcript_intens[i]))
    //        continue;
    //      computed_intens[transcripts[i].id] = cplex.getValue(transcript_intens[i]);
    //      //normalize intensity
    //      Size trans_len = 0;
    //      for(Size l = 0; l < transcripts[i].nodes.size(); ++l)
    //      {
    //        trans_len += segments.find(transcripts[i].nodes[l])->second.length;
    //      }
    //      trans_len = max(1u, trans_len - insert_size + 1);
    //      computed_intens[transcripts[i].id] = (cplex.getValue(transcript_intens[i]) * effective_length[i]) / trans_len;
    //    }


    //*******for ilp *****
    // for(int i=0; i<transcript_active.getSize(); ++i)
    // {
    //   if(cplex.getValue(transcript_active[i]))
    // 	 computed_intens[transcripts[i].id] = cplex.getValue(transcript_intens[i]);
    // }

    //std::cout << "objective: " << cplex.getObjValue() << std::endl;

  }
  catch (IloException& ex)
  {
    cerr << "Error: " << ex << endl;
  }
  catch (...)
  {
    cerr << "Error" << endl;
  }

  env.end();

  return score;
}

int doGlmnet(const vector<Transcript>&transcripts,
			 const vector<UInt>& locus,
        	 map<UInt, double>& computed_intens,
        	 const vector<SegmentCover>& all_covers,
        	 const vector<UInt>& selected_cover_ids,
        	 vector<bool>& cov_expl,
        	 const vector<SegmentCover>& fake_covers,
        	 const TAllSegmentsMap &segments,
        	 float& lambda,
        	 float& total_error,
        	 const std::vector<Transcript>& known_transcripts)
{

	if (selected_cover_ids.size() == 0) {
		cerr << "no covers selected." << endl;
		return 0;
	}

	//build flat coefficient matrix x and right-hand side y
	//all rows are added, even if cover not supported by any transcript! -  man this happen?
	int nof_obs = selected_cover_ids.size();
	if(Parameters::fake_mode)
		nof_obs += fake_covers.size();
	vector<float> y;
	y.resize(nof_obs);
	vector<float> w;
	w.resize(nof_obs);

	//vector<float> x (transcripts.size()*nof_obs,0);
	//cout << transcripts.size()*nof_obs << endl;
	//cout << x.size() << endl;

	vector<float> sparse_x;	
	vector<int> jx; 	
	vector<int> ix;
	//ix.resize(nof_obs+1);
	ix.resize(transcripts.size()+1);
	ix[0] = 1;
	int last_idx = 0;
	//float y_mean = 0;

	bool add_refined = false;
	UInt tot_nof_refined = 0;

	float total_weight = 0; //needed to transfrom lambda to theta
	if(transcripts.empty()) //enumerate all transcripts implicitly
	{
		//map exon to position in locus
		map<int, int> exon_order;
		//cout << "locus" << endl;
		for(size_t i = 0; i < locus.size(); i++) {
			exon_order[locus[i]] = i;
			//cout << locus[i] << endl;
		}

		vector<vector<float> > nonzero_coeff(pow(2.,(int)locus.size()));
		vector<vector<int> > sorted_jx(pow(2.,(int)locus.size()));
		for(size_t i = 0; i < selected_cover_ids.size(); ++i)
		{
      w[i] = 1./max(Parameters::pseudoCount, all_covers[selected_cover_ids[i]].intensity);
			y[i] = all_covers[selected_cover_ids[i]].intensity;
			total_weight += w[i];

			//now enumerate all compatible transcripts

			SegmentCover sc = all_covers[selected_cover_ids[i]];


      //cout << "left cover" << endl;
      //for(int z=0; z<sc.exons_1.size(); z++)
      //	cout << sc.exons_1[z] << " ";
      //cout << endl;
      //cout << "right cover" << endl;
      //for(int z=0; z<sc.exons_2.size(); z++)
      //	cout << sc.exons_2[z] << " ";
      //cout << endl;


			//any combination of exons left of left mate is valid
			Transcript tmp;
			tmp.nodes.reserve(locus.size());
			int first_exon_left = sc.exons_1.front();
			UInt num = pow( 2.0, exon_order[first_exon_left] );
			for(UInt ii=0; ii<num; ++ii)
			{
				//cout << "next left combi " << endl;
				for(UInt pos=0; pos < exon_order[first_exon_left]; ++pos) {
					if(ii&1<<pos) {
						tmp.nodes.push_back(locus[pos]);
						//cout << locus[pos] << " ";
					}
				}
				//cout << endl;

				//fix left mate in transcript
				for(UInt j = 0; j < sc.exons_1.size(); j++)
					tmp.nodes.push_back(sc.exons_1[j]);

				//middle part restricted
				vector<vector<bool> > candidates;
				enumGapExonSets(sc, segments, locus, candidates);
				vector<UInt>::iterator prev_last1 = tmp.nodes.end()-1;
				for(UInt j = 0; j < max(1, (int)candidates.size()); j++)
				{
					//cout << "middle part" << endl;
					if(candidates.size()>0) {
						for(UInt k = 0; k < candidates[j].size(); k++) {
							if(candidates[j][k]) {
								tmp.nodes.push_back( locus[exon_order[sc.exons_1.back()]+k+1] );
								//cout << locus[exon_order[sc.exons_1.back()]+k+1] << " ";
							}
						}
						//cout << endl;
					}

					//fix right mate in transcript
					for(UInt k = 0; k < sc.exons_2.size(); k++) {
						if(sc.exons_2[k] > sc.exons_1.back())
							tmp.nodes.push_back(sc.exons_2[k]);
					}

					//any combination of exons right of right mate is valid
					int last_exon_right = sc.exons_2.back();
					//cout << "last exon right " << last_exon_right << endl;
					UInt num2 = pow( 2.0, static_cast<int>(locus.size() - exon_order[last_exon_right] - 1));
					vector<UInt>::iterator prev_last2 = tmp.nodes.end()-1;
					for(UInt l=0; l<num2; ++l)
					{
						//cout << "next right combi" << endl;
						for(UInt pos=0; pos < locus.size() - exon_order[last_exon_right] - 1; ++pos) {
							if(l&1<<pos) {
								tmp.nodes.push_back( locus[exon_order[last_exon_right] + 1 + pos] );
								//cout << locus[exon_order[last_exon_right] + 1 + pos] << " ";
							}
						}
						//cout << endl;

						//here we have a transcript ready
						long idx = 0;
						for(vector<UInt>::iterator it = tmp.nodes.begin(); it!=tmp.nodes.end(); ++it) {
							idx += pow( 2.0, exon_order[*it] );
							//cout << *it << " ";
						}
						idx--;

						//assert(tmp.nodes==transcripts[idx].nodes);
						//assert(isCoverSupported(all_covers[selected_cover_ids[i]], vector<Transcript>(1,tmp)));
						float normf = getNormFactor(all_covers[selected_cover_ids[i]], tmp, segments);
						if(normf > 0) {
							nonzero_coeff[idx].push_back(normf);
							sorted_jx[idx].push_back(i+1);
						}

						if(prev_last2+1 != tmp.nodes.end())
							tmp.nodes.erase(prev_last2+1, tmp.nodes.end());
					}
					if(prev_last1+1 != tmp.nodes.end() )
						tmp.nodes.erase(prev_last1+1, tmp.nodes.end());
				}
				tmp.nodes.clear();
			}
		}

		//same for fakes
		if(Parameters::fake_mode)
		{
			for(size_t i = 0; i < fake_covers.size(); ++i)
			{
				y[selected_cover_ids.size()+i] = fake_covers[i].intensity;
        w[selected_cover_ids.size()+i] = 1./max(Parameters::pseudoCount, fake_covers[i].intensity);
				total_weight += w[selected_cover_ids.size()+i];

				//now enumerate all compatible transcripts

				SegmentCover sc = fake_covers[i];

				//any combination of exons left of left mate is valid
				Transcript tmp;
				tmp.nodes.reserve(locus.size());
				int first_exon_left = sc.exons_1.front();
				UInt num = pow( 2.0, exon_order[first_exon_left] );
				for(UInt ii=0; ii<num; ++ii)
				{
					for(UInt pos=0; pos < exon_order[first_exon_left]; ++pos) {
						if(ii&1<<pos) {
							tmp.nodes.push_back(locus[pos]);
						}
					}

					//fix left mate in transcript
					for(UInt j = 0; j < sc.exons_1.size(); j++)
						tmp.nodes.push_back(sc.exons_1[j]);

					//middle part restricted
					vector<vector<bool> > candidates;
					enumGapExonSets(sc, segments, locus, candidates);
					vector<UInt>::iterator prev_last1 = tmp.nodes.end()-1;
					for(UInt j = 0; j < max(1, (int)candidates.size()); j++)
					{
						if(candidates.size()>0) {
							for(UInt k = 0; k < candidates[j].size(); k++) {
								if(candidates[j][k]) {
									tmp.nodes.push_back( locus[exon_order[sc.exons_1.back()]+k+1] );
								}
							}
						}

						//fix right mate in transcript
						for(UInt k = 0; k < sc.exons_2.size(); k++) {
							if(sc.exons_2[k] > sc.exons_1.back())
								tmp.nodes.push_back(sc.exons_2[k]);
						}

						//any combination of exons right of right mate is valid
						int last_exon_right = sc.exons_2.back();
						UInt num2 = pow( 2.0, static_cast<int>(locus.size() - exon_order[last_exon_right] - 1));
						vector<UInt>::iterator prev_last2 = tmp.nodes.end()-1;
						for(UInt l=0; l<num2; ++l)
						{
							for(UInt pos=0; pos < locus.size() - exon_order[last_exon_right] - 1; ++pos) {
								if(l&1<<pos) {
									tmp.nodes.push_back( locus[exon_order[last_exon_right] + 1 + pos] );
								}
							}

							//here we have a transcript ready
							long idx = 0;
							for(vector<UInt>::iterator it = tmp.nodes.begin(); it!=tmp.nodes.end(); ++it) {
								idx += pow( 2.0, exon_order[*it] );
							}
							idx--;

							//assert(tmp.nodes==transcripts[idx].nodes);
							//assert(isCoverSupported(fake_covers[i], vector<Transcript>(1,tmp)));

							float normf = getNormFactor(fake_covers[i], tmp, segments);
							if(normf > 0) {
								nonzero_coeff[idx].push_back(normf);
								sorted_jx[idx].push_back(selected_cover_ids.size()+i+1);
							}

							if(prev_last2+1 != tmp.nodes.end())
								tmp.nodes.erase(prev_last2+1, tmp.nodes.end());
						}
						if(prev_last1+1 != tmp.nodes.end() )
							tmp.nodes.erase(prev_last1+1, tmp.nodes.end());
					}
					tmp.nodes.clear();
				}
			}
		}

		//now lets merge all the info
		for(long i = 0; i<pow(2.0,(int)locus.size()); i++) {
			sparse_x.insert(sparse_x.end(), nonzero_coeff[i].begin(), nonzero_coeff[i].end());
			jx.insert(jx.end(), sorted_jx[i].begin(), sorted_jx[i].end());
			last_idx += nonzero_coeff[i].size();
			ix.push_back(last_idx+1);
		}
	} else //transcripts explicitly given
	{
		/*
		//debugging stuff
		for(size_t i = 0; i < selected_cover_ids.size(); ++i)
		{
			bool sup = false;
			for(long j = 0; j < transcripts.size(); ++j)
			{
				if(isCoverSupported(all_covers[selected_cover_ids[i]], vector<Transcript>(1,transcripts[j])))
				{
					float normf = getNormFactor(all_covers[selected_cover_ids[i]], transcripts[j], segments);
					if(normf > 0) {
						sup = true;
						break;
					}
				}
			}
			if(!sup) {
				cout << i << endl;
				cout << "==============" << endl;
			}
		}
		for(size_t i = 0; i < fake_covers.size(); ++i)
		{
			bool sup = false;
			for(long j = 0; j < transcripts.size(); ++j)
			{
				if(isCoverSupported(fake_covers[i], vector<Transcript>(1,transcripts[j])))
				{
					float normf = getNormFactor(fake_covers[i], transcripts[j], segments);
					if(normf > 0) {
						sup = true;
						break;
					}
				}
			}
			if(!sup) {
				cout << "fake: " << i << endl;
				cout << "==============" << endl;
			}
		}
		*/

		//prepare for refined counts
		std::pair<unsigned, unsigned> bounds;
		bounds.first = std::max((2 * Parameters::read_length_global), (int)floor(gsl_cdf_gaussian_Pinv(Parameters::lower_percentile, Parameters::s_dev)) + Parameters::insert_size_global);
		bounds.second = ceil(gsl_cdf_gaussian_Pinv(Parameters::upper_percentile, Parameters::s_dev)) + Parameters::insert_size_global;
		std::vector<std::pair<std::vector<UInt>, double> > clusters;
		UInt tot_nof_cover = selected_cover_ids.size();
		if(Parameters::fake_mode)
			tot_nof_cover += fake_covers.size();

		//float _debug = 0;
    if (Parameters::verbose)
      cout << "constructing sparse constraint matrix." << endl;
		
    for(long j = 0; j < transcripts.size(); ++j)
		{
			if(Parameters::verbose && j%10000==0 && j!=0)
				cout << "processed " << j << " transcripts." << endl;
			for(size_t i = 0; i < selected_cover_ids.size(); ++i)
			{
				if(j==0) {
					w[i] = 1./max(Parameters::pseudoCount, all_covers[selected_cover_ids[i]].intensity);
					//w[i] = 1.;

					/*
          	  	  	//adjust weight if cover has size three
          	  	  	int cover_size = all_covers[selected_cover_ids[i]].exons_1.size() + all_covers[selected_cover_ids[i]].exons_2.size();
          	  	  	if (cover_size == 3)
          	  	  		w[i] = 0.4*w[i];
					 */
					y[i] = all_covers[selected_cover_ids[i]].intensity;
					total_weight += w[i];
					//y_mean += (1./max(Parameters::pseudoCount, all_covers[selected_cover_ids[i]].intensity)) * all_covers[selected_cover_ids[i]].intensity;
				}
				if(isCoverSupported(all_covers[selected_cover_ids[i]], vector<Transcript>(1,transcripts[j])))
				{
					float normf = getNormFactor(all_covers[selected_cover_ids[i]], transcripts[j], segments);
					if(normf > 0) {
						/*
						//if(j==2)
							//cout << i << " " << j << " " << normf << " " << normf*0.035362 << endl;
						if(j==4 && (i<=12 || (i>=18 && i<=23)))
							//cout << i << " " << j << " " << normf << " " << normf*0.34503 << endl;
							_debug += ((normf*0.35503) - all_covers[selected_cover_ids[i]].intensity)*((normf*0.35503) - all_covers[selected_cover_ids[i]].intensity)/all_covers[selected_cover_ids[i]].intensity;
						 */

/*
						cout << "explained (" << normf << ")" << endl;
						cout << "left mate:" << endl;
						for(int t=0; t<all_covers[selected_cover_ids[i]].exons_1.size(); ++t)
							cout << all_covers[selected_cover_ids[i]].exons_1[t] << " ";
						cout << endl;
						cout << "right mate:" << endl;
						for(int t=0; t<all_covers[selected_cover_ids[i]].exons_2.size(); ++t)
							cout << all_covers[selected_cover_ids[i]].exons_2[t] << " ";
						cout << endl;
*/

						cov_expl[i] = true;
						sparse_x.push_back(normf);
						jx.push_back(i+1);
						last_idx++;
					}
				}
			}
			if(Parameters::fake_mode)
			{
				for(UInt i = 0; i < fake_covers.size(); ++i)
				{
					if(j==0) {
						y[selected_cover_ids.size()+i] = fake_covers[i].intensity;
						w[selected_cover_ids.size()+i] = 1./max(Parameters::pseudoCount, fake_covers[i].intensity);
						//w[selected_cover_ids.size()+i] = 1;

						/*
            			//adjust weight if cover has size three
            			int cover_size = all_covers[selected_cover_ids.size()+i].exons_1.size() + all_covers[selected_cover_ids.size()+i].exons_2.size();
            			if (cover_size == 3)
            				w[selected_cover_ids.size()+i] = 0.4*w[selected_cover_ids.size()+i];
						 */
						total_weight += w[selected_cover_ids.size()+i];
						//y_mean += (1./max(Parameters::pseudoCount, fake_covers[i].intensity)) * fake_covers[i].intensity;
					}
					if(isCoverSupported(fake_covers[i], vector<Transcript>(1,transcripts[j])))
					{
						float normf = getNormFactor(fake_covers[i], transcripts[j], segments);
						/*UInt target[] = {240682, 240684, 240690};
						vector<UInt> targetv (target, target+sizeof(target)/sizeof(int));
						if(targetv==transcripts[j].nodes) {
							cout << "next compatible fake cover:" << endl;
							for(int yy = 0; yy < fake_covers[i].exons_1.size(); yy++)
								cout << fake_covers[i].exons_1[yy] << " ";
							cout << " - ";
							for(int yy = 0; yy < fake_covers[i].exons_2.size(); yy++)
								cout << fake_covers[i].exons_2[yy] << " ";
							cout << endl << "intensity: " << fake_covers[i].intensity << endl;
							cout << "normf = " << normf << endl;
						}*/
						if(normf > 0) {
							sparse_x.push_back(normf);
							jx.push_back(selected_cover_ids.size()+i+1);
							last_idx++;
						}
					}
				}
			}
			ix[j+1]=last_idx+1;

			//add constraints related to refined counts
			if(add_refined) {
				UInt offset = 0;
				for(size_t i = 0; i < selected_cover_ids.size(); ++i)
				{
					clusters.clear();
					computeRefinedCounts(all_covers[selected_cover_ids[i]], transcripts, segments, bounds, clusters, Parameters::read_length_global);
					if(j==0) {
						nof_obs += clusters.size();
						y.resize(nof_obs);
						w.resize(nof_obs);
					}
					for(size_t k=0; k<clusters.size(); ++k)
					{
						if(j==0) {
							w[tot_nof_cover + offset + k] = 1./max(Parameters::pseudoCount, clusters[k].second);
							//w[tot_nof_cover + offset + k] = 1./10000.;
							//w[i] = 1.;
							y[tot_nof_cover + offset + k] = clusters[k].second;
							total_weight += w[tot_nof_cover + offset + k];
						}
						if(find(clusters[k].first.begin(), clusters[k].first.end(), j) != clusters[k].first.end())
						{
							float normf = getNormFactor(all_covers[selected_cover_ids[i]], transcripts[j], segments);
							if(normf > 0) {
								sparse_x.push_back(normf);
								jx.push_back(tot_nof_cover + offset + k + 1);
								last_idx++;
							}
						}
					}
					offset += clusters.size();
				}
				ix[j+1]=last_idx+1;
			}
		}

		if(add_refined) {
			//now add slack variables for refined counts
			UInt offset = 0;
			for(size_t i = 0; i < selected_cover_ids.size(); ++i)
			{
				clusters.clear();
				computeRefinedCounts(all_covers[selected_cover_ids[i]], transcripts, segments, bounds, clusters, Parameters::read_length_global);
				ix.resize(transcripts.size()+1+offset+clusters.size());
				for(size_t k=0; k<clusters.size(); ++k)
				{
					sparse_x.push_back(1);
					jx.push_back(tot_nof_cover + offset + k + 1);
					last_idx++;
					ix[transcripts.size()+offset+k+1]=last_idx+1;
				}
				offset += clusters.size();
			}
			tot_nof_refined = offset;

			cerr << "total number of refined constraints: " << tot_nof_refined << endl;
		}
		//y_mean = y_mean / (nof_obs);
		//y_mean = y_mean / total_weight;
	}
	//cout << "y_mean = " << y_mean << endl;


	/*
	//non-sparse variant ?
	for(size_t i = 0; i < selected_cover_ids.size(); ++i)
	{
		y[i] = all_covers[selected_cover_ids[i]].intensity;
		w[i] = 1./max(1.,all_covers[selected_cover_ids[i]].intensity);
		//w[i] = 1.;
		for(long j = 0; j < transcripts.size(); ++j)
		{
			if(isCoverSupported(all_covers[selected_cover_ids[i]], vector<Transcript>(1,transcripts[j])))
			{
				float normf = getNormFactor(all_covers[selected_cover_ids[i]], transcripts[j], segments, read_length, insert_size);
				if(normf > 0) {
				  count_sparse++;				  
				}
				//cout << j << " " << nof_obs << " " << i << " " << j*nof_obs+i << endl;
				x[j*nof_obs+i] = normf;
			}
		}	
	}
	cout << "number of non-zero coeff. for positive observations: " << count_sparse << endl;
	
	
	if(Parameters::fake_mode)
	{
		for(UInt i = 0; i < fake_covers.size(); ++i)
		{
			y[selected_cover_ids.size()+i] = fake_covers[i].intensity;
			w[selected_cover_ids.size()+i] = 1./max(1.,fake_covers[i].intensity);
			//w[selected_cover_ids.size()+i] = 1.;
			for(long j = 0; j < transcripts.size(); ++j)
			{
				if(isCoverSupported(fake_covers[i], vector<Transcript>(1,transcripts[j])))
				{
					float normf = getNormFactor(fake_covers[i], transcripts[j], segments, read_length, insert_size);
					if(normf > 0) {
					  count_sparse++;					  
					}
					x[j*nof_obs + selected_cover_ids.size() + i] = normf;
				}
			}			
		}
	}
	cout <<  "total number of non-zero coeff." << count_sparse << endl;
	*/


	//lets do it

	//Input
	int ka = 1; //covariance updating algorithm
	float parm = 1; //lasso
	int nof_vars;
	if(transcripts.empty())
		nof_vars = pow(2.0,(int)locus.size());
	else {
		nof_vars = transcripts.size();
		if(add_refined)
			nof_vars += tot_nof_refined;
	}
	int jd[2];
	jd[0] = jd[1] = 0; //use all variables
	vector<float> vp(nof_vars,1.);//lambda for each transcript?

	if(add_refined) {
		for(size_t i = transcripts.size(); i<transcripts.size()+tot_nof_refined; ++i)
			vp[i] = 0;
	}

  //Use lambda values stored with the candidate transcripts
  for (size_t i = 0; i < nof_vars; ++i)
  {
    vp[i] *= transcripts[i].regWeight;
  }

/*
  if (Parameters::penaltyUncov)
  {
      for (size_t i = 0; i < nof_vars; ++i)
      {
          //vp[i] = (std::pow(100000.0, (double) transcripts[i].uncovered));
          if (transcripts[i].uncovered != 0)
              vp[i] = 100000000.;
      }
  }
  if(Parameters::useKnownTrans)
  {
    for (size_t i = 0; i < nof_vars; ++i)
    {
      //check whether transcript is known
      bool t_known = false;
      vector<Transcript>::const_iterator t_it;
      for(t_it = known_transcripts.begin(); t_it != known_transcripts.end(); ++t_it)
      {
        if(t_it->nodes.size() != transcripts[i].nodes.size())
          continue;
        vector<UInt>::const_iterator f_it = search(t_it->nodes.begin(), t_it->nodes.end(), transcripts[i].nodes.begin(), transcripts[i].nodes.end());
        if(f_it != t_it->nodes.end())
        {
          t_known = true;
          break;
        }
      }
      if(!t_known)
        vp[i] = 2.;
    }
  }

  if (Parameters::lengthNormRegularized)
  {
    //as proposed in SLIDE paper
    for (size_t i = 0; i < nof_vars; ++i)
    {
      vp[i] = 1./transcripts[i].nodes.size();
    }
  }
 */

	int ne = nof_vars; //max. number of vars in model
	//int ne = 6;
	int nx = min((int)(ne*1.2),nof_vars); //max. number of vars overall
	//int nx = 7;
	int nlam = 1000; //(max) number of lambdas
	//int nlam = 2;
	float flmin = 0.001f; //smallest lambda
	//float flmin = 2;
	vector<float> ulam; //ignored if flmin < 1
	ulam.assign(nlam,0);
/*
	for(size_t i = 0; i < selected_cover_ids.size(); ++i)
	{
		total_weight += 1./max(1.,all_covers[selected_cover_ids[i]].intensity);
	}
	total_weight += fake_covers.size();
*/
	//ulam.resize(2);
	//ulam[0] = 100./(2.*total_weight);
	//ulam[1] = ulam[0];
	float thr = 0.000000001f;
	int isd = 0; //x not standardized?
	//new in 1.9.3 compared to first (?)
	vector<float> cl;
	cl.resize(2*nof_vars);
	for(size_t i=0; i<nof_vars; i++)
		cl[2*i] = 0;				 //lower bound on transcript intens.
	for(size_t i=0; i<nof_vars; i++)
		cl[2*i+1] = 1000;			 //upper bound on transcript intens. reasonable choice?
	int intr = 0; //no intercept
	int maxit = 10000; //max. number of iterations

	//Output
	GlmnetResult out;
	out.lmu = 0; //actual number of lambdas (solution)
	out.a0.assign(nlam,0); //intercept values for each solution
	out.ca.assign(nx*nlam,0); //compressed coeff. values for each solution?
	out.ia.assign(nx,0); //pointers to compressed coeff.
	out.nin.assign(nlam,0); //nof compressed coeff. per solution
	out.rsq.assign(nlam,0); //R**2 value per solution ?
	out.alm.assign(nlam,0); //lambda value per solution
	out.nlp = 0; //total passes ?
	out.jerr = 0; //error flag
	
	//elnet_(&ka, &parm, &nof_obs, &nof_vars, &x[0], &y[0], &w[0], jd, &vp[0], &cl[0], //input paras
	//       &ne, &nx, &nlam, &flmin, &ulam[0], &thr, &isd, &intr, &maxit,          //input paras
	//       &out.lmu, &out.a0[0], &out.ca[0], &out.ia[0], &out.nin[0], &out.rsq[0], &out.alm[0], &out.nlp, &out.jerr); //output paras

  if (Parameters::verbose)
  {
    cout << "starting spelnet" << endl;
    cout << sparse_x.size() << endl;
  }
	spelnet_(&ka, &parm, &nof_obs, &nof_vars, &sparse_x[0], &ix[0], &jx[0], &y[0], &w[0], jd, &vp[0], &cl[0], //input paras
	         &ne, &nx, &nlam, &flmin, &ulam[0], &thr, &isd, &intr, &maxit,          //input paras
	         &out.lmu, &out.a0[0], &out.ca[0], &out.ia[0], &out.nin[0], &out.rsq[0], &out.alm[0], &out.nlp, &out.jerr); //output paras

	//some random output
/*
	cout << "number of vars: " << nof_vars << endl;
	for(int i=0; i<out.lmu; i++)
		cout << out.alm[i] << " " << out.a0[i] << " " << out.rsq[i] << " " << out.nin[i] << endl;

	if(out.jerr > 0) {
		cout << out.jerr << endl;
		cout << "something is wrong" << endl;
		exit(1);
	}


	int zcount = 0;
	cout << "number of solutions: " << out.lmu << endl;
	cout << "passes: " << out.nlp << endl;
	double adj_rsq;
	for(int i = 0; i < out.lmu; ++i) {
		cout << "next solution" << endl;
		cout << "lambda: " << out.alm[i] << endl;
		cout << "nin: " << out.nin[i] << endl;
		cout << "ia: " << endl;
		for(int j=0; j<nx; j++)
			cout << out.ia[j] << " ";
		cout << endl;
		for(int j=0; j<nx; j++)
			cout << out.ca[i*nx+j] << " ";
		cout << endl;
		zcount += out.nin[i];
		adj_rsq = out.rsq[i] - ( (1-out.rsq[i])*nof_vars/(nof_obs-out.nin[i]-1) );
		cout << out.alm[i] << " " << adj_rsq << endl;
	}
*/

	if(out.jerr == 7777)
		return 7777;

	if(out.rsq[0] != out.rsq[0]) {
		lambda = 0;
		return 7777;
	}

/*
	//computing my own rsq for last solution
	float var_regress_last = 0;
	float var_res_last = 0;
	float var_y_last = 0;
	//cout << "mean " << y_mean << " intercept " << out.a0[i] << endl;
	for(size_t l = 0; l < selected_cover_ids.size(); ++l)
	{
		float est_l = 0.;
		//float est_l = out.a0[i];
		for(int j=0; j<out.nin[out.lmu-1]; ++j)
		{
			if(!out.ca[(out.lmu-1)*nx+j]>0)
				continue;
			if(isCoverSupported(all_covers[selected_cover_ids[l]], vector<Transcript>(1,transcripts[out.ia[j]-1])))
			{
				float normf = getNormFactor(all_covers[selected_cover_ids[l]], transcripts[out.ia[j]-1], segments);
				est_l += normf*out.ca[(out.lmu-1)*nx+j];
			}
		}
		//var_regress += (est_l - y_mean) * (est_l - y_mean);
		//var_res += (est_l - all_covers[selected_cover_ids[l]].intensity) *  (est_l - all_covers[selected_cover_ids[l]].intensity);
		//var_y += (all_covers[selected_cover_ids[l]].intensity - y_mean) * (all_covers[selected_cover_ids[l]].intensity - y_mean);
		var_regress_last += (1./max(1.,all_covers[selected_cover_ids[l]].intensity)) * (est_l - y_mean) * (est_l - y_mean);
		var_res_last += (1./max(1.,all_covers[selected_cover_ids[l]].intensity)) * (est_l - all_covers[selected_cover_ids[l]].intensity) *  (est_l - all_covers[selected_cover_ids[l]].intensity);
		var_y_last += (1./max(1.,all_covers[selected_cover_ids[l]].intensity)) * (all_covers[selected_cover_ids[l]].intensity - y_mean) * (all_covers[selected_cover_ids[l]].intensity - y_mean);
	}
	for(UInt l = 0; l < fake_covers.size(); ++l)
	{
		float est_l = 0.;
		//float est_l = out.a0[i];
		for(int j=0; j<out.nin[out.lmu-1]; ++j)
		{
			if(!out.ca[(out.lmu-1)*nx+j]>0)
				continue;
			if(isCoverSupported(fake_covers[l], vector<Transcript>(1,transcripts[out.ia[j]-1])))
			{
				float normf = getNormFactor(fake_covers[l], transcripts[out.ia[j]-1], segments);
				est_l += normf*out.ca[(out.lmu-1)*nx+j];
			}
		}
		//var_regress += (est_l - y_mean) * (est_l - y_mean);
		//var_res += (est_l - fake_covers[l].intensity) * (est_l - fake_covers[l].intensity);
		//var_y += (fake_covers[l].intensity - y_mean) * (fake_covers[l].intensity - y_mean);
		var_regress_last += (1./max(1.,fake_covers[l].intensity)) * (est_l - y_mean) * (est_l - y_mean);
		var_res_last += (1./max(1.,fake_covers[l].intensity)) * (est_l - fake_covers[l].intensity) * (est_l - fake_covers[l].intensity);
		var_y_last += (1./max(1.,fake_covers[l].intensity)) * (fake_covers[l].intensity - y_mean) * (fake_covers[l].intensity - y_mean);
	}

	double myrsq_last = 1 - (var_res_last/var_y_last);
*/

    double sse_f = out.rsq[out.lmu-1] * out.rsq[out.lmu-1];
	//double sse_f = myrsq_last * myrsq_last;

	int prev_nin = -1;
	double prev_adj_rsq;
	int chosen_sol = -1;
	double best_adj_rsq;
	double best_cp;
	for(int i = 0; i < out.lmu; ++i) {
		//cout << "lambda: " << out.alm[i] << endl;

		//compute real nof nonzero coeff.
/*		double tot_intens = 0.;
		for(int j=0; j<out.nin[i]; ++j) {
			tot_intens += out.ca[i*nx+j];
		}
*/
		int nof_nonzero = 0;
		for(int j=0; j<out.nin[i]; ++j)
		{
			/*
			cout << "next predicted transcript: " << endl;
			for(size_t yy = 0; yy < transcripts[out.ia[j]-1].nodes.size(); yy++)
				cout << transcripts[out.ia[j]-1].nodes[yy] << " ";
			cout << " " << out.ca[i*nx+j] << endl;
			*/

			//if(out.ca[i*nx+j]/tot_intens > 0.1) {
				//nof_nonzero++;
				//cout << "...which is truely non-zero." << endl;
			//}
			if(add_refined && out.ia[j]-1>transcripts.size()-1) {//do not count slack variable
				continue;
			}

			if(out.ca[i*nx+j] > 0.000001)
				nof_nonzero++;
		}

		//****************************************
			    //debugging stuff
/*				float total_cover_error = 0.;
				for(size_t l = 0; l < selected_cover_ids.size(); ++l)
				{
					float est_l = 0.;
					//float est_l = out.a0[i];
					for(int j=0; j<out.nin[i]; ++j)
					{
						if(!out.ca[i*nx+j]>0)
							continue;
						if(isCoverSupported(all_covers[selected_cover_ids[l]], vector<Transcript>(1,transcripts[out.ia[j]-1])))
						{
							float normf = getNormFactor(all_covers[selected_cover_ids[l]], transcripts[out.ia[j]-1], segments);
							est_l += normf*out.ca[i*nx+j];
						}
					}
					total_cover_error += (est_l - all_covers[selected_cover_ids[l]].intensity) * (est_l - all_covers[selected_cover_ids[l]].intensity) * total_weight / max(1.,all_covers[selected_cover_ids[l]].intensity);
					//cout << l << " cover intens " << all_covers[selected_cover_ids[l]].intensity << " vs " << est_l << endl;
				}
				cout << "total cover error: " << total_cover_error << endl;
				float total_fake_error = 0.;
				for(UInt l = 0; l < fake_covers.size(); ++l)
				{
					float est_l = 0.;
					for(int j=0; j<out.nin[i]; ++j)
					{
						if(!out.ca[i*nx+j]>0)
							continue;
						if(isCoverSupported(fake_covers[l], vector<Transcript>(1,transcripts[out.ia[j]-1])))
						{
							float normf = getNormFactor(fake_covers[l], transcripts[out.ia[j]-1], segments);
							est_l += normf*out.ca[i*nx+j];
						}
					}
					total_fake_error += (est_l - fake_covers[l].intensity) * (est_l - fake_covers[l].intensity) * total_weight;
					//cout << l+selected_cover_ids.size() << " fake intens " << fake_covers[l].intensity << " vs " << est_l << endl;
				}
				cout << "total fake error: " << total_fake_error << endl;

				float total_intens = 0.;
				for(int j=0; j<out.nin[i]; ++j)
				{
					total_intens += out.ca[i*nx+j];
				}
				cout << "total objective: " << (total_intens * out.alm[i]) + total_fake_error + total_cover_error << endl; */
				//****************************************


/*
		//computing my own rsq
		float var_regress = 0;
		float var_res = 0;
		float var_y = 0;
		//cout << "mean " << y_mean << " intercept " << out.a0[i] << endl;
		for(size_t l = 0; l < selected_cover_ids.size(); ++l)
		{
			float est_l = 0.;
			//float est_l = out.a0[i];
			for(int j=0; j<out.nin[i]; ++j)
			{
				if(!out.ca[i*nx+j]>0)
					continue;
				if(isCoverSupported(all_covers[selected_cover_ids[l]], vector<Transcript>(1,transcripts[out.ia[j]-1])))
				{
					float normf = getNormFactor(all_covers[selected_cover_ids[l]], transcripts[out.ia[j]-1], segments);
					est_l += normf*out.ca[i*nx+j];
				}
			}
			//var_regress += (est_l - y_mean) * (est_l - y_mean);
			//var_res += (est_l - all_covers[selected_cover_ids[l]].intensity) *  (est_l - all_covers[selected_cover_ids[l]].intensity);
			//var_y += (all_covers[selected_cover_ids[l]].intensity - y_mean) * (all_covers[selected_cover_ids[l]].intensity - y_mean);
			var_regress += (1./max(1.,all_covers[selected_cover_ids[l]].intensity)) * (est_l - y_mean) * (est_l - y_mean);
			var_res += (1./max(1.,all_covers[selected_cover_ids[l]].intensity)) * (est_l - all_covers[selected_cover_ids[l]].intensity) *  (est_l - all_covers[selected_cover_ids[l]].intensity);
			var_y += (1./max(1.,all_covers[selected_cover_ids[l]].intensity)) * (all_covers[selected_cover_ids[l]].intensity - y_mean) * (all_covers[selected_cover_ids[l]].intensity - y_mean);
		}
		for(UInt l = 0; l < fake_covers.size(); ++l)
		{
			float est_l = 0.;
			//float est_l = out.a0[i];
			for(int j=0; j<out.nin[i]; ++j)
			{
				if(!out.ca[i*nx+j]>0)
					continue;
				if(isCoverSupported(fake_covers[l], vector<Transcript>(1,transcripts[out.ia[j]-1])))
				{
					float normf = getNormFactor(fake_covers[l], transcripts[out.ia[j]-1], segments);
					est_l += normf*out.ca[i*nx+j];
				}
			}
			//var_regress += (est_l - y_mean) * (est_l - y_mean);
			//var_res += (est_l - fake_covers[l].intensity) * (est_l - fake_covers[l].intensity);
			//var_y += (fake_covers[l].intensity - y_mean) * (fake_covers[l].intensity - y_mean);
			var_regress += (1./max(1.,fake_covers[l].intensity)) * (est_l - y_mean) * (est_l - y_mean);
			var_res += (1./max(1.,fake_covers[l].intensity)) * (est_l - fake_covers[l].intensity) * (est_l - fake_covers[l].intensity);
			var_y += (1./max(1.,fake_covers[l].intensity)) * (fake_covers[l].intensity - y_mean) * (fake_covers[l].intensity - y_mean);
		}

		double myrsq = 1 - (var_res/var_y);
		//cout << "my rsq: " << myrsq << endl;
		double myadjrsq = myrsq - ((1-myrsq)*nof_nonzero/(nof_obs-nof_nonzero-1));
		//cout <<  "adj my rsq: " << myadjrsq << endl;
*/
		//cout << "number of true non-zero: " << nof_nonzero << endl;
		//cout << out.alm[i]*2*total_weight;
		//cout << "rsq: " << out.rsq[i] << endl;
		//double adj_rsq = out.rsq[i] - ( (1-out.rsq[i])*nof_vars/(nof_obs-out.nin[i]-1) );
		//cout << nof_obs << " " << nof_nonzero << endl;
		//cout << "rsq of glmnet: " << out.rsq[i] << endl;
		double mallow_cp = ((out.rsq[i] * out.rsq[i] * nof_obs) / sse_f ) - nof_obs + (2*nof_nonzero);
		//double my_mallow_cp = ((myrsq * myrsq * nof_obs) / sse_f ) - nof_obs + (2*nof_nonzero);
		//cout << mallow_cp << endl;
		double adj_rsq = out.rsq[i] - ( (1-out.rsq[i])*nof_nonzero/(nof_obs-nof_nonzero-1) );
		//cout << "adj_rsq: " << adj_rsq << endl;
		//if(i > 0 && out.nin[i] > prev_nin) {
/*
		if(i > 0 && nof_nonzero > prev_nin) {
			//cout << (adj_rsq - prev_adj_rsq)/prev_adj_rsq << endl;
			if( out.nin[i-1] > 0 && ((adj_rsq < prev_adj_rsq) || fabs((adj_rsq - prev_adj_rsq)/prev_adj_rsq) <= 0.01)) {
			//if(fabs((myadjrsq - prev_adj_rsq)/prev_adj_rsq) <= 0.01) {
			//if(adj_rsq <= prev_adj_rsq) {
				chosen_sol = i-1;
				break;
			}
			//prev_nin = out.nin[i];
			prev_nin = nof_nonzero;
		}
*/


		if(i==0)
			best_adj_rsq = adj_rsq;
			//best_adj_rsq = myadjrsq;
			//best_cp = my_mallow_cp;
		else if(i>0 && adj_rsq > best_adj_rsq) {
		//else if(i>0 && myadjrsq > best_adj_rsq) {
		//else if (i>0 && my_mallow_cp > best_cp) {
			chosen_sol = i;
			best_adj_rsq = adj_rsq;
			//best_adj_rsq = myadjrsq;
			//best_cp = my_mallow_cp;
		}


		prev_adj_rsq = adj_rsq;
		//prev_adj_rsq = myadjrsq;

		if(i == out.lmu-1 && chosen_sol == -1)
			chosen_sol = i;

	}

	if(chosen_sol == -1) {
	  cout << "no solution chosen. " << endl;
	  cout << out.jerr << endl;	
	  return 1;
	}

	//cout << "chosen lambda: " << out.alm[chosen_sol] << " (" <<static_cast<float>(chosen_sol)/out.lmu << ")" << endl;
	//cout << "number of iterations: " << out.nlp << endl;
	//cout << "jerr = " << out.jerr << endl;
	//cout << "total weight " << total_weight << endl;
	for(int i=0; i<transcripts.size(); ++i) {
		computed_intens[transcripts[i].id] = 0;
		//computed_intens[i] = 0;
	}

	//cout << "number of non-zero: " << out.nin[chosen_sol] << endl;
	for(int i=0; i<out.nin[chosen_sol]; ++i)
	{
		if(add_refined && out.ia[i]-1>transcripts.size()-1) //slack variable
			continue;

		//cout << out.ca[chosen_sol*nx+i] << endl;
		if (Parameters::penaltyUncov && transcripts[out.ia[i]-1].uncovered != 0)
		{
			if (out.ca[chosen_sol*nx+i] > 0.0001)
			{
				static int numInvalid = 0;
				std::cerr << "USED PENALIZED TRANS WITH INTENS: " << out.ca[chosen_sol*nx+i]  << "  Total: " << ++numInvalid << std::endl;
				//exit(1);
			}
		}

		if(transcripts.empty())
			computed_intens[out.ia[i]-1] = out.ca[chosen_sol*nx+i];
		else
			computed_intens[transcripts[out.ia[i]-1].id] = out.ca[chosen_sol*nx+i];
    }
	lambda = (chosen_sol == 0) ? out.alm[chosen_sol] : out.alm[chosen_sol]*2*total_weight;


	//****************************************
	//determine total error in lp notion
	if(!transcripts.empty()) {
		float total_cover_error = 0.;
		for(size_t l = 0; l < selected_cover_ids.size(); ++l)
		{
			//cout << "cover " << l << endl;
			float est_l = 0.;
			//float est_l = out.a0[i];
			for(int j=0; j<out.nin[chosen_sol]; ++j)
			{
				if(add_refined && out.ia[j]-1>transcripts.size()-1) //slack variable
					continue;

				//cout << "transcript: " << j << endl;
				//cout << "transcript: " << out.ia[j]-1 << endl;
				if(!out.ca[chosen_sol*nx+j]>0)
					continue;
				if(isCoverSupported(all_covers[selected_cover_ids[l]], vector<Transcript>(1,transcripts[out.ia[j]-1])))
				{
					float normf = getNormFactor(all_covers[selected_cover_ids[l]], transcripts[out.ia[j]-1], segments);
					est_l += normf*out.ca[chosen_sol*nx+j];
					//cout << "normf " << normf << endl;
					//cout << "est_l = " <<  normf*out.ca[chosen_sol*nx+j] << endl;
				}
			}
			//total_cover_error += (est_l - all_covers[selected_cover_ids[l]].intensity) * (est_l - all_covers[selected_cover_ids[l]].intensity) * total_weight / max(1.,all_covers[selected_cover_ids[l]].intensity);
			total_cover_error += (est_l - all_covers[selected_cover_ids[l]].intensity) * (est_l - all_covers[selected_cover_ids[l]].intensity) * 1. / max(1.,all_covers[selected_cover_ids[l]].intensity);
			//cout << "total cover error: " << total_cover_error << endl;
			//cout << l << " cover intens " << all_covers[selected_cover_ids[l]].intensity << " vs " << est_l << endl;
		}
		//cout << "total cover error: " << total_cover_error << endl;
		float total_fake_error = 0.;
		//cout << "now the fakes"	 << endl;
		for(UInt l = 0; l < fake_covers.size(); ++l)
		{
			//cout << "cover " << l << endl;
			float est_l = 0.;
			for(int j=0; j<out.nin[chosen_sol]; ++j)
			{
				if(add_refined && out.ia[j]-1>transcripts.size()-1) //slack variable
					continue;
				//cout << "transcript: " << j << endl;
				if(!out.ca[chosen_sol*nx+j]>0)
					continue;
				if(isCoverSupported(fake_covers[l], vector<Transcript>(1,transcripts[out.ia[j]-1])))
				{
					float normf = getNormFactor(fake_covers[l], transcripts[out.ia[j]-1], segments);
					est_l += normf*out.ca[chosen_sol*nx+j];
					//cout << "normf " << normf << endl;
				}
			}
			//total_fake_error += (est_l - fake_covers[l].intensity) * (est_l - fake_covers[l].intensity) * total_weight;
			total_fake_error += (est_l - fake_covers[l].intensity) * (est_l - fake_covers[l].intensity);
			//cout << "total fake error: " << total_fake_error << endl;
			//cout << selected_cover_ids.size()+l << " fake intens " << fake_covers[l].intensity << " vs " << est_l << endl;
		}
		//cout << "total fake error: " << total_fake_error << endl;

		float total_intens = 0.;
		for(int j=0; j<out.nin[chosen_sol]; ++j)
		{
			if(add_refined && out.ia[j]-1>transcripts.size()-1) //slack variable
				continue;
			total_intens += out.ca[chosen_sol*nx+j];
		}
		//cout << "total intens: " << total_intens * out.alm[chosen_sol]*2*total_weight << endl;

		//cout << "total objective: " << (total_intens * out.alm[chosen_sol]*2*total_weight) + total_fake_error + total_cover_error << endl;
		//****************************************
		total_error = total_cover_error + total_fake_error;
	}
	
	return out.jerr;
}



//similar to previous buildILP method, but returns computed intensities
//minor changes: squared norm in denominator, creates fake covers, no normalization of intensities
//------------------------------------------------------------------------------------------------
int buildILP(const vector<Transcript>&transcripts,
             map<UInt, double>& computed_intens,
             const vector<SegmentCover>& all_covers,
             const vector<UInt>& selected_cover_ids,
             const vector<SuperSegmentCover>& all_super_covers,
             const map<UInt, set<UInt> > &supercovers_to_covers,
             const TAllSegmentsMap &segments,
             UInt read_length,
             UInt insert_size,
             bool de_novo)

{
  //normalize the intensity of the covers to 1
  //double max_intens=-1.0;
  //double sum_intens = 0.0;
  /*  for(size_t i=0; i<covers.size();++i)
  {
    //sum_intens += covers[i].intensity;
    //max_intens=max(max_intens, covers[i].intensity);
      min_intens = min(min_intens, covers[i].intensity);
      std::cout << covers[i].intensity << std::endl;f
  }

  for(size_t i=0; i<covers.size();++i)
  {
    //covers[i].intensity=covers[i].intensity/max_intens;
  }
*/

  std::vector<SegmentCover> fake_covers;
  vector<UInt>::const_iterator cov_id_iter;
  generateFakeCovers(all_covers, selected_cover_ids, transcripts, fake_covers, Parameters::fake_mode);
  
  IloEnv env; // get an ILOG environment
  try {
    //ILP variables for directed edges
    IloModel model(env); // get an empty ILOG model

    //----------------------------------------------------
    //----------------Variables Section-------------------
    //----------------------------------------------------

    //binary variable for every transcript representing the abundant/missing status
    IloBoolVarArray trannscript_active(env, transcripts.size());

    //numerical variable for every transcript representing the intensity for that transcript
    IloNumVarArray transcript_intens(env, transcripts.size(),0.0, IloInfinity);

    //count the number of supercovers associated to the covers
    std::set<UInt> associated_supercovers;
    std::vector<UInt>::const_iterator cov_it = selected_cover_ids.begin();
    while (cov_it != selected_cover_ids.end())
    {
      map<UInt, set<UInt> >::const_iterator map_it = supercovers_to_covers.find(*cov_it);
      if(map_it != supercovers_to_covers.end())
      {
        associated_supercovers.insert(map_it->second.begin(), map_it->second.end());
      }
      ++cov_it;
    }

    //std::cerr<<"#supercovers: " << associated_supercovers.size() << std::endl;

    //one numeric variable for every node cover denoting the error between measured and computed COVERAGE
    //this is a small hack. actually the last transcript is the one containing all nodes
    IloNumVarArray errors(env, selected_cover_ids.size(), 0.0, IloInfinity);
    IloNumVarArray errors_fake(env, fake_covers.size(), 0.0, IloInfinity);
    IloNumVarArray errors_super(env, associated_supercovers.size(), 0.0, IloInfinity);

    std::vector<double> weights(selected_cover_ids.size(), 1.);
    std::vector<double> weights_super(associated_supercovers.size(), 1.);
    std::vector<double> weights_fake(fake_covers.size(), 1.);

    typedef std::vector<map<UInt, list<IloNumVar> > > TVarMapType;
    TVarMapType sub_transcript_intens(transcripts.size());

    //----------------------------------------------------
    //--------------------Constraints---------------------
    //----------------------------------------------------


    //CONSTRAINT
    //Constraints for normal covers
    IloExpr constr_cov(env);
    Size id = 0;
    for(cov_id_iter = selected_cover_ids.begin(); cov_id_iter != selected_cover_ids.end(); ++cov_id_iter)
    {
      bool add_row = false;
      //add all transcripts that support this cover
      double confidence;
      for(int j = 0; j < transcript_intens.getSize(); ++j)
      {
        if(isCoverSupported(all_covers[*cov_id_iter], vector<Transcript>(1,transcripts[j])))
        {
          float normf = getNormFactor(all_covers[*cov_id_iter], transcripts[j], segments);
          //float normf = getCoverLength(all_covers[*cov_id_iter], segments, read_length, insert_size);
          confidence = 1 - exp(-normf/100);
          {
            if(all_covers[*cov_id_iter].intensity > 0 || Parameters::fake_mode)
            {
              sub_transcript_intens[j][*cov_id_iter].push_back(IloNumVar(env, 0.0, IloInfinity));
              constr_cov += sub_transcript_intens[j][*cov_id_iter].back() * normf;
              add_row = true;
            }
          }
        }
      }
      if(add_row)
      {
        model.add(constr_cov <= errors[id] + all_covers[*cov_id_iter].intensity);
        model.add(constr_cov >= all_covers[*cov_id_iter].intensity - errors[id]);
        constr_cov.clear();
      }
      ++id;
    }
    constr_cov.end();


    //CONSTRAINT
    //Constraints for fake covers
    if(Parameters::fake_mode)
    {
      id = 0;
      IloExpr constr_fake(env);
      for(UInt i = 0; i < fake_covers.size(); ++i)
      {
        bool add_row = false;
        //add all transcripts that support this cover
        double confidence;
        for(int j = 0; j < transcript_intens.getSize(); ++j)
        {
          if(isCoverSupported(fake_covers[i], vector<Transcript>(1,transcripts[j])))
          {
            float normf = getNormFactor(fake_covers[i], transcripts[j], segments);
            confidence = 1 - exp(-normf/100);
            //sub_transcript_intens[j][i].push_back(IloNumVar(env, 0.0, IloInfinity));
            constr_fake += transcript_intens[j] * normf;
            add_row = true;
          }
        }
        if(add_row)
        {
          model.add(constr_fake <= errors_fake[id] + fake_covers[i].intensity);
          model.add(constr_fake >= fake_covers[i].intensity - errors_fake[id]);
          constr_fake.clear();
        }
        ++id;
      }
      constr_fake.end();
    }


    //CONSTRAINT
    //Constraints for supercovers
    IloExpr constr_sup(env);

    id = 0;
    std::set<UInt>::const_iterator ass_sup_it;
    for(ass_sup_it = associated_supercovers.begin(); ass_sup_it != associated_supercovers.end(); ++ass_sup_it)
    {
      bool add_row = false;
      SuperSegmentCover::TContainerType::const_iterator cov_it;
      for(cov_it = all_super_covers[*ass_sup_it].covers.begin(); cov_it != all_super_covers[*ass_sup_it].covers.end(); ++cov_it)
      {
        for(int j = 0; j < transcript_intens.getSize(); ++j)
        {
          if(isCoverSupported(all_covers[*cov_it], vector<Transcript>(1,transcripts[j])))
          {
            if(all_super_covers[*ass_sup_it].intensity > 0 || Parameters::fake_mode)
            {
              sub_transcript_intens[j][*cov_it].push_back(IloNumVar(env, 0.0, IloInfinity));
              float normf = getNormFactor(all_covers[*cov_it], transcripts[j], segments);

              constr_sup += sub_transcript_intens[j][*cov_it].back() * normf;
              add_row = true;
            }
          }
        }
      }
      if(add_row)
      {
        model.add(constr_sup <= errors_super[id] + all_super_covers[*ass_sup_it].intensity);
        model.add(constr_sup >= all_super_covers[*ass_sup_it].intensity - errors_super[id]);
        constr_sup.clear();
      }
      ++id;
    }
    constr_sup.end();


    //CONSTRAINT
    //couple the transcript sub_intensities to the overall intensity for each transcript
    IloExpr constr_couple(env);
    for(Size i = 0; i < transcripts.size(); ++i)
    {
      map<UInt, list<IloNumVar> >::const_iterator m_it;
      for(m_it = sub_transcript_intens[i].begin(); m_it != sub_transcript_intens[i].end(); ++m_it)
      {
        std::list<IloNumVar>::const_iterator var_it;
        for(var_it = m_it->second.begin(); var_it != m_it->second.end(); ++var_it)
        {
          constr_couple += *var_it;
        }
        model.add(constr_couple == transcript_intens[i]);
        constr_couple.clear();
      }
    }
    constr_couple.end();



    //CONSTRAINT
    //couples the intensities for each transcript to the binary switch variable (one row per transcript)
    // !! ONLY FOR DE NOVO !!
    if(de_novo)
    {
      for (int i = 0; i < trannscript_active.getSize(); ++i)
      {
        model.add(transcript_intens[i] <= trannscript_active[i]);
      }
    }

    //third constraint forces to support all registered mate pair data (since the mate pair counts are not taken into account in first constraint)
    // !!  ONLY FOR DE NOVO !!
    //@TODO This makes also sense for non de novo. But actually we don't want to use the binary variables "transcript_active". we can also use the intensities and force them to be at some minimal vaue
    //    if(de_novo)
    //    {
    //      IloExpr constr_3(env);
    //      for(UInt i = 0; i < covers.size(); ++i)
    //      {
    //        bool add_row = false;
    //        //add all transcripts that support this cover
    //        for(int j = 0; j < transcript_intens.getSize(); ++j)
    //        {
    //          if(isCoverSupported(covers[i], vector<Transcript>(1,transcripts[j])) && !covers[i].exons_2.empty() &&
    //             getNormFactor(covers[i], transcripts[j], segments, read_length, insert_size)>0)
    //          {
    //            constr_3 += trannscript_active[j];
    //            add_row = true;
    //          }
    //        }
    //        if(add_row)
    //        {
    //          model.add(constr_3 >= 1);
    //          constr_3.clear();
    //        }
    //      }
    //      constr_3.end();
    //    }


    //----------------------------------------------------
    //----------------Objective Function------------------
    //----------------------------------------------------
    //--The objective function is to minimize the total---
    //----------number of selected Transcripts------------
    //----------------------------------------------------

    IloExpr obj(env);
    //keep the number of transcripts small
    // !! ONLY FOR DE NOVO !!
    if(de_novo)
    {
      for (int i = 0; i < trannscript_active.getSize(); ++i)
      {
        obj += trannscript_active[i];
      }
    }

    //keep the errors small for each ordinary cover
    id = 0;
    for(cov_id_iter = selected_cover_ids.begin(); cov_id_iter != selected_cover_ids.end(); ++cov_id_iter)
    {
      double norm = max(1., all_covers[*cov_id_iter].intensity);
      if(!Parameters::weights)
      {
        obj += (delta_penalty * errors[id])/(sqrt(norm));
      }
      else
      {
        obj += (weights[id] * delta_penalty * errors[id])/(sqrt(norm));
      }
      ++id;
    }

    //keep the errors small for each super_cover
    id = 0;
    for(ass_sup_it = associated_supercovers.begin(); ass_sup_it != associated_supercovers.end(); ++ass_sup_it)
    {
      double norm = max(1., all_super_covers[*ass_sup_it].intensity);
      if(!Parameters::weights)
      {
        obj += (delta_penalty * errors_super[id])/(sqrt(norm));
      }
      else
      {
        obj += (weights_super[id] * delta_penalty * errors_super[id])/(sqrt(norm));
      }
      ++id;
    }

    //keep the errors small for each fake cover
    if(Parameters::fake_mode)
    {
      for (size_t i = 0; i < fake_covers.size(); ++i)
      {
        double norm = max(1., fake_covers[i].intensity);
        if (!Parameters::weights)
        {
          obj += (delta_penalty * errors_fake[i])/(sqrt(norm));
        }
        else
        {
          obj += (weights_fake[i] * delta_penalty * errors_fake[i])/(sqrt(norm));
        }
      }
    }

    model.add(IloMinimize(env, obj));
    obj.end();


    //solve the ilp model
    IloCplex cplex(model);
    cplex.setOut(env.getNullStream());
    //cplex.exportModel("transcript_lp.lp");
    cplex.solve();

    //fetch result
    for(int i=0; i<transcript_intens.getSize(); ++i)
    {
      if(!cplex.isExtracted(transcript_intens[i]))
        continue;
      computed_intens[transcripts[i].id] = cplex.getValue(transcript_intens[i]);
    }
  }

  catch (IloException& ex)
  {
    cerr << "Error: " << ex << endl;
  }
  catch (...)
  {
    cerr << "Error" << endl;
  }

  env.end();

  return 0;
}

//for sorting the covers by their left exon
//operator < ignores different lengths
bool lexico_smaller(const SegmentCover& lhs, const SegmentCover& rhs)
{
	UInt size=std::min(lhs.exons_1.size(), rhs.exons_1.size());
	for(UInt i=0; i<size; ++i)
	{
	    if(lhs.exons_1[i]<rhs.exons_1[i])
	    {
	      return true;
	    }
	    else if(lhs.exons_1[i]>rhs.exons_1[i])
	    {
	      return false;
	    }
	}
	if(rhs.exons_1.size() > size)
		return true;
	return false;
}



//the column generation method for de novo assembly
//converts all reads to single-ends
//returns inferred_transcripts and computed_intens, which match via id
void colgen_se(vector<Transcript>& inferred_transcripts,
		       const vector<UInt>& locus,
		       map<UInt, double>& computed_intens,
		       const vector<SegmentCover>& covers_in,
           const TAllSegmentsMap& segments,
		       UInt read_length)
{
  typedef seqan::Graph<seqan::Directed<> > TGraph;
  typedef seqan::VertexDescriptor<TGraph>::Type TVertexDescriptor;
  typedef seqan::EdgeDescriptor<TGraph>::Type TEdgeDescriptor;

  //for balancing multi-objective
  const float trans_coeff = 50.;

  //consider paired-ends as single-ends (only left mate)
  //and ignore too long reads
  //---------------------------------------------------
  vector<SegmentCover> covers;
  bool right_mate_ex = false;
  for (size_t i = 0; i < covers_in.size(); ++i) {
	  if(covers_in[i].exons_1.size() > 0 && covers_in[i].exons_1.size() <= 2) {
		  covers.push_back(covers_in[i]);
	  }
	  if(covers_in[i].exons_2.size() > 0 && covers_in[i].exons_2.size() <= 2) {
		  right_mate_ex = true;
		  SegmentCover tmp;
		  tmp.exons_1 = covers_in[i].exons_2;
		  tmp.intensity = covers_in[i].intensity;
		  covers.push_back(tmp);
	  }
  }
  
  //merge identical covers
  vector<SegmentCover> merged_covers;
  if(right_mate_ex) { //otherwise no collision (uniqueness) assumed
	  std::sort(covers.begin(), covers.end(), lexico_smaller);
	  SegmentCover tmp;
	  tmp.exons_1 = covers[0].exons_1;
	  tmp.intensity = 0;
	  for(UInt i=0; i<covers.size(); ++i) {
		  if( covers[i].exons_1.size() == tmp.exons_1.size() &&
		      equal(covers[i].exons_1.begin(),covers[i].exons_1.end(),tmp.exons_1.begin()) )
		  {
			  tmp.intensity += covers[i].intensity;
		  } else
		  {
			  merged_covers.push_back(tmp);
			  tmp.exons_1 = covers[i].exons_1;
			  tmp.intensity = covers[i].intensity;
		  }
	  }
	  merged_covers.push_back(tmp);
	  covers = merged_covers;
  }

  //search for all exons (nodes in the splice graph) and junctions (edges in splice graph)
  //that are not part of some cover.
  //for all theses junctions we generate a node cover with intensity 0
  //--------------------------------------------------------------------------------------
  std::set<pair<UInt, UInt> >abundant_junctions;
  std::set<UInt>abundant_singles;
  for(UInt i=0; i<covers.size(); ++i)
  {
    if(covers[i].exons_1.size()==1)
    {
      abundant_singles.insert(covers[i].exons_1.front());
    }

    for(int j=0; j<(int)covers[i].exons_1.size()-1; ++j)
    {
      abundant_junctions.insert(make_pair(covers[i].exons_1[j], covers[i].exons_1[j+1]));
    }
  }

  for(UInt i=0; i<locus.size()-1; ++i)
  {
    if(abundant_singles.find(locus[i]) == abundant_singles.end())
    {
      SegmentCover tmp;
      tmp.exons_1.push_back(locus[i]);
      tmp.intensity=0.0;
      covers.push_back(tmp);
    }
    for(UInt j=i+1; j<locus.size(); ++j)
    {
      if(abundant_junctions.find(make_pair(locus[i], locus[j])) == abundant_junctions.end())
      {
        SegmentCover tmp;
        tmp.exons_1.push_back(locus[i]);
        tmp.exons_1.push_back(locus[j]);
        tmp.intensity=0.0;
        covers.push_back(tmp);
      }
    }
  }
  if(abundant_singles.find(locus[locus.size()-1]) == abundant_singles.end())
  {
    SegmentCover tmp;
    tmp.exons_1.push_back(locus[locus.size()-1]);
    tmp.intensity=0.0;
    covers.push_back(tmp);
  }


  //map exon to position in locus
  //-----------------------------
  map<int, int> exon_order;
  for (size_t i = 0; i < locus.size(); i++)
    exon_order[locus[i]] = i;
  
  vector<std::vector<bool> > vars;
  
  IloEnv env;
  try {
    IloNumArray cov(env);
    IloNumArray l(env);
    
    //compute mapping from nodes and edges in transcript graph to respective cover
    //----------------------------------------------------------------------------
    vector<int> node_idx_map(locus.size(), -1);

    vector<vector<vector<int> > > edge_idx_map(locus.size()-1);
    for (size_t i = 0; i < locus.size() - 1; i++)
    {
      edge_idx_map[i].resize(locus.size() - 1 - i);
      //edge_idx_map[i].assign(locus.size()-1-i, -1);
    }

    for (size_t i = 0; i < covers.size(); ++i)
    {
      cov.add(-1 * covers[i].intensity);
      if (covers[i].exons_1.size() == 1)
      {
        assert(node_idx_map[ exon_order[covers[i].exons_1.front()] ] == -1);
        node_idx_map[ exon_order[covers[i].exons_1.front()] ] = i;
      } else
      {
        int first_idx = exon_order[covers[i].exons_1[0]];
        int second_idx = exon_order[covers[i].exons_1[1]];
        //int last_idx = exon_order[covers[i].exons_1.back()];
        //edge_idx_map[first_idx][last_idx-first_idx-1].push_back(i);
        edge_idx_map[first_idx][second_idx-first_idx-1].push_back(i);
      }
    }
    
    for(size_t i = 0; i < covers.size(); ++i)
      cov.add(covers[i].intensity);
    
    for(size_t i = 0; i < covers.size(); ++i)
    {
      l.add(getCoverLength(covers[i], segments, read_length));
    }
    
    IloModel approxCov(env);
    
    IloObjective transUsed = IloAdd(approxCov, IloMinimize(env));
    IloRangeArray covered = IloAdd(approxCov, IloRangeArray(env, cov, IloInfinity));
    
    IloNumVarArray error(env);
    IloNumVarArray trans_intens(env);
    
    //create columns for error vars
    //-----------------------------
    for (size_t i = 0; i < covers.size(); ++i)
    {
      double norm = max(1., covers[i].intensity);
      //float norm = max(0.1,covers[i].intensity);

      //error.add(IloNumVar(transUsed((1.-alpha)/((norm))) +  covered[i](1) + covered[covers.size()+i](1)));
      error.add(IloNumVar(transUsed((1.)/(sqrt(norm))) +  covered[i](1) + covered[covers.size()+i](1)));
    }
    
    IloCplex approxSolver(approxCov);
    approxSolver.setOut(env.getNullStream());
    approxSolver.setParam(IloCplex::RootAlg, IloCplex::Primal);
    
    
    //construct transcript graph
    //--------------------------

    TVertexDescriptor s = 0;
    TVertexDescriptor t = locus.size() + 1;
    TGraph G;

    for (size_t i = 0; i < locus.size() + 2; ++i) //add 2 additional nodes s and t at first and last position
    {
      seqan::addVertex(G);
    }

    std::vector< std::vector<TEdgeDescriptor> > edge_ids(locus.size() + 1);

    for (size_t i = 0; i < locus.size() + 1; ++i)
    {
      edge_ids[i].assign(locus.size() + 1 - i, 0);
      for (size_t j = i + 1; j < locus.size() + 2; ++j)
      {
        if (i==0 || j == locus.size() + 1 || !edge_idx_map[i-1][j-1-i].empty())
          edge_ids[i][j - i - 1] = seqan::addEdge(G, i, j);
      }
    }

    seqan::String<double> edge_weights;
    seqan::resizeEdgeMap(edge_weights, G);

    //assign 0-weights to edges ending at node t
    //------------------------------------------
    for (size_t i = 1; i < locus.size() + 1; ++i)
    {
      seqan::property(edge_weights, edge_ids[i][t - i - 1]) = 0.;
    }
    
    //THE HEART
    //---------
    vector<vector<int> > edge_minweight_map(locus.size()-1);
    for (size_t i = 0; i < locus.size() - 1; ++i)
    {
      edge_minweight_map[i].assign(locus.size() - 1 - i, -1);
    }
    for(;;)
    {
      //solve master problem
      //--------------------
      approxSolver.solve();
      assert(approxSolver.getCplexStatus()==IloCplex::Optimal);
      //cout << "solved - SCORE: " << approxSolver.getObjValue() << endl;

      //adapt edge weight based on dual solution
      //----------------------------------------
      for (size_t i = 0; i < locus.size(); ++i)
      {
        int k = node_idx_map[i];
        seqan::property(edge_weights, edge_ids[s][i]) = (-approxSolver.getDual(covered[k]) * -l[k]) + (-approxSolver.getDual(covered[covers.size()+k]) * l[k]);
      }

      for (size_t i = 0; i + 1 < locus.size(); ++i)
      {
        for (size_t j = i + 1; j < locus.size(); ++j)
        {
          if (edge_idx_map[i][j-i-1].empty())
            continue;
          int k = edge_idx_map[i][j-i-1].front();
          double min_weight = (-approxSolver.getDual(covered[k]) * -l[k]) + (-approxSolver.getDual(covered[covers.size()+k]) * l[k]);
          if (covers[k].exons_1.size()>2)
          {
            for(size_t t = 1; t < covers[k].exons_1.size(); ++t)
            {
              int no_exon = exon_order[covers[k].exons_1[t]];
              if (t < covers[k].exons_1.size() - 1)
              {
                int k2 = node_idx_map[no_exon];
                min_weight +=  (-approxSolver.getDual(covered[k2]) * -l[k2]) + (-approxSolver.getDual(covered[covers.size()+k2]) * l[k2]);
              }
              int no_prevexon = exon_order[covers[k].exons_1[t-1]];
              int k_pair = -1;
              for (size_t kp = 0; kp < edge_idx_map[no_prevexon][no_exon-no_prevexon-1].size(); ++kp)
              {
                if (covers[edge_idx_map[no_prevexon][no_exon-no_prevexon-1][kp]].exons_1.size()==2)
                {
                  assert(exon_order[covers[edge_idx_map[no_prevexon][no_exon-no_prevexon-1][kp]].exons_1[0]]==no_prevexon);
                  assert(exon_order[covers[edge_idx_map[no_prevexon][no_exon-no_prevexon-1][kp]].exons_1[1]]==no_exon);
                  k_pair = edge_idx_map[no_prevexon][no_exon-no_prevexon-1][kp];
                  break;
                }
              }
              if(k_pair!=-1)
              {
                min_weight += (-approxSolver.getDual(covered[k_pair]) * -l[k_pair]) + (-approxSolver.getDual(covered[covers.size()+k_pair]) * l[k_pair]);
              }
            }
          }
          edge_minweight_map[i][j-i-1] = k;
          for (size_t t = 1; t < edge_idx_map[i][j-i-1].size(); ++t)
          {
            k = edge_idx_map[i][j-i-1][t];
            double e_weight = (-approxSolver.getDual(covered[k]) * -l[k]) + (-approxSolver.getDual(covered[covers.size()+k]) * l[k]);
            if(covers[k].exons_1.size() > 2)
            {
              for (size_t r = 1; r < covers[k].exons_1.size(); ++r)
              {
                int no_exon = exon_order[covers[k].exons_1[r]];
                if(r<covers[k].exons_1.size()-1)
                {
                  int k2 = node_idx_map[no_exon];
                  e_weight +=  (-approxSolver.getDual(covered[k2]) * -l[k2]) + (-approxSolver.getDual(covered[covers.size()+k2]) * l[k2]);
                }
                int no_prevexon = exon_order[covers[k].exons_1[r-1]];
                int k_pair = -1;
                for (size_t kp = 0; kp < edge_idx_map[no_prevexon][no_exon-no_prevexon-1].size(); ++kp) {
                  if(covers[edge_idx_map[no_prevexon][no_exon-no_prevexon-1][kp]].exons_1.size()==2)
                  {
                    assert(exon_order[covers[edge_idx_map[no_prevexon][no_exon-no_prevexon-1][kp]].exons_1[0]]==no_prevexon);
                    assert(exon_order[covers[edge_idx_map[no_prevexon][no_exon-no_prevexon-1][kp]].exons_1[1]]==no_exon);
                    k_pair = edge_idx_map[no_prevexon][no_exon-no_prevexon-1][kp];
                    break;
                  }
                }
                if(k_pair!=-1)
                {
                  e_weight += (-approxSolver.getDual(covered[k_pair]) * -l[k_pair]) + (-approxSolver.getDual(covered[covers.size()+k_pair]) * l[k_pair]);
                }
              }
            }
            if(e_weight<min_weight) {
              min_weight = e_weight;
              edge_minweight_map[i][j-i-1] = k;
            }
          }

          seqan::property(edge_weights, edge_ids[i+1][j - i - 1]) = seqan::property(edge_weights, edge_ids[s][j]) + min_weight;
        }
      }

      //compute longest path in transcript graph
      //----------------------------------------
      seqan::String<TVertexDescriptor> predMap;
      seqan::String<double> distMap;
      seqan::dagShortestPath(predMap, distMap, G, s, edge_weights);
      
      //std::cout.precision(10);
      //std::cout << -distMap[t] << std::endl;
      
      //if new transcript is not improving objective function we are done
      if(-distMap[t] < trans_coeff+1.0e-6)  {
    	  //cout << endl << "SCORE:  " << approxSolver.getObjValue() << endl;
    	  //cout << "rows: " << approxSolver.getNrows() << endl;
    	  break;
      }

      //derive from longest path transcript as new column to LP
      //-------------------------------------------------------
      IloNumColumn col = transUsed(trans_coeff);
      TVertexDescriptor _s = predMap[t];
      TVertexDescriptor succ = t;

      std::vector<bool> new_trans(locus.size(), false);
      while(_s!=s)
      {
        new_trans[_s - 1] = true;
        int k = node_idx_map[_s - 1];
        col += covered[k](-l[k]);
        col += covered[covers.size()+k](l[k]);

        if(succ!=t)
        {
          int i = _s - 1;
          int j = succ - 1;
          k = edge_minweight_map[i][j-i-1];
          col += covered[k](-l[k]);
          col += covered[covers.size()+k](l[k]);
          if(covers[k].exons_1.size()>2)
          {
            for (size_t t = 1; t < covers[k].exons_1.size(); ++t)
            {
              int no_exon = exon_order[covers[k].exons_1[t]];
              if (t < covers[k].exons_1.size() - 1)
              {
                new_trans[no_exon] = true;
                int k2 = node_idx_map[no_exon];
                col += covered[k2](-l[k2]);
                col += covered[covers.size()+k2](l[k2]);
              }
              int no_prevexon = exon_order[covers[k].exons_1[t-1]];
              int k_pair = -1;
              for (size_t kp = 0; kp < edge_idx_map[no_prevexon][no_exon-no_prevexon-1].size(); ++kp) {
                if(covers[edge_idx_map[no_prevexon][no_exon-no_prevexon-1][kp]].exons_1.size()==2)
                {
                  assert(exon_order[covers[edge_idx_map[no_prevexon][no_exon-no_prevexon-1][kp]].exons_1[0]]==no_prevexon);
                  assert(exon_order[covers[edge_idx_map[no_prevexon][no_exon-no_prevexon-1][kp]].exons_1[1]]==no_exon);
                  k_pair = edge_idx_map[no_prevexon][no_exon-no_prevexon-1][kp];
                  break;
                }
              }
              if(k_pair!=-1)
              {
                col += covered[k_pair](-l[k_pair]);
                col += covered[covers.size()+k_pair](l[k_pair]);
              }
            }
          }
        }
        succ = _s;
        _s = predMap[_s];
      }

/*
      for (size_t e = 0; e < locus.size(); e++)
        std::cout << new_trans[e] << " ";
      std::cout << std::endl;
*/

/*
      if(vars.size()>0)
        if(approxSolver.isExtracted(trans_intens[vars.size()-1]))
          std::cout << "value of new var: " << approxSolver.getValue(trans_intens[vars.size()-1]);
        else
          exit(1);
*/
      
      trans_intens.add(IloNumVar(col));
      col.end();
      vars.push_back(new_trans);
    } //end of THE HEART
    
    
    //interpret and store result
    //--------------------------
    Transcript tmp;
    tmp.nodes.reserve(locus.size());
    int next_id = 0;
    for(int j=0; j<trans_intens.getSize(); j++)
    {
      if(approxSolver.isExtracted(trans_intens[j]) && approxSolver.getValue(trans_intens[j])>0)
      {
    	//cout << "transcript:" << endl;
        for (size_t k = 0; k < locus.size(); k++) {
          if(vars[j][k]) {
        	  //cout << locus[k] << " ";
        	  tmp.nodes.push_back(locus[k]);
          }
        }
        //cout << endl;
        tmp.id = next_id;
        inferred_transcripts.push_back(tmp);
        computed_intens[next_id] = approxSolver.getValue(trans_intens[j]);

        tmp.nodes.clear();
        next_id++;
      }
    }
  }
  catch (IloException& ex)
  {
    cerr << "Error: " << ex << endl;
  }
  catch (...)
  {
    cerr << "Error" << endl;
  }

  env.end();
}



//the column generation method for de novo assembly
//takes into account pairing information of reads
//ignores single end reads
void colgen_pe(vector<Transcript>& inferred_transcripts, 
	           const vector<UInt>& locus,
               map<UInt, double>& computed_intens,
               const vector<SegmentCover>& covers_in,
               const TAllSegmentsMap& segments,
               UInt read_length,
               UInt insert_size,
               vector<Transcript>& init_sol)
{  

  //for balancing multi-objective
  const float trans_coeff = 50.;

  vector<SegmentCover> covers;
  for (size_t i = 0; i < covers_in.size(); ++i) {
	  if(!covers_in[i].exons_2.empty())
		  covers.push_back(covers_in[i]);
  }

  //search for all  exons (nodes in the splice graph) and junctions (edges in splice graph)
  //that are not part of some cover.
  //for all theses junctions we generate a node cover with intensity 0,
  //----------------------------------------------------------------------------------------
  std::set<pair<UInt, UInt> >abundant_junctions;
  std::set<UInt>abundant_singles;
  for(UInt i=0; i<covers.size(); ++i)
  {
    if(covers[i].exons_1.size()==1)
    {
      abundant_singles.insert(covers[i].exons_1.front());
    }

    for(UInt j=0; j<covers[i].exons_1.size()-1; ++j)
    {
      abundant_junctions.insert(make_pair(covers[i].exons_1[j], covers[i].exons_1[j+1]));
    }
    
    if(covers[i].exons_2.size()==1)
    {
      abundant_singles.insert(covers[i].exons_2.front());
    }
    
    for(UInt j=0; j<covers[i].exons_2.size()-1; ++j)
    {
      abundant_junctions.insert(make_pair(covers[i].exons_2[j], covers[i].exons_2[j+1]));
    }

  }

/*
  for(UInt i=0; i<locus.size()-1; ++i)
  {
    if(abundant_singles.find(locus[i])==abundant_singles.end())
    {
      SegmentCover tmp;
      tmp.exons_1.push_back(locus[i]);
      tmp.intensity=0.0;
      covers.push_back(tmp);
    }
    for(UInt j=i+1; j<locus.size(); ++j)
    {
      if(abundant_junctions.find(make_pair(locus[i], locus[j])) == abundant_junctions.end())
      {
        SegmentCover tmp;
        tmp.exons_1.push_back(locus[i]);
        tmp.exons_1.push_back(locus[j]);
        tmp.intensity=0.0;
        covers.push_back(tmp);
      }
    }
  }
  if(abundant_singles.find(locus[locus.size()-1])==abundant_singles.end())
  {
    SegmentCover tmp;
    tmp.exons_1.push_back(locus[locus.size()-1]);
    tmp.intensity=0.0;
    covers.push_back(tmp);
  }
*/

  //map exon to position in locus
  //-----------------------------
  map<int, int> exon_order;
  for (size_t i = 0; i < locus.size(); i++) {    
    exon_order[locus[i]] = i;
  }
  
  vector<std::vector<bool> > vars;
  
  IloEnv env;
  IloEnv env_prcg;
  try {
    IloNumArray cov(env);
    //IloNumArray l(env);
    
    for(size_t i = 0; i < covers.size(); ++i)
     cov.add(-1*covers[i].intensity);    
    for(size_t i = 0; i < covers.size(); ++i)
      cov.add(covers[i].intensity);
    /*
    for(size_t i = 0; i < covers.size(); ++i)
    {
      l.add(getCoverLength(covers[i], segments, read_length));
    }
    */
    IloModel approxCov(env);
    
    IloObjective transUsed = IloAdd(approxCov, IloMinimize(env));
    IloRangeArray covered = IloAdd(approxCov, IloRangeArray(env, cov, IloInfinity));
    
    IloNumVarArray error(env);
    IloNumVarArray trans_intens(env);
    
    //create columns for error vars
    //-----------------------------
    for (size_t i = 0; i < covers.size(); ++i)
    {
      double norm = max(1., covers[i].intensity);
      //float norm = max(0.1,covers[i].intensity);

      //error.add(IloNumVar(transUsed((1.-alpha)/((norm))) +  covered[i](1) + covered[covers.size()+i](1)));
      error.add(IloNumVar(transUsed((1.)/(sqrt(norm))) +  covered[i](1) + covered[covers.size()+i](1)));
    }

    //insert initially known transcripts
    //----------------------------------
	for(size_t s=0; s<init_sol.size(); ++s)
	{
/*
		cout << "transcript: " << endl;
		for(int t=0; t<init_sol[s].nodes.size(); ++t)
			cout << init_sol[s].nodes[t] << " ";
		cout << endl;
*/
		IloNumColumn col = transUsed(trans_coeff);
		std::vector<bool> new_trans(locus.size(), false);

		//determine coefficients for new column
		for(size_t i=0; i<covers.size(); i++)
		{/*
			cout << "left mate:" << endl;
			for(int t=0; t<covers[i].exons_1.size(); ++t)
				cout << covers[i].exons_1[t] << " ";
			cout << endl;
			cout << "right mate:" << endl;
			for(int t=0; t<covers[i].exons_2.size(); ++t)
				cout << covers[i].exons_2[t] << " ";
			cout << endl;
			*/
			//check whether transcript is consistent with cover
			vector<UInt>::const_iterator excov_it = covers[i].exons_1.begin();
			vector<UInt>::const_iterator extrans_it = init_sol[s].nodes.begin();
			while(*extrans_it < *excov_it) extrans_it++;
			bool is_consistent = true;
			for(; excov_it != covers[i].exons_1.end(); ++excov_it) {
				if(extrans_it == init_sol[s].nodes.end()) {
					is_consistent = false;
					break;
				}
				if(*excov_it != *extrans_it) {
					is_consistent = false;
					break;
				}
				extrans_it++;
			}
			if(!is_consistent) {
				continue;
			}
			excov_it = covers[i].exons_2.begin();
			extrans_it = init_sol[s].nodes.begin();
			while(*extrans_it < *excov_it) extrans_it++;
			for(; excov_it != covers[i].exons_2.end(); ++excov_it) {
				if(extrans_it == init_sol[s].nodes.end()) {
					is_consistent = false;
					break;
				}
				if(*excov_it != *extrans_it) {
					is_consistent = false;
					break;
				}
				extrans_it++;
			}
			if(!is_consistent) {
				continue;
			}
			//cout << "consistent" << endl;
			//here they must be consistent
			double ll = getNormFactor(covers[i], init_sol[s], segments);
			col += covered[i](-ll);
			col += covered[covers.size()+i](ll);
		}
		trans_intens.add(IloNumVar(col));
		col.end();

		vector<UInt>::const_iterator extrans_it = init_sol[s].nodes.begin();
		for(; extrans_it != init_sol[s].nodes.end(); ++ extrans_it)
			new_trans[exon_order[*extrans_it]] = true;
		vars.push_back(new_trans);
	}

    IloCplex approxSolver(approxCov);
    approxSolver.setOut(env.getNullStream());
    approxSolver.setParam(IloCplex::RootAlg, IloCplex::Primal);
    
    

    //construct pricing ILP
    //--------------------------
    IloModel model_prcg(env_prcg);

    //x-var denotes whether corresponding exon is contained in transcript
    IloBoolVarArray x(env_prcg, locus.size());
    for(int i=0; i<locus.size(); i++)
      x[i] = IloBoolVar(env_prcg);
    
    //for every cover introduce set of y variables
    IloArray<IloBoolVarArray> y(env_prcg, covers.size());
    vector<vector<vector<bool> > > y2exons(covers.size());
    IloExpr y_lb(env_prcg);
    for(int i=0; i<covers.size(); i++)      
    {
      enumGapExonSets(covers[i], segments, locus, y2exons[i]);      
      cout << "number of possibilities " << y2exons[i].size() << endl;
                  
      y[i] = IloBoolVarArray(env_prcg, max(1,(int)y2exons[i].size()));
      
      //at most one variable from each y family
      IloExpr sumofy(env_prcg);
      for(int j=0; j<max(1,(int)y2exons[i].size()); j++) {
    	  y[i][j] = IloBoolVar(env_prcg);
    	  sumofy += y[i][j];
      }
      model_prcg.add(sumofy<=1);
      sumofy.end();
 
      //connect y to x
      vector<UInt>::const_iterator low = lower_bound(locus.begin(), locus.end(), covers[i].exons_1.back());
      for(int j=0; j<max(1,(int)y2exons[i].size()); j++) {
    	  int cnt_overlap = 0;
    	  int tot_span = 0;
    	  y_lb.clear();
    	  std::vector<UInt>::const_iterator ex_it;
    	  vector<UInt>::const_iterator locus_it = lower_bound(locus.begin(), locus.end(), covers[i].exons_1.front());
    	  for(;locus_it!=locus.end() && *locus_it <= covers[i].exons_1.back(); locus_it++)
    	  {
    		  ex_it = find(covers[i].exons_1.begin(), covers[i].exons_1.end(), *locus_it);
    		  if(ex_it==covers[i].exons_1.end()) {
    			  y_lb += 1-x[ exon_order[*locus_it] ];
    			  model_prcg.add(y[i][j]<=1-x[ exon_order[*locus_it] ]);
    			  tot_span++;
    		  } else
    		  {
    			  y_lb += x[ exon_order[*ex_it] ];
    			  model_prcg.add(y[i][j]<=x[ exon_order[*ex_it] ]);
    			  tot_span++;
    		  }
    	  }
    	  locus_it = lower_bound(locus.begin(), locus.end(), covers[i].exons_2.front());
    	  for(;locus_it!=locus.end() && *locus_it <= covers[i].exons_2.back(); locus_it++)
    	  {
    		  if(*locus_it <= covers[i].exons_1.back()) {
    			  cnt_overlap++;
    			  continue;
    		  }
    		  ex_it = find(covers[i].exons_2.begin(), covers[i].exons_2.end(), *locus_it);
    		  if(ex_it==covers[i].exons_2.end()) {
    			  y_lb += 1-x[ exon_order[*locus_it] ];
    			  model_prcg.add(y[i][j]<=1-x[ exon_order[*locus_it] ]);
    			  tot_span++;
    		  } else
    		  {
    			  y_lb += x[ exon_order[*ex_it] ];
    			  model_prcg.add(y[i][j]<=x[ exon_order[*ex_it] ]);
    			  tot_span++;
    		  }
    	  }
    	  if(y2exons[i].size()>0) {
    		  for(int z=0; z<y2exons[i][j].size(); z++) {
    			  if(y2exons[i][j][z]) {
    				  y_lb += x[ exon_order[*(low+z+1)] ];
    				  model_prcg.add(y[i][j]<=x[ exon_order[*(low+z+1)] ]);
    			  }
    			  else {
    				  y_lb += 1 - x[ exon_order[*(low+z+1)] ];
    				  model_prcg.add(y[i][j]<=1-x[ exon_order[*(low+z+1)] ]);
    			  }
    		  }
    	  }
    	  if(y2exons[i].size()>0) {
    		  y_lb += 1 - (int)y2exons[i][0].size() - tot_span;
    	  }
    	  else {
    		  y_lb += 1 - tot_span;
    	  }
    	  model_prcg.add(y[i][j]>=y_lb);
      	  }
    	}
    	y_lb.end();

    	IloObjective obj_prcg = IloMinimize(env_prcg);
    	model_prcg.add(obj_prcg);
    	IloCplex cplex_prcg(model_prcg);
    	cplex_prcg.setParam(IloCplex::EpGap, 0.00001);
    	int iter_cnt = 0;
    
    	//THE HEART
    	//---------
    	for(;;)
    	{
    		iter_cnt++;
    		//solve master problem
    		//--------------------
    		approxSolver.solve();
    		assert(approxSolver.getCplexStatus()==IloCplex::Optimal);
    		cout<<endl<<"solved - SCORE:  "<<approxSolver.getObjValue()<<endl;
 
    		//adapt weight based on dual solution
    		for(size_t i=0; i<covers.size(); i++)
    		{
    			vector<UInt>::const_iterator low;
    			if(y2exons[i].size()>0)
    				low = lower_bound(locus.begin(), locus.end(), covers[i].exons_1.back());
    			for(int j=0; j<max(1,(int)y2exons[i].size()); j++)
    			{
    				Transcript tmp;
    				for(vector<UInt>::const_iterator ex_it = covers[i].exons_1.begin(); ex_it != covers[i].exons_1.end(); ex_it++) {
    					tmp.nodes.push_back(*ex_it);
    				}
    				if(y2exons[i].size()>0)
    				{
    					for(int z=0; z<y2exons[i][j].size(); z++)
    					{
    						if(y2exons[i][j][z]) {
    							tmp.nodes.push_back(*(low+z+1));
    						}
    					}
    				}
    				for(vector<UInt>::const_iterator ex_it = covers[i].exons_2.begin(); ex_it != covers[i].exons_2.end(); ex_it++)
    				{
    					if(*ex_it <= covers[i].exons_1.back())
    						continue;
    					tmp.nodes.push_back(*ex_it);
    				}
    				double ll = getNormFactor(covers[i], tmp, segments);
    				obj_prcg.setLinearCoef( y[i][j], (-approxSolver.getDual(covered[i]) * -ll) + (-approxSolver.getDual(covered[covers.size()+i]) * ll) );
    			}
    		}

    		//cplex_prcg.exportModel("test.lp");
      
    		//compute optimal solution to pricing ILP
    		if( !cplex_prcg.solve() ) {
    			env_prcg.error() << "Failed to optimize LP" << endl;
    			throw(-1);
    		}
      
    		//std::cout.precision(12);
    		//std::cout << -distMap[t]-100 << std::endl;
    		cout << cplex_prcg.getCplexStatus() << endl;
    		assert(cplex_prcg.getCplexStatus()==IloCplex::Optimal || cplex_prcg.getCplexStatus()==IloCplex::OptimalTol);
    		//assert(cplex_prcg.getCplexStatus()==IloCplex::Optimal);
    		cout << cplex_prcg.getObjValue() << endl;
      
    		//if new transcript is not improving objective function we are done
    		if(-1*cplex_prcg.getObjValue() < trans_coeff+1.0e-6)  {
    			cout<<endl<<"SCORE:  "<<approxSolver.getObjValue()<<endl;
    			//cout << "rows: " << approxSolver.getNrows() << endl<<endl;
    			break;
    		}


    		//derive from optimal ILP solution transcript as new column to LP
    		//-------------------------------------------------------
    		IloNumColumn col = transUsed(trans_coeff);
    		std::vector<bool> new_trans(locus.size(), false);
    		for(size_t i=0; i<covers.size(); i++)
    		{
    			vector<UInt>::const_iterator low;
    			if(y2exons[i].size()>0)
    				low = lower_bound(locus.begin(), locus.end(), covers[i].exons_1.back());
    			for(int j=0; j<max(1,(int)y2exons[i].size()); j++)
    			{
    				if((int)(cplex_prcg.getValue(y[i][j])+0.5)==1)
    				{
    					Transcript tmp;
    					for(vector<UInt>::const_iterator ex_it = covers[i].exons_1.begin(); ex_it != covers[i].exons_1.end(); ex_it++) {
    						tmp.nodes.push_back(*ex_it);
    						new_trans[exon_order[*ex_it]] = true;
    					}
    					if(y2exons[i].size()>0)
    					{
    						for(int z=0; z<y2exons[i][j].size(); z++)
    						{
    							if(y2exons[i][j][z]) {
    								tmp.nodes.push_back(*(low+z+1));
    								new_trans[exon_order[*(low+z+1)]] = true;
    							}
    						}
    					}
    					for(vector<UInt>::const_iterator ex_it = covers[i].exons_2.begin(); ex_it != covers[i].exons_2.end(); ex_it++)
    					{
    						if(*ex_it <= covers[i].exons_1.back())
    							continue;
    						tmp.nodes.push_back(*ex_it);
    						new_trans[exon_order[*ex_it]] = true;
    					}
    					double ll = getNormFactor(covers[i], tmp, segments);
    					col += covered[i](-ll);
    					col += covered[covers.size()+i](ll);
    					break;
    				}
    			}
    		}
      
    		trans_intens.add(IloNumVar(col));
    		col.end();
    		vars.push_back(new_trans);
      
    	} //end of THE HEART
    
    	cout << "column generation required " << iter_cnt << " iterations." << endl;
    
    	Transcript tmp;
    	tmp.nodes.reserve(locus.size());
    	int next_id = 0;
    	for(int j=0; j<trans_intens.getSize(); j++)
    	{
    		if(approxSolver.isExtracted(trans_intens[j]) && approxSolver.getValue(trans_intens[j])>0)
    		{
    			//cout << "transcript " << next_id << endl;
    			for (size_t k = 0; k < locus.size(); k++) {
    				if(vars[j][k]) {
    					tmp.nodes.push_back(locus[k]);
    					//cout << locus[k] << " ";
    				}
    			}
    			//cout << endl;
    			tmp.id = next_id;
    			inferred_transcripts.push_back(tmp);
    			computed_intens[next_id] = approxSolver.getValue(trans_intens[j]);

    			tmp.nodes.clear();
    			next_id++;
    		}
    	}

  }
  catch (IloException& ex)
  {
    cerr << "Error: " << ex << endl;
  }
  catch (...)
  {
    cerr << "Error" << endl;
  }
  
  env_prcg.end();
  env.end();
}

//the column generation method for de novo assembly
//takes into account pairing information of reads
//ignores single end reads
int colgen_pe_pwlin(vector<Transcript>& inferred_transcripts,
					vector<Transcript>& new_transcripts,
					const vector<UInt>& locus,
					map<UInt, double>& computed_intens,
					const vector<SegmentCover>& all_covers,
					const vector<UInt>& selected_cover_ids,
					vector<bool>& cov_expl_by_cand,
					const vector<SegmentCover>& fake_covers,
					const TAllSegmentsMap& segments,
					vector<Transcript>& init_sol,
					bool tss_tes,
					SpliceGraph& sg,
					const vector<pwQuadCoeff>& coeff_bp,
					const float lp_error,
					const std::map<UInt, std::set<UInt> > &legalBlockBounds)
{
	if (selected_cover_ids.size() == 0) {
		cout << "no covers selected." << endl;
		return 0;
	}

	std::vector<bool> cov_expl_by_opt(selected_cover_ids.size(), false);
	for(size_t i = 0; i < selected_cover_ids.size(); ++i)
	{
		for(long j = 0; j < init_sol.size(); ++j)
		{
			if(isCoverSupported(all_covers[selected_cover_ids[i]], vector<Transcript>(1,init_sol[j])))
			{
				float normf = getNormFactor(all_covers[selected_cover_ids[i]], init_sol[j], segments);
				if(normf > 0)
					cov_expl_by_opt[i] = true;
			}
		}
	}

	std::vector<bool>& cov_expl = Parameters::cov_expl_by_opt ? cov_expl_by_opt : cov_expl_by_cand;
  
  //avoid useless construction of master LP
  UInt totalUncov = 0;
  double sum = 0;
  for (size_t i = 0; i < cov_expl.size(); ++i)
  {
    if (!cov_expl[i])
    {
      double intens = all_covers[selected_cover_ids[i]].intensity;
      sum += intens;
      
      if (intens >= Parameters::unexpl_cov_bound)
      {
        ++totalUncov;
      }
    }
  }

  if(Parameters::unexpl_cov_sum_bound && sum < Parameters::unexpl_cov_sum_bound)
  {
    return 0;
  }
  else if (Parameters::unexpl_cov_bound && !totalUncov)
  {
    return 0;
  }

	/*
	cout << "covers not explained: " << endl;
	for(int i=0; i<selected_cover_ids.size(); i++)
		if(!cov_expl[i])
		{
			cout << i << endl;
			cout << "left mate:" << endl;
			for(int t=0; t<all_covers[selected_cover_ids[i]].exons_1.size(); ++t)
				cout << all_covers[selected_cover_ids[i]].exons_1[t] << " ";
			cout << endl;
			cout << "right mate:" << endl;
			for(int t=0; t<all_covers[selected_cover_ids[i]].exons_2.size(); ++t)
				cout << all_covers[selected_cover_ids[i]].exons_2[t] << " ";
			cout << endl;
		}
	 */

	vector<SegmentCover> covers;
	for(std::vector<UInt>::const_iterator iit = selected_cover_ids.begin(); iit != selected_cover_ids.end(); iit++)
		covers.push_back(all_covers[*iit]);

	for(std::vector<SegmentCover>::const_iterator fit = fake_covers.begin(); fit != fake_covers.end(); fit++)
		covers.push_back(*fit);


	//map exon to position in locus
	//-----------------------------
	map<int, int> exon_order;
	for (size_t i = 0; i < locus.size(); i++)
	{
		exon_order[locus[i]] = i;
	}

	vector<std::vector<bool> > vars;

	vector<UInt> tss;  //attention: tss is locus index, tes exon id!
	vector<UInt> tes;  //attention: tss is locus index, tes exon id!
	vector<vector<pair<UInt,UInt> > > exon_cluster;
	map<UInt, UInt> locid2exidx;
	vector<pair<UInt,UInt> > intron_retention;
	get_locus_structure(locus, segments, legalBlockBounds, tss, tes,  exon_cluster, locid2exidx, intron_retention);

/*
	//debug stuff
	cout << "intron retentions: " << endl;
	for(UInt i=0; i<intron_retention.size(); ++i)
		cout << locus[intron_retention[i].first] << " " << intron_retention[i].second << endl;
	for(UInt i=0; i<intret_exon_cluster.size(); ++i)
	{
		cout << "next cluster: " << endl;
		for(UInt j=0; j<intret_exon_cluster[i].size(); ++j)
			cout << locus[intret_exon_cluster[i][j].first] << " " << intret_exon_cluster[i][j].second << endl;
	}
	for(UInt i=0; i<locus.size(); i++)
	{
		if(locid2intretexidx.find(locus[i])==locid2intretexidx.end())
			cout << locus[i] << ": " << " - " << endl;
		else
			cout << locus[i] << ": " << locid2intretexidx.at(locus[i]) << endl;
	}
	//return;
*/

	IloEnv env;
	IloEnv env_prcg;
	int iter_cnt = 0;
	try
	{
		//prepare master lp
		//-----------------
		IloModel approxCov(env);
		pwLinApprox pwlin_apx;
		pwQuadApprox pwquad_apx(coeff_bp);

		//=========================================
		/*for(size_t i = 0; i < covers.size(); ++i)
		{
			pwquad_apx.set_d(max(1.,covers[i].intensity));
			cout << covers[i].intensity << endl;
			cout << "--------" << endl;
			for(size_t j = 0; j < pwquad_apx.getNofBp(); j++)
				cout << pwquad_apx.bp(j) << " " << pwquad_apx.f(j) << " " << pwquad_apx.df(j) << endl;
		}*/
		//=========================================

		IloObjective transUsed = IloAdd(approxCov, IloMinimize(env));

		IloNumArray cov(env);
		for(size_t i = 0; i < covers.size(); ++i) {
			IloNum cov_intens = covers[i].intensity;
			cov.add(cov_intens);
		}
		IloRangeArray covered = IloAdd(approxCov, IloRangeArray(env, cov, cov));

		//model piecwise-linear approximation constraints
		IloNumArray upenv(env);
		vector<size_t> acc_nof_bp;
		acc_nof_bp.resize(covers.size());
		for(size_t i = 0; i < covers.size(); ++i)
		{
			if(coeff_bp.empty()) {
				pwlin_apx.set_d(max(Parameters::pseudoCount, covers[i].intensity));
				acc_nof_bp[i] = (i==0) ? pwlin_apx.getNofBp() : acc_nof_bp[i-1] + pwlin_apx.getNofBp();
				for(size_t j = 0; j < pwlin_apx.getNofBp(); ++j)
					upenv.add( (pwlin_apx.df(j) * pwlin_apx.bp(j)) - pwlin_apx.f(j) );
			}
			else {
				pwquad_apx.set_d(max(Parameters::pseudoCount, covers[i].intensity));
				acc_nof_bp[i] = (i==0) ? pwquad_apx.getNofBp() : acc_nof_bp[i-1] + pwquad_apx.getNofBp();
				for(size_t j = 0; j < pwquad_apx.getNofBp(); ++j)
					upenv.add( (pwquad_apx.df(j) * pwquad_apx.bp(j)) - pwquad_apx.f(j) );
			}
//			cout << covers[i].intensity << endl;
//			cout << "--------" << endl;
//			for(size_t j = 0; j < pwlin_apx.getNofBp(); j++)
//				cout << pwlin_apx.bp(j) << " " << pwlin_apx.f(j) << endl;
		}
		IloRangeArray upper_env = IloAdd(approxCov, IloRangeArray(env, -IloInfinity, upenv));

		IloNumVarArray error(env);
		IloNumVarArray trans_intens(env);
		IloNumVarArray z(env);


		//create columns for error vars
		IloNumColumn err_col(env);
		for (size_t i = 0; i < covers.size(); ++i)
		{
			err_col.clear();
			err_col += covered[i](-1);
			if(coeff_bp.empty()) {
				pwlin_apx.set_d(max(Parameters::pseudoCount, covers[i].intensity));
				for(size_t j = 0; j < pwlin_apx.getNofBp(); ++j) {
					size_t idx = (i==0) ? j : acc_nof_bp[i-1] + j;
					err_col +=  upper_env[idx](pwlin_apx.df(j));
				}
			}
			else {
				pwquad_apx.set_d(max(Parameters::pseudoCount, covers[i].intensity));
				for(size_t j = 0; j < pwquad_apx.getNofBp(); ++j) {
					size_t idx = (i==0) ? j : acc_nof_bp[i-1] + j;
					err_col +=  upper_env[idx](pwquad_apx.df(j));
				}
			}
			error.add(IloNumVar(err_col, -IloInfinity, IloInfinity));
		}
		err_col.end();

		//piecewise-linear approximation in objective
		//idea: z >= df*e + f - df*bp
		//equivalent: -z + dfe <= -f + df*bp
		//rhs see upenv, and coefficients of vars z and error
		IloNumColumn z_col(env);
		for (size_t i = 0; i < covers.size(); ++i)
		{
			z_col.clear();
			z_col += transUsed(1);
			if(coeff_bp.empty()) {
				pwlin_apx.set_d(max(Parameters::pseudoCount,covers[i].intensity));
				for(size_t j = 0; j < pwlin_apx.getNofBp(); ++j) {
					size_t idx = (i==0) ? j : acc_nof_bp[i-1] + j;
					z_col += upper_env[idx](-1);
				}
			} else {
				pwquad_apx.set_d(max(Parameters::pseudoCount, covers[i].intensity));
				for(size_t j = 0; j < pwquad_apx.getNofBp(); ++j) {
					size_t idx = (i==0) ? j : acc_nof_bp[i-1] + j;
					z_col += upper_env[idx](-1);
				}
			}
			z.add(IloNumVar(z_col, 0.0, IloInfinity));
		}
		z_col.end();


		clock_t _start_y = clock();

		//construct pricing ILP
		//---------------------
		PriceIlp::Options options;
		options._maxUncovered = 1;
		//options._sgComp = false;
		PriceIlp::Data ilpData(locus, covers, cov_expl, sg, segments, legalBlockBounds,
							   //exon_cluster, locid2exidx,
							   intron_retention, exon_cluster, locid2exidx);
		PriceIlp* pIlp = new PriceIlp(ilpData, options);
		bool ilp_feasible = pIlp->init();

		clock_t _end_y = clock();

    if (Parameters::verbose)
      cout << "constructing y vars for pricing ILP took " << (double)(_end_y -_start_y) / CLOCKS_PER_SEC << endl;

        if (!pIlp->hasRelaxedEdges())
        {
          if (Parameters::verbose)
            std::cout << "Pricing ILP has no relaxed edges -- terminating!" << std::endl;
          
           return 0;
        }


		//vector<bool> cover_valid(covers.size(), true);
    	//insert initially known transcripts
    	//----------------------------------
		//init_sol.clear();
		for(size_t s=0; s<init_sol.size(); ++s)
		{
/*
			for(int j=0; j<init_sol[s].nodes.size(); ++j)
				cout << init_sol[s].nodes[j] << " ";
			cout << endl;
*/

			IloNumColumn col = transUsed(Parameters::theta);
			std::vector<bool> new_trans(locus.size(), false);
			//determine coefficients for new column
			for(size_t i=0; i<covers.size(); i++)
			{
				//cout << "cover " << i << endl;
				//cout << "===" << endl;

				if(!pIlp->getCoverValid()[i]) {
					continue;
				}

/*
				    				cout << "left mate:" << endl;
				    				for(int t=0; t<covers[i].exons_1.size(); ++t)
				    					cout << covers[i].exons_1[t] << " ";
				    				cout << endl;
				    				cout << "right mate:" << endl;
				    				for(int t=0; t<covers[i].exons_2.size(); ++t)
				    					cout << covers[i].exons_2[t] << " ";
				    				cout << endl;
*/

				//check whether transcript is consistent with cover
				vector<UInt>::const_iterator excov_it = covers[i].exons_1.begin();
				vector<UInt>::const_iterator extrans_it = init_sol[s].nodes.begin();
				while(extrans_it != init_sol[s].nodes.end() && *extrans_it < *excov_it) extrans_it++;
				if(extrans_it == init_sol[s].nodes.end())
					continue;
				//cout << *extrans_it << " " << *excov_it << endl;
				bool is_consistent = true;
				for(; excov_it != covers[i].exons_1.end(); ++excov_it)
				{
					if(extrans_it == init_sol[s].nodes.end()) {
						is_consistent = false;
						break;
					}
					if(*excov_it != *extrans_it) {
						is_consistent = false;
						break;
					}
					extrans_it++;
				}
				if(!is_consistent) {
					//cout << i << " 0" << endl;
					continue;
				}
				excov_it = covers[i].exons_2.begin();
				extrans_it = init_sol[s].nodes.begin();
				while(extrans_it != init_sol[s].nodes.end() && *extrans_it < *excov_it) extrans_it++;
				if(extrans_it == init_sol[s].nodes.end())
					continue;
				for(; excov_it != covers[i].exons_2.end(); ++excov_it)
				{
					if(extrans_it == init_sol[s].nodes.end()) {
						is_consistent = false;
						break;
					}
					if(*excov_it != *extrans_it) {
						is_consistent = false;
						break;
					}
					extrans_it++;
				}
				if(!is_consistent) {
					//cout << i << " 0" << endl;
					continue;
				}
				//at this point they must be consistent
				double ll = getNormFactor(covers[i], init_sol[s], segments);
				col += covered[i](ll);
				//cout << i << " " << ll << endl;
			}
			trans_intens.add(IloNumVar(col, 0.0, IloInfinity));
			col.end();
			vector<UInt>::const_iterator extrans_it = init_sol[s].nodes.begin();
			for(; extrans_it != init_sol[s].nodes.end(); ++extrans_it) {
				new_trans[exon_order[*extrans_it]] = true;
			}
			vars.push_back(new_trans);
		}

		//approxCov.add(trans_intens[0]==0.12904);
		//approxCov.add(trans_intens[1]==0.0222627);
		//approxCov.add(trans_intens[2]==3.01532);

		//if new loss function determine scaling factor for theta
		//compute score of initial lp solution with new scoring scheme
		//------------------------------------------------------------
		IloRangeArray fix_intens(env, init_sol.size());
		for(size_t s=0; s<init_sol.size(); ++s)
		{
			std::map<UInt, double>::const_iterator intens_it = computed_intens.find(init_sol[s].id);
			assert(intens_it != computed_intens.end());
			double intens =  computed_intens[intens_it->first];
			fix_intens.add(IloRange(env, intens, trans_intens[s], intens));
			transUsed.setLinearCoef(trans_intens[s], 0.);
		}
		IloRangeArray fixed_intens = IloAdd(approxCov, fix_intens);

		IloCplex approxSolver(approxCov);
		approxSolver.setOut(env.getNullStream());
		approxSolver.setParam(IloCplex::RootAlg, IloCplex::Primal);

		//cout << "nof rows: " << approxSolver.getNrows() << endl;

		approxSolver.solve();
		assert(approxSolver.getCplexStatus()==IloCplex::Optimal);
		double new_lp_error = approxSolver.getObjValue();

		assert(lp_error>0);
		double theta_scaling = new_lp_error/lp_error;
		//double theta_scaling = 1.0;
    
    if (Parameters::verbose)
      cout << "theta_scaling: " << theta_scaling << "(" << new_lp_error << "/" << lp_error << ")" << endl;
    
		for(size_t s=0; s<init_sol.size(); ++s)
		{
			transUsed.setLinearCoef(trans_intens[s], Parameters::theta*theta_scaling);
		}
		fixed_intens.endElements();

    	//------------------------------
    	seqan::String<TInterval> mate_intervals;
    	seqan::String<TInterval> insert_intervals;

    	vector<vector<vector<pair<UInt,UInt> > > > lmate;
    	vector<vector<vector<pair<UInt,UInt> > > > rmate;
    	lmate.resize(locus.size());
    	rmate.resize(locus.size());
    	for(size_t i = 0; i < locus.size(); i++) {
    		lmate[i].resize(locus.size()-i);
    		rmate[i].resize(locus.size()-i);
    	}

    	prepareGreedyPricing(locus, covers, legalBlockBounds, mate_intervals, insert_intervals, lmate, rmate);

    	TIntervalTree mate_tree(mate_intervals);
    	TIntervalTree insert_tree(insert_intervals);
    	//------------------------------

    	//THE HEART
    	//---------
    	for(;;)
    	{
    		iter_cnt++;

    		//solve master problem
    		//--------------------
    		clock_t _start_lp = clock();
    		approxSolver.solve();
    		clock_t _end_lp = clock();
        
        if (Parameters::verbose)
          cout << "solving master lp took " << (double)(_end_lp -_start_lp) / CLOCKS_PER_SEC << endl;

    		assert(approxSolver.getCplexStatus()==IloCplex::Optimal);

        if (Parameters::verbose)
          cout << endl << "solved master LP to optimality: - SCORE:  "<<approxSolver.getObjValue()<<endl;


        if (Parameters::verbose)
        {
          //debugging stuff
          cout << "errorsum: " << endl;
          double errorsum = 0.;
          for(int t = 0; t<selected_cover_ids.size(); t++)
            errorsum += approxSolver.getValue(z[t]);
          cout << errorsum << endl;
          cout << "---" << endl;
          double errorsum_fake = 0.;
          for(int t=selected_cover_ids.size(); t<covers.size(); t++) {
            //cout << approxSolver.getValue(z[t]) << endl;
            errorsum_fake += approxSolver.getValue(z[t]);
          }
          cout << errorsum_fake << endl;
          //cout << "---" << endl;
          //cout << covers.size() - selected_cover_ids.size() << endl;
          cout << "---" << endl;
          double totintens = 0.;
          for(int j=0; j<trans_intens.getSize(); j++)
            if(approxSolver.isExtracted(trans_intens[j]) && approxSolver.getValue(trans_intens[j])>0) {
              cout << approxSolver.getValue(trans_intens[j]) << endl;
              totintens += Parameters::theta*theta_scaling*approxSolver.getValue(trans_intens[j]);
            }
          cout << totintens << endl;
          cout << " --- " << endl;
          cout << errorsum + errorsum_fake + totintens << endl;
          //exit(0);

          cout << "lp_error: " << lp_error << endl;
        }



/*
    		//solve pricing
    		//-------------
    		clock_t _start_pricing = clock();
    		Transcript pricing_trans;
    		double reduced_cost = greedyPricing(locus, covers, segments, approxSolver, covered, legalBlockBounds, tss, tes, exon_cluster, locid2exidx, mate_tree, insert_tree, pricing_trans, lmate, rmate);
    		clock_t _end_pricing = clock();

    		cout << endl << "pricing done. reduced cost by greedy pricing: " << reduced_cost << endl << endl;
    		cout << "greedy pricing took " << (double)(_end_pricing - _start_pricing) / CLOCKS_PER_SEC << endl;
*/

    		/*
    		cout << "let's double check score" << endl;
    		double cost = 0;
    		for(UInt i=0; i<covers.size(); i++)
    		{
    			double nf = getNormFactor(covers[i], pricing_trans, segments);
    			cost += approxSolver.getDual(covered[i]) * nf;
    			cout << i << ": " << approxSolver.getDual(covered[i]) << " " << nf << endl;
    		}
    		cout << "my cost: " << cost << endl;
    		*/

//-------------------------
/*
    		//fix solution of pricing heuristic in pricing ILP - for score verification
    		IloRangeArray fix_heur_sol(env_prcg);
    		//cout << "array size: " << fix_heur_sol.getSize() << endl;
    		int next_idx = 0;
    		cout << "fixing solution in pricing ILP: " << endl;
    		for(size_t i=0; i<locus.size(); i++)
    		{
    			//cout << "i " << locus[i] << endl;
    			//if(next_idx < pricing_trans.nodes.size())
    				//cout << "next: " << pricing_trans.nodes[next_idx] << endl;
    			if(next_idx == pricing_trans.nodes.size()) {
    				//cout << "remaining" << endl;
    				fix_heur_sol.add(IloRange(env_prcg, 0, x[i], 0));
    				model_prcg.add(fix_heur_sol[i]);
    				continue;
    			}

    			if(locus[i] < pricing_trans.nodes[next_idx]) {
    				//cout << "0" << endl;
    				fix_heur_sol.add(IloRange(env_prcg, 0, x[i], 0));
    				model_prcg.add(fix_heur_sol[i]);
    			}
    			else if(locus[i] == pricing_trans.nodes[next_idx]) {
    				//cout << "1" << endl;
    				cout << locus[i] << " ";
    				fix_heur_sol.add(IloRange(env_prcg, 1, x[i], 1));
    				model_prcg.add(fix_heur_sol[i]);
    				next_idx++;
    			} else
    			{
    				cout << "fuck" << endl;
    				exit(0);
    			}
    		}
    		cout << endl;
*/
//--------------------------

    		if(!ilp_feasible)
    			break;

    		//adapt weight based on dual solution
    		IloNumArray duals(env);
    		approxSolver.getDuals(duals, covered);
    		pIlp->updateObjDual(duals);

    		//compute optimal solution to pricing ILP
    		if( !pIlp->solve() ) {
    			//in rare cases relaxed edges cannot explain any new cover
    			//saw one case of an illegal cover violating either tes or intron retention
    			//also lower bound on sum of intensities can cause infeasibility that is difficult to see in advance
    			if(Parameters::explainNewCover && pIlp->is_infeasible()) {
    				cerr << "ILP not feasible, probably because of explain new cover constraint" << endl;
    				break;
    			}
    			else
    				throw(-1);
    		}

    		//std::cout.precision(12);
    		//std::cout << -distMap[t]-100 << std::endl;
        if (Parameters::verbose)
          pIlp->printCplexStatus();
        
        if (Parameters::verbose)
          cout << "optimal score of new pricing ILP: " << pIlp->getObjValue() << endl;


//-----------------------------
/*
			//undo changes to pricing ILP and run again
    		for(size_t i=0; i<locus.size(); i++)
    		{
    			model_prcg.remove(fix_heur_sol[i]);
    			fix_heur_sol[i].end();
    		}

    		cout << endl << "now again.." << endl << endl;

    		if( !cplex_prcg.solve() ) {
    			env_prcg.error() << "Failed to optimize LP" << endl;
    			throw(-1);
    		}

    		//std::cout.precision(12);
    		//std::cout << -distMap[t]-100 << std::endl;
    		cout << cplex_prcg.getCplexStatus() << endl;
    		assert(cplex_prcg.getCplexStatus()==IloCplex::Optimal || cplex_prcg.getCplexStatus()==IloCplex::OptimalTol);
    		//assert(cplex_prcg.getCplexStatus()==IloCplex::Optimal);
    		cout << "optimal score of real pricing ILP: " << cplex_prcg.getObjValue() << endl;
    		if(-1*cplex_prcg.getObjValue() >= Parameters::theta+1.0e-6)  {
    			cout << "good one" << endl;
    		}
    		cout << "ILP pricing transcript: ";
    		for(int i=0; i<locus.size(); i++) {
    			if((int)(cplex_prcg.getValue(x[i])+0.5)==1)
    				cout << locus[i] << " ";
    		}
    		cout << endl;
    		if(tss_tes) {
    		    for(UInt i=0; i<locus.size(); i++) {
    		    	if((int)(cplex_prcg.getValue(s[i])+0.5)==1)
    		    		cout << "tss: " << locus[i] << endl;
    		    	if((int)(cplex_prcg.getValue(e[i])+0.5)==1)
    		    		cout << "tes: " << locus[i] << endl;
    		    }
    		}

    		cout << "using following y vars: " << endl;
    		for(size_t i=0; i<covers.size(); i++)
    		{
    			//for(int j=0; j<max(1,(int)y2exons[i].size()); j++)
    			for(int j=0; j<(int)y2exons[i].size(); j++)
    			{
    				if((int)(cplex_prcg.getValue(y[i][j])+0.5) == 1)
    					cout << i << "/" << j << ": " << endl;
    			}
    		}
*/
//-----------------------------


    		//if new transcript is not improving objective function we are done
    		if(-1*pIlp->getObjValue() < (Parameters::theta*theta_scaling)+1.0e-6)  {
    		//if(reduced_cost < Parameters::theta+1.0e-6)  {
          
          if (Parameters::verbose)
            cout << endl << "Did not find improving transcript. SCORE:  "<<approxSolver.getObjValue()<<endl;
    			//cout << "rows: " << approxSolver.getNrows() << endl<<endl;
    			break;
    		}

        if (Parameters::verbose)
        {
          std::cout << "X:" << std::endl;
          pIlp->printX();
        }

    		//derive from optimal ILP solution transcript as new column to LP
    		//---------------------------------------------------------------
    		IloNumColumn col = transUsed(Parameters::theta*theta_scaling);
    		std::vector<bool> new_trans(locus.size(), false);
    		vector<double> ll(covers.size());
    		pIlp->getNewTrans(new_trans, ll);
    		for(size_t i=0; i<covers.size(); i++)
    		{
    			if(ll[i]==-1) {
    				continue;
    			}
    			//cout << i << " " <<  ll[i] << endl;
    			col += covered[i](ll[i]);
    		}


/*
    		//derive from greedy solution transcript as new column to LP
    		//----------------------------------------------------------
    		IloNumColumn col = transUsed(Parameters::theta);
    		for(size_t i=0; i<covers.size(); i++)
    		{
    			if(!cover_valid[i]) {
    				continue;
    			}
    			double ll = getNormFactor(covers[i], pricing_trans, segments);
    			col += covered[i](ll);
    		}

    		cout << "added following transcript to LP: " << endl;
    		std::vector<bool> new_trans(locus.size(), false);
    		for(vector<UInt>::const_iterator node_it = pricing_trans.nodes.begin(); node_it != pricing_trans.nodes.end(); node_it++) {
    			new_trans[exon_order[*node_it]] = true;
    			cout << *node_it << " ";
    		}
    		cout << endl;
*/

    		trans_intens.add(IloNumVar(col, 0.0, IloInfinity));
    		col.end();
    		vars.push_back(new_trans);

    		if(Parameters::greedy_expl_uncov)
    		{
    			//update set of explained covers
    			Transcript tmp;
    			tmp.nodes.reserve(locus.size());
    			for (size_t k = 0; k < locus.size(); k++) {
    				if(new_trans[k]) {
    					tmp.nodes.push_back(locus[k]);
    				}
    			}
    			//std::vector<int> explained;
    			for(size_t i = 0; i < selected_cover_ids.size(); ++i)
    			{
    				if(!cov_expl[i])
    				{
              if (Parameters::verbose)
                cout << " check: " << i << endl;
              
    					if(isCoverSupported(covers[i], vector<Transcript>(1,tmp)))
    					{
    						float normf = getNormFactor(covers[i], tmp, segments);
    						if(normf > 0) {
    							//explained.push_back(i);
    							cov_expl[i] = true;
                  
                  if (Parameters::verbose)
                    cout << " newly explained: " << i << endl;
    						}
    					}
    				}
    			}
    			if(Parameters::explainNewCover)
    				ilp_feasible = pIlp->updateNewCover();
    			ilp_feasible = ilp_feasible && pIlp->updateSgComp();
    		}
    	} //end of THE HEART

      if (Parameters::verbose)
        cout << "column generation required " << iter_cnt << " iterations." << endl;


/*
    	for(int k=0; k<covers.size(); ++k) {
    		for(IloExpr::LinearIterator it = IloExpr(covered[k].getExpr()).getLinearIterator(); it.ok(); ++it)
    			if(approxSolver.isExtracted(it.getVar()) && approxSolver.getValue(it.getVar())>0) {
    				cout << it.getCoef() << " ";
    			}
    		cout << endl;
    	}
*/

    	//format final result properly
    	if(iter_cnt > 1) {  //if column generation did not find any transcript keep lp solution
    		computed_intens.clear();
    		Transcript tmp;
    		tmp.nodes.reserve(locus.size());
    		int next_id = 0;
    		for(int j=0; j<trans_intens.getSize(); j++)
    		{
    			if(approxSolver.isExtracted(trans_intens[j]) && approxSolver.getValue(trans_intens[j])>0)
    			{
    				//cout << " yes " << endl;
    				//cout << "transcript " << next_id << endl;
    				for (size_t k = 0; k < locus.size(); k++) {
    					if(vars[j][k]) {
    						tmp.nodes.push_back(locus[k]);
    						//cout << locus[k] << " ";
    					}
    				}
    				//cout << endl;
    				tmp.id = next_id;
    				inferred_transcripts.push_back(tmp);
    				computed_intens[next_id] = approxSolver.getValue(trans_intens[j]);

    				tmp.nodes.clear();
    				next_id++;
    			} //else
    				//cout << " no " << endl;
    		}

    		//collect all newly found transcripts
    		assert(vars.size()>init_sol.size());
    		next_id = init_sol.size();
    		for(int j=init_sol.size(); j<vars.size(); j++)
    		{
    			tmp.nodes.clear();
    			for (size_t k = 0; k < locus.size(); k++) {
    				if(vars[j][k])
    					tmp.nodes.push_back(locus[k]);
    			}
    			tmp.id = next_id;
    			tmp.regWeight = Parameters::cg_regWeight;
    			new_transcripts.push_back(tmp);
    			next_id++;
    		}
    	}

  }
  catch (IloException& ex)
  {
    cerr << "Error: " << ex << endl;
  }
  catch (...)
  {
    cerr << "Error" << endl;
  }

  env_prcg.end();
  env.end();

  return iter_cnt;
}

//attention: tss is index, tes is locus id
void get_locus_structure(const vector<UInt>& locus, const TAllSegmentsMap& segments, const std::map<UInt, std::set<UInt> > &legalBlockBounds,
						 vector<UInt>& tss, vector<UInt>& tes, vector<vector<pair<UInt,UInt> > >& exon_cluster, map<UInt, UInt>& locid2exidx,
						 vector<pair<UInt,UInt> >& intron_retentions)
{
	//collect structure of locus (tss, tes)
	//-------------------------------------
	std::set<UInt> tes_uniq;
	for(UInt i=0; i<locus.size(); i++)
	{
		std::map<UInt, std::set<UInt> >::const_iterator entryIt = legalBlockBounds.find(locus[i]);
		if(entryIt != legalBlockBounds.end())
		{
			if(segments[locus[i]].tss)
      {
        if (Parameters::verbose)
          cout << "found tss: " << locus[i] << endl;
				tss.push_back(i);
			}

			for(std::set<UInt>::const_iterator exitIt = entryIt->second.begin(); exitIt != entryIt->second.end(); ++exitIt)
				if(segments[*exitIt].tes)
        {
          if (Parameters::verbose)
            cout << "found tes: " << *exitIt << endl;
					tes_uniq.insert(*exitIt);
				}
		}
	}

	for(std::set<UInt>::iterator tes_it = tes_uniq.begin(); tes_it != tes_uniq.end(); tes_it++)
		tes.push_back(*tes_it);
	std::sort(tes.begin(), tes.end());


	//cluster structure taking into account intron retentions
	map<int, int> exon_order;
	for (size_t i = 0; i < locus.size(); i++)
	{
		exon_order[locus[i]] = i;
	}

	vector<pair<float,interval*> > exon_bounds;
	for(UInt i=0; i<locus.size(); i++)
	{
		std::map<UInt, std::set<UInt> >::const_iterator entryIt = legalBlockBounds.find(locus[i]);
		if(entryIt != legalBlockBounds.end())
		{
			for(std::set<UInt>::const_iterator exitIt = entryIt->second.begin(); exitIt != entryIt->second.end(); ++exitIt)
			{
				interval* I = new interval(i,exitIt,-1);
				//cout << "push back start: " << i << endl;
				exon_bounds.push_back(pair<float,interval*>(i,I));
				UInt exidx = exon_order[*exitIt];
				if(exidx < locus.size()-1 && segments[locus[exidx+1]].beginPos==segments[locus[exidx]].endPos) { //treat touching as overlapping
					exon_bounds.push_back(pair<float,interval*>(exon_order[*exitIt]+1.5,I));
					//cout << "push back end: " << exon_order[*exitIt]+1.5 << endl;
				}
				else {
					exon_bounds.push_back(pair<float,interval*>(exon_order[*exitIt]+0.5,I));
					//cout << "push back end: " << exon_order[*exitIt]+0.5 << endl;
				}
			}
		}
	}


	//Phase 1
	sort(exon_bounds.begin(),exon_bounds.end());
	set<interval*> active_ints;
	set<interval*> int_rets;
	for(UInt j=0; j<exon_bounds.size(); ++j)
	{
		if((int)(exon_bounds[j].first+0.7)==(int)(exon_bounds[j].first)) {// left boundary
			set<interval*>::const_iterator actIt = active_ints.begin();
			for(;actIt != active_ints.end(); ++actIt)
			{
				if((*actIt)->closed_within != -1 && (int)(exon_bounds[j].first)-(*actIt)->closed_within > 1)
        {
          if (Parameters::verbose)
          {
            cout << "found intron retention - really" << endl;
            cout << locus[(*actIt)->start_coord] << " " << *((*actIt)->exitIt) << endl;
          }
					int_rets.insert(*actIt);
				}
			}
			active_ints.insert(exon_bounds[j].second);
		} else //right boundary
		{
			set<interval*>::const_iterator to_remove;
			set<interval*>::const_iterator actIt = active_ints.begin();
			for(;actIt != active_ints.end(); ++actIt)
			{
				if(*actIt==exon_bounds[j].second)
					to_remove = actIt;
				else if((*actIt)->closed_within == -1) {//no other interval closed so far within this interval
					//(*actIt)->closed_within = (int)(exon_bounds[j].first);
					//cout << "closing right boundary: " << exon_order[*(exon_bounds[j].second->exitIt)] << endl;
					(*actIt)->closed_within = exon_order[*(exon_bounds[j].second->exitIt)]; //cannot take simply .first since modified during push_back
				}
			}
			active_ints.erase(to_remove);
		}
	}
	assert(active_ints.empty());
	set<interval*>::const_iterator intret_it = int_rets.begin();
	for(;intret_it != int_rets.end(); ++intret_it)
		intron_retentions.push_back(pair<UInt,UInt>((*intret_it)->start_coord,*((*intret_it)->exitIt)));

	//Phase 2
	int cluster_idx = -1;
	int min_right_boundary = -1;
	for(UInt j=0; j<exon_bounds.size(); ++j)
	{
		if(int_rets.find(exon_bounds[j].second)!=int_rets.end())
			continue;
		if((int)(exon_bounds[j].first+0.7)==(int)(exon_bounds[j].first)) //left boundary
		{
			//cout << "next one: " << locus[exon_bounds[j].second->start_coord] << " " <<  *(exon_bounds[j].second->exitIt) << endl;
			if(active_ints.empty()) {
				active_ints.insert(exon_bounds[j].second);
				min_right_boundary = exon_order[*(exon_bounds[j].second->exitIt)];
			} else if ( exon_bounds[j].second->start_coord <= min_right_boundary ||
					  	(exon_bounds[j].second->start_coord == min_right_boundary+1 &&
					  	 segments[locus[exon_bounds[j].second->start_coord]].beginPos == segments[locus[min_right_boundary]].endPos)
					  )
			{
				active_ints.insert(exon_bounds[j].second);
				min_right_boundary = min(min_right_boundary, exon_order[*(exon_bounds[j].second->exitIt)]);
			} else
			{
        if (Parameters::verbose)
          cout << "exon cluster:" << endl;
				exon_cluster.push_back(vector<pair<UInt,UInt> >());
				cluster_idx++;
				UInt leftmost = locus.size();
				UInt rightmost = locus.size();
				set<interval*>::const_iterator actIt = active_ints.begin();
				for(;actIt != active_ints.end(); ++actIt)
				{
          if (Parameters::verbose)
            cout << locus[(*actIt)->start_coord] << " " << *((*actIt)->exitIt) << endl;
					exon_cluster[cluster_idx].push_back( pair<UInt,UInt>( (*actIt)->start_coord, *((*actIt)->exitIt) ) );
					if(leftmost == locus.size() || (*actIt)->start_coord < leftmost)
						leftmost = (*actIt)->start_coord;
					if(rightmost == locus.size() || exon_order[*((*actIt)->exitIt)] > rightmost)
						rightmost = exon_order[*((*actIt)->exitIt)];
					//active_ints.erase(*actIt);
				}
				active_ints.clear();
				for(UInt k=leftmost; k<rightmost+1; ++k)
					locid2exidx[locus[k]]=cluster_idx;
				active_ints.insert(exon_bounds[j].second);
				min_right_boundary = exon_order[*(exon_bounds[j].second->exitIt)];
			}
		}
	}
	if(!active_ints.empty())
	{
    if (Parameters::verbose)
      cout << "exon cluster:" << endl;
		exon_cluster.push_back(vector<pair<UInt,UInt> >());
		cluster_idx++;
		UInt leftmost = locus.size();
		UInt rightmost = locus.size();
		set<interval*>::const_iterator actIt = active_ints.begin();
		for(;actIt != active_ints.end(); ++actIt)
		{
      if (Parameters::verbose)
        cout << locus[(*actIt)->start_coord] << " " << *((*actIt)->exitIt) << endl;
			exon_cluster[cluster_idx].push_back( pair<UInt,UInt>( (*actIt)->start_coord, *((*actIt)->exitIt ) ) );
			if(leftmost == locus.size() || (*actIt)->start_coord < leftmost)
				leftmost = (*actIt)->start_coord;
			if(rightmost == locus.size() || exon_order[*((*actIt)->exitIt)] > rightmost)
				rightmost = exon_order[*((*actIt)->exitIt)];
			//active_ints.erase(*actIt);
		}
		active_ints.clear();
		for(UInt k=leftmost; k<rightmost+1; ++k)
			locid2exidx[locus[k]]=cluster_idx;
	}
	for(UInt j=0; j<exon_bounds.size(); ++j)
	{
		if((int)(exon_bounds[j].first+0.7)==(int)(exon_bounds[j].first)) { //left boundary
			delete exon_bounds[j].second;
		}
	}

}


void prepareGreedyPricing(const vector<UInt>& locus, const vector<SegmentCover>& selected_covers,									  //in
						  const std::map<UInt, std::set<UInt> > &legalBlockBounds,													  //in
						  seqan::String<TInterval>& mate_intervals, seqan::String<TInterval>& insert_intervals,                       //out
						  vector<vector<vector<pair<UInt,UInt> > > >& lmate, vector<vector<vector<pair<UInt,UInt> > > >& rmate) 	  //out
{



/*
  	//organize covers in interval trees
	for(UInt i = 0; i < selected_covers.size(); i++)
	{
		appendValue( mate_intervals, TInterval(selected_covers[i].exons_1.front(), selected_covers[i].exons_1.back()+1, i) );
		if( selected_covers[i].exons_2.front() != selected_covers[i].exons_1.front() ||
				selected_covers[i].exons_2.back() != selected_covers[i].exons_1.back() )
		{
			appendValue( mate_intervals, TInterval(selected_covers[i].exons_2.front(), selected_covers[i].exons_2.back()+1, i) );
		}

		if(selected_covers[i].exons_1.back() < selected_covers[i].exons_2.front())
		{
			vector<UInt>::const_iterator insert_left = lower_bound( locus.begin(), locus.end(), selected_covers[i].exons_1.back() );
			vector<UInt>::const_iterator insert_right = lower_bound( locus.begin(), locus.end(), selected_covers[i].exons_2.front() );
			insert_left++;
			insert_right--;
			if(*insert_left <= *insert_right)
			{
				appendValue( insert_intervals, TInterval(*insert_left, (*insert_right)+1, i) );
			}
		}
	}
*/

	//try new data structure
	map<int, int> exon_order;
	for(size_t i = 0; i < locus.size(); i++) {
		exon_order[locus[i]] = i;
	}

	for(UInt i = 0; i < selected_covers.size(); i++)
	{
/*
		cout << "i: " << i << endl;
		cout << "left mate:" << endl;
		for(int t=0; t<selected_covers[i].exons_1.size(); ++t)
			cout << selected_covers[i].exons_1[t] << " ";
		cout << endl;
		cout << "right mate:" << endl;
		for(int t=0; t<selected_covers[i].exons_2.size(); ++t)
			cout << selected_covers[i].exons_2[t] << " ";
		cout << endl;
*/

		if(selected_covers[i].exons_1.size() == 1)
		{
			int lmate_idx_x = exon_order[selected_covers[i].exons_1.front()];
			int lmate_idx_y = 0;
			lmate[lmate_idx_x][lmate_idx_y].push_back( pair<UInt,UInt>(selected_covers[i].exons_2.front(),i) );\
			//cout << "inserted single left in " << lmate_idx_x << " " << lmate_idx_y << endl;
		} else
		{
			for (UInt j=1; j<selected_covers[i].exons_1.size(); ++j)
			{
				int lmate_idx_x = exon_order[selected_covers[i].exons_1[j-1]];
				int lmate_idx_y = exon_order[selected_covers[i].exons_1[j]] - lmate_idx_x;
				lmate[lmate_idx_x][lmate_idx_y].push_back( pair<UInt,UInt>(selected_covers[i].exons_2.front(),i) );
				//cout << "inserted junction left in " << lmate_idx_x << " " << lmate_idx_y << endl;
			}
		}
		if(selected_covers[i].exons_2.size() == 1)
		{
			int rmate_idx_x = exon_order[selected_covers[i].exons_2.front()];
			int rmate_idx_y = 0;
			rmate[rmate_idx_x][rmate_idx_y].push_back( pair<UInt,UInt>(selected_covers[i].exons_1.back(),i) );
			//cout << "inserted single right in " << rmate_idx_x << " " << rmate_idx_y << endl;
		} else
		{
			for (UInt j=1; j<selected_covers[i].exons_2.size(); ++j)
			{
				int rmate_idx_x = exon_order[selected_covers[i].exons_2[j-1]];
				int rmate_idx_y = exon_order[selected_covers[i].exons_2[j]] - rmate_idx_x;
				rmate[rmate_idx_x][rmate_idx_y].push_back( pair<UInt,UInt>(selected_covers[i].exons_1.back(),i) );
				//cout << "inserted junction right in " << rmate_idx_x << " " << rmate_idx_y << endl;
			}
		}
	}
	for(size_t i = 0; i < locus.size(); i++)
	{
		for(size_t j=0; j<locus.size()-1-i; j++)
		{
			std::sort(lmate[i][j].begin(), lmate[i][j].end());
			std::sort(rmate[i][j].begin(), rmate[i][j].end());
		}
	}
}

double greedyPricing(const vector<UInt>& locus, const vector<SegmentCover>& selected_covers, const TAllSegmentsMap& segments,
		             const IloCplex& approxSolver, IloRangeArray& covered, const std::map<UInt, std::set<UInt> > &legalBlockBounds,
		             const vector<UInt>& tss, const vector<UInt>& tes, const vector<vector<UInt> >& exon_cluster, const map<UInt, UInt>& locid2exidx,
		             const TIntervalTree& mate_tree, const TIntervalTree& insert_tree, Transcript& result_trans,
		             const vector<vector<vector<pair<UInt,UInt> > > >& lmate, const vector<vector<vector<pair<UInt,UInt> > > >& rmate)
{
	double best_reduced_cost;
	vector<pair<UInt,UInt> > best_meta_trans;
	vector<bool> best_ex_skip;

	vector<UInt>::const_iterator tss_it = tss.begin();
	for(; tss_it!=tss.end(); tss_it++)
	{
		vector<UInt>::const_iterator tes_it = tes.begin();
		for(; tes_it!=tes.end(); tes_it++)
		{
			if(*tes_it < locus[*tss_it])
				continue;

			cout << "tss: " << locus[*tss_it] << " - tes: " << *tes_it << endl;

			double time_total = 0;
			double time_init = 0;
			double time_for = 0;
			double time_imprv_exskip = 0;
			double time_imprv_altss = 0;
			double time_for_template = 0;
			double time_for_cover = 0;
			double time_for_redcost = 0;

			clock_t start_total = clock();
			clock_t start_init = clock();

			//create full template transcript with best exon in each cluster from tss to tes
			//------------------------------------------------------------------------------
			Transcript template_trans;
			vector<pair<UInt, UInt> > meta_trans; //contains for every cluster exon boundaries/idx
			vector<bool> ex_skipped;
			bool tss_tes_incons = false;
			for(UInt cluster_idx = locid2exidx.at(locus[*tss_it]); cluster_idx <= locid2exidx.at(*tes_it); cluster_idx++)
			{
				//if single candidate exon add it to transcript
				if(exon_cluster[cluster_idx].size()==1)
				{
					std::map<UInt, std::set<UInt> >::const_iterator entryIt = legalBlockBounds.find( locus[exon_cluster[cluster_idx][0]] );
					assert(entryIt != legalBlockBounds.end());
					if(entryIt->second.size()==1)
					{
						meta_trans.push_back( make_pair( exon_cluster[cluster_idx][0], *(entryIt->second.begin()) ) );
						ex_skipped.push_back(false);
						for(UInt i=exon_cluster[cluster_idx][0]; i<locus.size() && locus[i]<=*(entryIt->second.begin()); i++) {
							//cout << "adding node " << locus[i] << endl;
							template_trans.nodes.push_back(locus[i]);
						}
						continue;
					}
				}

				//pick one with highest potential among multiple candidate exons
				//cout << "multiple candidates" << endl;
				double best_score;
				UInt best_l_bound_idx;
				UInt best_r_bound;
				bool first_iter = true;
				for(UInt j=0; j<exon_cluster[cluster_idx].size(); j++)
				{
					//in first cluster we have to be consistent with tss
					if(cluster_idx == locid2exidx.at(locus[*tss_it]) && locus[exon_cluster[cluster_idx][j]] != locus[*tss_it])
						continue;

					std::map<UInt, std::set<UInt> >::const_iterator entryIt = legalBlockBounds.find( locus[exon_cluster[cluster_idx][j]] );
					assert(entryIt != legalBlockBounds.end());
					for(std::set<UInt>::const_iterator exitIt = entryIt->second.begin(); exitIt != entryIt->second.end(); ++exitIt)
					{
						//in last cluster we have to be consistent with tes
						if(cluster_idx == locid2exidx.at(*tes_it) && *exitIt != *tes_it)
							continue;

						seqan::String<UInt> overlap_mates;
						UInt query_l = locus[exon_cluster[cluster_idx][j]];
						UInt query_r = (*exitIt)+1;
						findIntervals(mate_tree, query_l, query_r, overlap_mates);
						std::set<UInt> overlap_mates_uniq;
						for(UInt i = 0; i < length(overlap_mates); ++i)
							overlap_mates_uniq.insert(overlap_mates[i]);
						//cout << "exon: " << query_l << " " << query_r-1 << endl;
						double score = 0;
						for(std::set<UInt>::const_iterator ov_it = overlap_mates_uniq.begin(); ov_it != overlap_mates_uniq.end(); ++ov_it)
						{
							bool lmate_compatible = is_mate_compatible(selected_covers[*ov_it].exons_1, query_l, query_r-1, cluster_idx, locid2exidx, locus);
							bool rmate_compatible = is_mate_compatible(selected_covers[*ov_it].exons_2, query_l, query_r-1, cluster_idx, locid2exidx, locus);

							/*
											//debug stuff
											cout << "left mate:" << endl;
											for(vector<UInt>::const_iterator mate_it = selected_covers[*ov_it].exons_1.begin(); mate_it != selected_covers[*ov_it].exons_1.end(); mate_it++)
											{
												cout << *mate_it << " ( " << segments.find(*mate_it)->second.length << ") - ";
											}
											cout << endl;
											if(lmate_compatible)
												cout << "compatible" << endl;
											else
												cout << "not compatible" << endl;
											cout << "right mate:" << endl;
											for(vector<UInt>::const_iterator mate_it = selected_covers[*ov_it].exons_2.begin(); mate_it != selected_covers[*ov_it].exons_2.end(); mate_it++)
											{
												cout << *mate_it << " ( " << segments.find(*mate_it)->second.length << ") - ";
											}
											cout << endl;
											if(rmate_compatible)
												cout << "compatible" << endl;
											else
												cout << "not compatible" << endl;
							 */

							if(lmate_compatible || rmate_compatible)
							{
								pair<int, int> pos_l, pos_r;
								Transcript t_mate;
								vector<UInt>::const_iterator mate_it = selected_covers[*ov_it].exons_1.begin();
								for(; mate_it != selected_covers[*ov_it].exons_1.end(); mate_it++)
									t_mate.nodes.push_back(*mate_it);
								computeSingleRange(selected_covers[*ov_it].exons_1, t_mate, segments, Parameters::read_length_global, pos_l);
								int space_left = pos_l.second - pos_l.first + 1;

								t_mate.nodes.clear();
								mate_it = selected_covers[*ov_it].exons_2.begin();
								for(; mate_it != selected_covers[*ov_it].exons_2.end(); mate_it++)
									t_mate.nodes.push_back(*mate_it);
								computeSingleRange(selected_covers[*ov_it].exons_2, t_mate, segments, Parameters::read_length_global, pos_r);
								int space_right = pos_r.second - pos_r.first + 1;

								int norm_local = max(0, min(space_left, space_right));

								score += approxSolver.getDual(covered[*ov_it]) * norm_local;
							}
						}
						//cout << "score: " << score << endl;
						if( first_iter || score > best_score)
						{
							best_score = score;
							best_l_bound_idx = exon_cluster[cluster_idx][j];
							best_r_bound = query_r-1;
							first_iter = false;
						}
					}
				}
				if(first_iter == true) { //couldn't pick one, because for example no exon satisfying tss and tes simultaneously
					tss_tes_incons = true;
					break;
				}
				assert(meta_trans.size() == cluster_idx-locid2exidx.at(locus[*tss_it]));
				meta_trans.push_back(make_pair(best_l_bound_idx, best_r_bound));
				//cout << "pushed back " << locus[best_l_bound_idx] << " "  << best_r_bound << endl;
				ex_skipped.push_back(false);
				for(UInt i=best_l_bound_idx; i<locus.size() && locus[i]<=best_r_bound; i++)
				{
					//cout << "adding node " << locus[i] << endl;
					template_trans.nodes.push_back(locus[i]);
				}
			}
			if(tss_tes_incons)
				continue;
			assert(meta_trans.size() == locid2exidx.at(*tes_it)-locid2exidx.at(locus[*tss_it])+1);
//			cout << endl << "starting from pre-mRNA: ";
//			for(UInt i=0; i<meta_trans.size(); i++)
//				cout << "[" << locus[meta_trans[i].first] << "-" << meta_trans[i].second << "] ";
//			cout << endl;

			//compute norm factor of each cover in current template transcript
			map<UInt, double> normfs;
			double reduced_cost = 0;
			for(UInt i=0; i<selected_covers.size(); i++)
			{
				double nf = getNormFactor(selected_covers[i], template_trans, segments);
				normfs.insert(std::pair<UInt, double>(i,nf));
				reduced_cost += approxSolver.getDual(covered[i]) * nf;
			}

			clock_t end_init = clock();
			time_init = double(end_init- start_init);

			clock_t start_for = clock();
			for(;;)
			{
//				cout << "checking for best exon to skip." << endl;

				clock_t start_imprv_exskip = clock();
				//compute potential improvement of every (single) exon skipping event and pick best (greedy)
				double highest_imprv;
				UInt best_exskip = meta_trans.size(); //marks not initialized
				map<UInt, double> new_normfs_4best;

				find_best_exskip(locus, selected_covers, segments, approxSolver, covered, meta_trans, ex_skipped,
						         normfs, lmate, rmate, highest_imprv, best_exskip, new_normfs_4best);

				clock_t end_imprv_exskip = clock();
				time_imprv_exskip += double(end_imprv_exskip-start_imprv_exskip);

//				cout << "checking for alternative splice site." << endl;
				clock_t start_imprv_altss = clock();

				double highest_exswap_imprv;
				UInt best_exswap_cluster = locid2exidx.at(*tes_it) + 1;//marks not initialized;
				UInt best_exswap_entry_idx;
				UInt best_exswap_exit;
				map<UInt, double> new_normfs_4best_ass;

				find_best_ass(locus, selected_covers, segments, locid2exidx, ex_skipped, exon_cluster, tss_it, tes_it, lmate, rmate,
						legalBlockBounds, meta_trans, normfs, approxSolver, covered, highest_exswap_imprv, best_exswap_cluster,
						best_exswap_entry_idx, best_exswap_exit, new_normfs_4best_ass);

				clock_t end_imprv_altss = clock();
				time_imprv_altss = double(end_imprv_altss-start_imprv_altss);

				//did we find an improving exon skipping event?
				if(best_exskip != meta_trans.size() && highest_imprv > 0)
				{
					//did we also find an improving ass?
					if(best_exswap_cluster <= locid2exidx.at(*tes_it) && highest_exswap_imprv > 0)
					{
						//exon skipping bettern than ass
						if(highest_imprv > highest_exswap_imprv)
						{
//							cout << "implementing exon skipping: [" << locus[meta_trans[best_exskip].first] << "-" << meta_trans[best_exskip].second << "]" << endl;
							assert(!new_normfs_4best.empty());

							//update norm factors for new template solution
							for(std::map<UInt, double>::const_iterator normf_it = new_normfs_4best.begin(); normf_it != new_normfs_4best.end(); normf_it++)
								normfs[normf_it->first] = normf_it->second;
							ex_skipped[best_exskip] = true;

							reduced_cost += highest_imprv;
						} else //ass better than exon skipping
						{
							assert(!new_normfs_4best_ass.empty());

							//update norm factors for new template solution
							for(std::map<UInt, double>::const_iterator normf_it = new_normfs_4best_ass.begin(); normf_it != new_normfs_4best_ass.end(); normf_it++)
								normfs[normf_it->first] = normf_it->second;

//							cout << "replacing [";
//							cout << locus[meta_trans[best_exswap_cluster-locid2exidx.at(locus[*tss_it])].first] << "-";
//							cout <<  meta_trans[best_exswap_cluster-locid2exidx.at(locus[*tss_it])].second << "] by [";
//							cout << locus[best_exswap_entry_idx] << "-" << best_exswap_exit << "]" << endl;

							meta_trans[best_exswap_cluster-locid2exidx.at(locus[*tss_it])].first = best_exswap_entry_idx;
							meta_trans[best_exswap_cluster-locid2exidx.at(locus[*tss_it])].second = best_exswap_exit;

							reduced_cost += highest_exswap_imprv;
						}
					} else //only found improving exon skipping
					{
//						cout << "implementing exon skipping: [" << locus[meta_trans[best_exskip].first] << "-" << meta_trans[best_exskip].second << "]" << endl;
						assert(!new_normfs_4best.empty());

						//update norm factors for new template solution
						for(std::map<UInt, double>::const_iterator normf_it = new_normfs_4best.begin(); normf_it != new_normfs_4best.end(); normf_it++)
							normfs[normf_it->first] = normf_it->second;
						ex_skipped[best_exskip] = true;

						reduced_cost += highest_imprv;
					}
				} else if(best_exswap_cluster <= locid2exidx.at(*tes_it) && highest_exswap_imprv > 0)   //found only improving ass
				{
					assert(!new_normfs_4best_ass.empty());

					//update norm factors for new template solution
					for(std::map<UInt, double>::const_iterator normf_it = new_normfs_4best_ass.begin(); normf_it != new_normfs_4best_ass.end(); normf_it++)
						normfs[normf_it->first] = normf_it->second;

//					cout << "replacing [";
//					cout << locus[meta_trans[best_exswap_cluster-locid2exidx.at(locus[*tss_it])].first] << "-";
//					cout <<  meta_trans[best_exswap_cluster-locid2exidx.at(locus[*tss_it])].second << "] by [";
//					cout << locus[best_exswap_entry_idx] << "-" << best_exswap_exit << "]" << endl;

					meta_trans[best_exswap_cluster-locid2exidx.at(locus[*tss_it])].first = best_exswap_entry_idx;
					meta_trans[best_exswap_cluster-locid2exidx.at(locus[*tss_it])].second = best_exswap_exit;

					reduced_cost += highest_exswap_imprv;
				} else //neither improving exon skipping nor ass
					break;
			} //for(;;)

			clock_t end_for = clock();
			time_for = double(end_for-start_for);

			if(best_meta_trans.empty() || reduced_cost > best_reduced_cost)
			{
				best_reduced_cost = reduced_cost;

				best_meta_trans.clear();
				for(vector<pair<UInt, UInt> >::const_iterator metran_it = meta_trans.begin(); metran_it != meta_trans.end(); metran_it++)
					best_meta_trans.push_back(*metran_it);

				best_ex_skip.clear();
				for(vector<bool>::const_iterator exskip_it = ex_skipped.begin(); exskip_it != ex_skipped.end(); exskip_it++)
					best_ex_skip.push_back(*exskip_it);

				/*
				cout << "best meta trans so far:" << endl;
				for(UInt j=0; j<best_meta_trans.size(); j++)
				{
					cout << locus[best_meta_trans[j].first] << " " << best_meta_trans[j].second << endl;
				}
				*/
			}
			clock_t end_total = clock();
			time_total = double(end_total-start_total);

			/*
			cout << "time for some time stats: " << endl;
			cout << "total: " << time_total / CLOCKS_PER_SEC << endl;
			cout << "init: " << time_init / CLOCKS_PER_SEC << endl;
			cout << "for : " << time_for / CLOCKS_PER_SEC << endl;
			cout << "find improving exon skipping event: " << time_imprv_exskip / CLOCKS_PER_SEC << endl;
			cout << "find improving alternative splice site: " << time_imprv_altss / CLOCKS_PER_SEC << endl;
			cout << "for - template : " << time_for_template / CLOCKS_PER_SEC << endl;
			cout << "for - cover: " << time_for_cover / CLOCKS_PER_SEC << endl;
			cout << "for - reduced cost " << time_for_redcost / CLOCKS_PER_SEC << endl;
			*/
		}//forall tes
	}//forall tss

	//cout << endl << "building final transcript:" << endl;
	result_trans.nodes.clear();
	for(UInt j=0; j<best_meta_trans.size(); j++)
	{
		if(best_ex_skip[j])
			continue;

		for(UInt k=best_meta_trans[j].first; k<locus.size() && locus[k]<=best_meta_trans[j].second; k++)
			result_trans.nodes.push_back(locus[k]);
	}


	return best_reduced_cost;
}

void find_best_ass(const vector<UInt>& locus, const vector<SegmentCover>& selected_covers, const TAllSegmentsMap& segments,
				   const map<UInt, UInt>& locid2exidx, const vector<bool>& ex_skipped,
				   const vector<vector<UInt> >& exon_cluster, const vector<UInt>::const_iterator tss_it, const vector<UInt>::const_iterator tes_it,
				   const vector<vector<vector<pair<UInt,UInt> > > >& lmate, const vector<vector<vector<pair<UInt,UInt> > > >& rmate,
				   const std::map<UInt,std::set<UInt> > &legalBlockBounds, const vector<pair<UInt,UInt> >& meta_trans, const map<UInt, double>& normfs,
				   const IloCplex& approxSolver, IloRangeArray& covered,
				   double& highest_exswap_imprv, UInt& best_exswap_cluster, UInt& best_exswap_entry_idx,
				   UInt& best_exswap_exit, map<UInt, double>& new_normfs_4best)
{
	for(UInt cluster_idx = locid2exidx.at(locus[*tss_it]); cluster_idx <= locid2exidx.at(*tes_it); cluster_idx++)
	{
		int rel_cluster_idx = cluster_idx - locid2exidx.at(locus[*tss_it]);
		//cout << "cluster" << cluster_idx << endl;

		if(ex_skipped[rel_cluster_idx]) {
			//cout << "skipping" << endl;
			continue;
		}

		//nothing to do if single exon in cluster
		if(exon_cluster[cluster_idx].size()==1)
		{
			std::map<UInt, std::set<UInt> >::const_iterator entryIt = legalBlockBounds.find( locus[exon_cluster[cluster_idx][0]] );
			assert(entryIt != legalBlockBounds.end());
			if(entryIt->second.size()==1)
			{
				//cout << "nothing to do, only one exon in cluster." << endl;
				continue;
			}
		}

		//reached cluster that wasn't skipped and that has multiple candidates
		for(UInt j=0; j<exon_cluster[cluster_idx].size(); j++)
		{
			//in first cluster we have to be consistent with tss
			if(cluster_idx == locid2exidx.at(locus[*tss_it]) && locus[exon_cluster[cluster_idx][j]] != locus[*tss_it])
				continue;

			std::map<UInt, std::set<UInt> >::const_iterator entryIt = legalBlockBounds.find( locus[exon_cluster[cluster_idx][j]] );
			assert(entryIt != legalBlockBounds.end());
			for(std::set<UInt>::const_iterator exitIt = entryIt->second.begin(); exitIt != entryIt->second.end(); ++exitIt)
			{
				//in last cluster we have to be consistent with tes
				if(cluster_idx == locid2exidx.at(*tes_it) && *exitIt != *tes_it)
					continue;

				//is current candidate exon different from current exon choice?
				if(meta_trans[rel_cluster_idx].first == exon_cluster[cluster_idx][j] &&
						meta_trans[rel_cluster_idx].second == *exitIt )
				{
					continue;
				}

				//ok, let's try new candidate exon
				//cout << "ok, let's check candidate " << locus[exon_cluster[cluster_idx][j]] << " " << *exitIt << endl;

				//construct candidate template
				Transcript cand_exswap_trans;
				for(UInt l=0; l<meta_trans.size(); l++)
				{
					if(ex_skipped[l])
						continue;

					if(l != rel_cluster_idx)
						for(UInt k=meta_trans[l].first; k<locus.size() && locus[k]<=meta_trans[l].second; k++)
							cand_exswap_trans.nodes.push_back(locus[k]);
					else
					{
						for(UInt k=exon_cluster[cluster_idx][j]; k<locus.size() && locus[k]<=*exitIt; k++)
							cand_exswap_trans.nodes.push_back(locus[k]);
					}
				}
				//find relevant covers
				//--------------------
				/*									set<UInt> relevant_covers;

							//first for new exon candidate
							seqan::String<UInt> overlap_mates;
							UInt query_l = locus[exon_cluster[cluster_idx][j]];
							UInt query_r = *exitIt + 1;
							findIntervals(mate_tree, query_l, query_r, overlap_mates);

							seqan::String<UInt> spanning_mates;
							findIntervals(insert_tree, query_l, query_r, spanning_mates);

							for(UInt l = 0; l < length(overlap_mates); ++l)
								relevant_covers.insert(overlap_mates[l]);
							for(UInt l = 0; l < length(spanning_mates); ++l)
								relevant_covers.insert(spanning_mates[l]);

							//then for old exon choice
							clear(overlap_mates);
							query_l = locus[meta_trans[rel_cluster_idx].first];
							query_r = meta_trans[rel_cluster_idx].second + 1;
							findIntervals(mate_tree, query_l, query_r, overlap_mates);

							clear(spanning_mates);
							findIntervals(insert_tree, query_l, query_r, spanning_mates);

							for(UInt l = 0; l < length(overlap_mates); ++l)
								relevant_covers.insert(overlap_mates[l]);
							for(UInt l = 0; l < length(spanning_mates); ++l)
								relevant_covers.insert(spanning_mates[l]);
				 */
				set<UInt> relevant_covers;

				get_relevant_covers_ass(relevant_covers, locus, meta_trans, rel_cluster_idx, exon_cluster[cluster_idx][j], *exitIt, lmate, rmate, segments, ex_skipped);

				//cout << " relevant covers: " << relevant_covers.size() << " vs " << my_relevant_covers.size() << endl;

				//compute change in reduced cost
				//------------------------------
				set<UInt>::const_iterator relcov_it = relevant_covers.begin();
				double cost_diff = 0.;
				std::map<UInt, double> new_normfs;
				int hit = 0;
				for(; relcov_it != relevant_covers.end(); relcov_it++)
				{
					double new_normf = getNormFactor(selected_covers[*relcov_it], cand_exswap_trans, segments);
					double normf_diff = new_normf - normfs.at(*relcov_it);
					if(normf_diff != 0.) {
						new_normfs.insert(std::pair<UInt, double>(*relcov_it, new_normf));
						cost_diff += approxSolver.getDual(covered[*relcov_it]) * normf_diff;
						hit++;
						/*
									cout << "left mate:" << endl;
									for(int t=0; t<selected_covers[*relcov_it].exons_1.size(); ++t)
										cout << selected_covers[*relcov_it].exons_1[t] << " ";
									cout << endl;
									cout << "right mate:" << endl;
									for(int t=0; t<selected_covers[*relcov_it].exons_2.size(); ++t)
										cout << selected_covers[*relcov_it].exons_2[t] << " ";
									cout << endl;
						 */
					}
				}
				/*
							set<UInt>::const_iterator my_relcov_it = my_relevant_covers.begin();
							int myhit = 0;
							for(; my_relcov_it != my_relevant_covers.end(); my_relcov_it++)
							{
								double new_normf = getNormFactor(selected_covers[*my_relcov_it], cand_exswap_trans, segments);
								double normf_diff = new_normf - normfs.at(*my_relcov_it);
								if(normf_diff != 0.) {
									myhit++;

									cout << "left mate:" << endl;
									for(int t=0; t<selected_covers[*my_relcov_it].exons_1.size(); ++t)
										cout << selected_covers[*my_relcov_it].exons_1[t] << " ";
									cout << endl;
									cout << "right mate:" << endl;
									for(int t=0; t<selected_covers[*my_relcov_it].exons_2.size(); ++t)
										cout << selected_covers[*my_relcov_it].exons_2[t] << " ";
									cout << endl;
								}
							}

							cout << " effectiveness: " << hit << " vs " << myhit << endl;
							assert(hit==myhit);
				 */

				//found better exon swap?
				if( cost_diff > 0 && (best_exswap_cluster > locid2exidx.at(*tes_it) || cost_diff > highest_exswap_imprv) )
				{
					//cout << "found better exon swap: " << cost_diff << endl;
					highest_exswap_imprv = cost_diff;
					best_exswap_cluster = cluster_idx;
					best_exswap_entry_idx = exon_cluster[cluster_idx][j];
					best_exswap_exit = *exitIt;
					new_normfs_4best.clear();
					for(std::map<UInt, double>::const_iterator normf_it = new_normfs.begin(); normf_it != new_normfs.end(); normf_it++)
						new_normfs_4best.insert(*normf_it);
				}
			}
		}
	}
}


void find_best_exskip(const vector<UInt>& locus, const vector<SegmentCover>& selected_covers, const TAllSegmentsMap& segments,
					  const IloCplex& approxSolver, IloRangeArray& covered,
					  const vector<pair<UInt,UInt> >& meta_trans, const vector<bool>& ex_skipped, const map<UInt, double>& normfs,
					  const vector<vector<vector<pair<UInt,UInt> > > >& lmate, const vector<vector<vector<pair<UInt,UInt> > > >& rmate,
					  double& highest_imprv, UInt& best_exskip, map<UInt, double>& new_normfs_4best)
{
	for(UInt i=1; i<meta_trans.size()-1; i++)
	{
		if(ex_skipped[i])
			continue;

		clock_t start_template = clock();
		//construct candidate template
		Transcript cand_exskip_trans;
		//cout << "cand_exskip_trans:" << endl;
		for(UInt j=0; j<meta_trans.size(); j++)
		{
			if(j==i || ex_skipped[j])
				continue;
			for(UInt k=meta_trans[j].first; k<locus.size() && locus[k]<=meta_trans[j].second; k++) {
				cand_exskip_trans.nodes.push_back(locus[k]);
				//cout << locus[k] << " ";
			}
			//cout << endl;
		}
		//cout << "cut from " << locus[meta_trans[i].first] << " to " << meta_trans[i].second << endl;
		clock_t end_template = clock();

		clock_t start_cover = clock();

		//find relevant covers
		//--------------------
		/*
	set<UInt> relevant_covers;

	seqan::String<UInt> overlap_mates;
	UInt query_l = locus[meta_trans[i].first];
	UInt query_r = meta_trans[i].second + 1;
	findIntervals(mate_tree, query_l, query_r, overlap_mates);

	seqan::String<UInt> spanning_mates;
	findIntervals(insert_tree, query_l, query_r, spanning_mates);

	for(UInt j = 0; j < length(overlap_mates); ++j)
		relevant_covers.insert(overlap_mates[j]);
	cout << "number of overlap mates: " << relevant_covers.size() << endl;
	for(UInt j = 0; j < length(spanning_mates); ++j)
		relevant_covers.insert(spanning_mates[j]);
		 */

		//...using new data structure
		set<UInt> relevant_covers;

		get_relevant_covers_exskip(relevant_covers, locus, meta_trans, i, lmate, rmate, segments, ex_skipped);

		clock_t end_cover = clock();


		clock_t start_redcost = clock();

		//compute change in reduced cost
		//------------------------------
		set<UInt>::const_iterator relcov_it = relevant_covers.begin();
		double cost_diff = 0.;
		std::map<UInt, double> new_normfs;
		//cout << "number of relevant covers: " << relevant_covers.size() << endl;
		int hit = 0;
		int nohit = 0;
		//cout << "query range " << query_l << " " << query_r << endl;
		for(; relcov_it != relevant_covers.end(); relcov_it++)
		{
			double new_normf = getNormFactor(selected_covers[*relcov_it], cand_exskip_trans, segments);
			double normf_diff = new_normf - normfs.at(*relcov_it);
			if(normf_diff != 0.) {
				hit++;
				//cout << normf_diff << endl;
				new_normfs.insert(std::pair<UInt, double>(*relcov_it, new_normf));
				cost_diff += approxSolver.getDual(covered[*relcov_it]) * normf_diff;
				/*
			cout << "left mate:" << endl;
			for(int t=0; t<selected_covers[*relcov_it].exons_1.size(); ++t)
				cout << selected_covers[*relcov_it].exons_1[t] << " ";
			cout << endl;
			cout << "right mate:" << endl;
			for(int t=0; t<selected_covers[*relcov_it].exons_2.size(); ++t)
				cout << selected_covers[*relcov_it].exons_2[t] << " ";
			cout << endl;
				 */
			} else
			{
				//							cout << "left mate:" << endl;
				//							for(int t=0; t<selected_covers[*relcov_it].exons_1.size(); ++t)
				//								cout << selected_covers[*relcov_it].exons_1[t] << " ";
				//							cout << endl;
				//							cout << "right mate:" << endl;
				//							for(int t=0; t<selected_covers[*relcov_it].exons_2.size(); ++t)
				//								cout << selected_covers[*relcov_it].exons_2[t] << " ";
				//							cout << endl;
				//							cout << "intensity: " << selected_covers[*relcov_it].intensity << endl;

				nohit++;

				//							if(!isCoverSupported(selected_covers[*relcov_it], vector<Transcript>(1,cand_exskip_trans)))
				//							{
				//								cout << "cover not supported" << endl;
				//							} else
				//								cout << "I knew it!" << endl;
			}
		}
		//cout << "hits: " << hit << endl;
		//cout << "no hits: " << nohit << endl;
		clock_t end_redcost = clock();

		/*
	set<UInt>::const_iterator my_relcov_it = my_relevant_covers.begin();
	int myhit = 0;
	int mynohit = 0;
	for(; my_relcov_it != my_relevant_covers.end(); my_relcov_it++)
	{
		double new_normf = getNormFactor(selected_covers[*my_relcov_it], cand_exskip_trans, segments);
		double normf_diff = new_normf - normfs.at(*my_relcov_it);
		if(normf_diff != 0.) {
			myhit++;

			cout << "left mate:" << endl;
			for(int t=0; t<selected_covers[*my_relcov_it].exons_1.size(); ++t)
				cout << selected_covers[*my_relcov_it].exons_1[t] << " ";
			cout << endl;
			cout << "right mate:" << endl;
			for(int t=0; t<selected_covers[*my_relcov_it].exons_2.size(); ++t)
				cout << selected_covers[*my_relcov_it].exons_2[t] << " ";
			cout << endl;

		}
		else
			mynohit++;
	}
	//cout << "my hits: " << myhit << endl;
	//cout << "my no hits: " << mynohit << endl;
		 */
		//assert(myhit == hit);

		if( cost_diff > 0 && (best_exskip == meta_trans.size() || cost_diff > highest_imprv) )
		{
			highest_imprv = cost_diff;
			best_exskip = i;
			new_normfs_4best.clear();
			for(std::map<UInt, double>::const_iterator normf_it = new_normfs.begin(); normf_it != new_normfs.end(); normf_it++)
				new_normfs_4best.insert(*normf_it);
		}
	}
}


void get_relevant_covers_ass(set<UInt>& relevant_covers, const vector<UInt>& locus, const vector<pair<UInt, UInt> >& meta_trans, int i,
							 UInt new_left_boundary_idx, UInt new_right_boundary,
		                     const vector<vector<vector<pair<UInt,UInt> > > >& lmate, const vector<vector<vector<pair<UInt,UInt> > > >& rmate,
                         const TAllSegmentsMap& segments, const vector<bool>& ex_skipped)
{
	map<int, int> exon_order;
	for(size_t j = 0; j < locus.size(); j++) {
		exon_order[locus[j]] = j;
	}

	//a) not necessarily supported anymore after replacing exon
	//mate within exon
	for(UInt k=meta_trans[i].first; k<locus.size() && locus[k]<=meta_trans[i].second; k++)
	{
		vector< pair<UInt,UInt> >::const_iterator lmate_it = lmate[k][0].begin();
		for(; lmate_it != lmate[k][0].end(); lmate_it++)
			relevant_covers.insert(lmate_it->second);
		if( locus[k]<meta_trans[i].second && k<locus.size()-1 )
		{
			lmate_it = lmate[k][1].begin();
			for(; lmate_it != lmate[k][1].end(); lmate_it++)
				relevant_covers.insert(lmate_it->second);
		}

		vector< pair<UInt,UInt> >::const_iterator rmate_it = rmate[k][0].begin();
		for(; rmate_it != rmate[k][0].end(); rmate_it++)
			relevant_covers.insert(rmate_it->second);
		if( locus[k]<meta_trans[i].second && k<locus.size()-1 )
		{
			rmate_it = rmate[k][1].begin();
			for(; rmate_it != rmate[k][1].end(); rmate_it++) {
				relevant_covers.insert(rmate_it->second);
			}

		}
	}

	//mate on left exon junction
	UInt left_neighbor;
	if(i>0) {
		left_neighbor = i-1;
		while(ex_skipped[left_neighbor])
			left_neighbor--;
		UInt idx_x = exon_order[ meta_trans[left_neighbor].second ];
		UInt idx_y = meta_trans[i].first - idx_x;
		vector< pair<UInt,UInt> >::const_iterator lmate_it = lmate[idx_x][idx_y].begin();
		for(; lmate_it != lmate[idx_x][idx_y].end(); lmate_it++)
			relevant_covers.insert(lmate_it->second);
		vector< pair<UInt,UInt> >::const_iterator rmate_it = rmate[idx_x][idx_y].begin();
		for(; rmate_it != rmate[idx_x][idx_y].end(); rmate_it++)
			relevant_covers.insert(rmate_it->second);
	}

	//mate on right exon junction
	UInt right_neighbor;
	if(i<meta_trans.size()-1) {
		right_neighbor = i+1;
		while(ex_skipped[right_neighbor])
			right_neighbor++;
		UInt idx_x = exon_order[ meta_trans[i].second ];
		UInt idx_y = meta_trans[right_neighbor].first - idx_x;
		vector< pair<UInt,UInt> >::const_iterator lmate_it = lmate[idx_x][idx_y].begin();
		for(; lmate_it != lmate[idx_x][idx_y].end(); lmate_it++) {
			relevant_covers.insert(lmate_it->second);
		}
		vector< pair<UInt,UInt> >::const_iterator rmate_it = rmate[idx_x][idx_y].begin();
		for(; rmate_it != rmate[idx_x][idx_y].end(); rmate_it++)
			relevant_covers.insert(rmate_it->second);
	}


	//b) (newly) supported after replacing exon
	//mate within exon
	for(UInt k=new_left_boundary_idx; k<locus.size() && locus[k]<=new_right_boundary; k++)
	{
		vector< pair<UInt,UInt> >::const_iterator lmate_it = lmate[k][0].begin();
		for(; lmate_it != lmate[k][0].end(); lmate_it++)
			relevant_covers.insert(lmate_it->second);
		if( locus[k]<new_right_boundary && k<locus.size()-1 )
		{
			lmate_it = lmate[k][1].begin();
			for(; lmate_it != lmate[k][1].end(); lmate_it++)
				relevant_covers.insert(lmate_it->second);
		}

		vector< pair<UInt,UInt> >::const_iterator rmate_it = rmate[k][0].begin();
		for(; rmate_it != rmate[k][0].end(); rmate_it++)
			relevant_covers.insert(rmate_it->second);
		if( locus[k]<new_right_boundary && k<locus.size()-1 )
		{
			rmate_it = rmate[k][1].begin();
			for(; rmate_it != rmate[k][1].end(); rmate_it++) {
				relevant_covers.insert(rmate_it->second);
			}

		}
	}

	//mate on left exon junction
	if(i>0) {
		UInt idx_x = exon_order[ meta_trans[left_neighbor].second ];
		UInt idx_y = new_left_boundary_idx - idx_x;
		vector< pair<UInt,UInt> >::const_iterator lmate_it = lmate[idx_x][idx_y].begin();
		for(; lmate_it != lmate[idx_x][idx_y].end(); lmate_it++)
			relevant_covers.insert(lmate_it->second);
		vector< pair<UInt,UInt> >::const_iterator rmate_it = rmate[idx_x][idx_y].begin();
		for(; rmate_it != rmate[idx_x][idx_y].end(); rmate_it++)
			relevant_covers.insert(rmate_it->second);
	}

	//mate on right exon junction
	if(i<meta_trans.size()-1) {
		UInt idx_x = exon_order[new_right_boundary];
		UInt idx_y = meta_trans[right_neighbor].first - idx_x;
		vector< pair<UInt,UInt> >::const_iterator lmate_it = lmate[idx_x][idx_y].begin();
		for(; lmate_it != lmate[idx_x][idx_y].end(); lmate_it++) {
			relevant_covers.insert(lmate_it->second);
		}
		vector< pair<UInt,UInt> >::const_iterator rmate_it = rmate[idx_x][idx_y].begin();
		for(; rmate_it != rmate[idx_x][idx_y].end(); rmate_it++)
			relevant_covers.insert(rmate_it->second);
	}

	//c) relevant spanning mates
	if(i>0 && i<meta_trans.size()-1)
	{
		int read_length = Parameters::read_length_global;
		int fragment_length = Parameters::insert_size_global;
		double s_dev = Parameters::s_dev;
		int lower = max((2 * read_length), (int)floor(gsl_cdf_gaussian_Pinv(Parameters::lower_percentile, Parameters::s_dev)) + fragment_length);
		int upper = ceil(gsl_cdf_gaussian_Pinv(Parameters::upper_percentile, s_dev)) + fragment_length;

		int old_exon_length = 0;
		for(UInt k=meta_trans[i].first; k<locus.size() && locus[k]<=meta_trans[i].second; k++)
      old_exon_length += segments[locus[k]].length;

		int new_exon_length = 0;
		for(UInt k=new_left_boundary_idx; k<locus.size() && locus[k]<=new_right_boundary; k++)
      new_exon_length += segments[locus[k]].length;

		int min_exon_length = (old_exon_length<new_exon_length) ? old_exon_length : new_exon_length;
		int max_exon_length = (old_exon_length<new_exon_length) ? new_exon_length : old_exon_length;

		//first find range of right mates if left mate ends at left neighbor of skipped exon
		int rmate_leftmost = -1;
		int rmate_rightmost = -1;
		int acc_length_right = 0;
		int acc_length_right_leftmost;
		int prev_k = -2;
		int prev_k_exon = -2;
    int min_length_approx = lower - 1 - segments[meta_trans[left_neighbor].second].length + 1 - (2*read_length) - 1;
		int max_length_approx = upper - (2*read_length);
		//cout << min_exon_length << " min max " << max_exon_length << endl;
		for(UInt j = right_neighbor; j < meta_trans.size(); j++)
		{
			if(ex_skipped[j])
				continue;

			for(UInt k=meta_trans[j].first; k<locus.size() && locus[k]<=meta_trans[j].second; k++)
			{
				if(rmate_leftmost == -1) {
          int min_length_approx2 =  min_length_approx - segments[locus[k]].length + 1;
					if(max_exon_length + acc_length_right >= max(0,min_length_approx2)) { //exceeds lower limit first time
						//cout << "left most found" << endl;
						//cout << acc_length_right << " " << max_exon_length << " " << max(0,min_length_approx2) << endl;
						rmate_leftmost = k;
						acc_length_right_leftmost = acc_length_right;
					}
				}
				if(acc_length_right + min_exon_length > max_length_approx) {
					//cout << "right most found " << endl;
					//cout << acc_length_right << " " << min_exon_length << " " << max_length_approx << endl;
					rmate_rightmost = prev_k;
					if(prev_k != -2)
            acc_length_right -= segments[locus[prev_k]].length;
					break;
				}
				prev_k = k;
				prev_k_exon = j;
        acc_length_right += segments[locus[k]].length;
			}
			if(rmate_rightmost != -1)
				break;
		}
		assert(!(rmate_rightmost != -1 && rmate_leftmost == -1));
		assert(rmate_rightmost == -1 || rmate_rightmost == -2 || rmate_rightmost >= rmate_leftmost);
		//cout << "rmate results: " << meta_trans[i].second << " " << locus[rmate_leftmost] << " " << locus[rmate_rightmost] << endl;

		if(rmate_rightmost != -2) //otherwise min exon length too large for spanning covers
		{
			//simplified variant that does not adapt range when moving to the left
			int acc_length_left = 0;
			bool done = false;
			int prev_exon;
			for(int j = left_neighbor; j >= 0; j--)
			{
				if(ex_skipped[j])
					continue;

				if(j < left_neighbor)
				{
					int idx_x = exon_order[meta_trans[j].second];
					int idx_y = meta_trans[prev_exon].first - idx_x;
					vector<pair<UInt,UInt> >::const_iterator low = std::lower_bound(lmate[idx_x][idx_y].begin(), lmate[idx_x][idx_y].end(),
							pair<UInt,UInt>(locus[meta_trans[right_neighbor].first], 0));
					while(low != lmate[idx_x][idx_y].end() && (rmate_rightmost == -1 || low->first <= locus[rmate_rightmost])) {
						relevant_covers.insert(low->second);
						low++;
					}
				}

				if(acc_length_left + min_exon_length > max_length_approx) {
					break;
				}

				for(int k=exon_order[meta_trans[j].second]; k>=0 && k>=meta_trans[j].first; k--)
				{
					if(acc_length_left + min_exon_length > max_length_approx) {
						done = true;
						break;
					}
					//left mate is single exon
					vector<pair<UInt,UInt> >::const_iterator low = std::lower_bound(lmate[k][0].begin(), lmate[k][0].end(),
							pair<UInt,UInt>(locus[meta_trans[right_neighbor].first], 0));
					while(low != lmate[k][0].end() && (rmate_rightmost == -1 || low->first <= locus[rmate_rightmost])) {
						relevant_covers.insert(low->second);
						low++;
					}
					//left mate is exon juction
					if(k>meta_trans[j].first) {
						low = std::lower_bound(lmate[k-1][1].begin(), lmate[k-1][1].end(),
								pair<UInt,UInt>(locus[meta_trans[right_neighbor].first], 0));
						while(low != lmate[k-1][1].end() && (rmate_rightmost == -1 || low->first <= locus[rmate_rightmost])) {
							relevant_covers.insert(low->second);
							low++;
						}
					}
          acc_length_left += segments[locus[k]].length;
				}
				if(done)
					break;
				prev_exon = j;
			}
		}
	}
}



void get_relevant_covers_exskip(set<UInt>& relevant_covers, const vector<UInt>& locus, const vector<pair<UInt, UInt> >& meta_trans, UInt i,
		                        const vector<vector<vector<pair<UInt,UInt> > > >& lmate, const vector<vector<vector<pair<UInt,UInt> > > >& rmate,
                            const TAllSegmentsMap& segments, const vector<bool>& ex_skipped)
{
	map<int, int> exon_order;
	for(size_t j = 0; j < locus.size(); j++) {
		exon_order[locus[j]] = j;
	}

	//a) not supported (anymore) after splicing out exon
	//mate within exon
	for(UInt k=meta_trans[i].first; k<locus.size() && locus[k]<=meta_trans[i].second; k++)
	{
		vector< pair<UInt,UInt> >::const_iterator lmate_it = lmate[k][0].begin();
		for(; lmate_it != lmate[k][0].end(); lmate_it++)
			relevant_covers.insert(lmate_it->second);
		if( locus[k]<meta_trans[i].second && k<locus.size()-1 )
		{
			lmate_it = lmate[k][1].begin();
			for(; lmate_it != lmate[k][1].end(); lmate_it++)
				relevant_covers.insert(lmate_it->second);
		}

		vector< pair<UInt,UInt> >::const_iterator rmate_it = rmate[k][0].begin();
		for(; rmate_it != rmate[k][0].end(); rmate_it++)
			relevant_covers.insert(rmate_it->second);
		if( locus[k]<meta_trans[i].second && k<locus.size()-1 )
		{
			rmate_it = rmate[k][1].begin();
			for(; rmate_it != rmate[k][1].end(); rmate_it++) {
				relevant_covers.insert(rmate_it->second);
			}

		}
	}

	//mate on left exon junction
	UInt left_neighbor = i-1;
	while(ex_skipped[left_neighbor])
		left_neighbor--;
	UInt idx_x = exon_order[ meta_trans[left_neighbor].second ];
	UInt idx_y = meta_trans[i].first - idx_x;
	vector< pair<UInt,UInt> >::const_iterator lmate_it = lmate[idx_x][idx_y].begin();
	for(; lmate_it != lmate[idx_x][idx_y].end(); lmate_it++)
		relevant_covers.insert(lmate_it->second);
	vector< pair<UInt,UInt> >::const_iterator rmate_it = rmate[idx_x][idx_y].begin();
	for(; rmate_it != rmate[idx_x][idx_y].end(); rmate_it++)
		relevant_covers.insert(rmate_it->second);

	//mate on right exon junction
	UInt right_neighbor = i+1;
	while(ex_skipped[right_neighbor])
		right_neighbor++;
	idx_x = exon_order[ meta_trans[i].second ];
	idx_y = meta_trans[right_neighbor].first - idx_x;
	lmate_it = lmate[idx_x][idx_y].begin();
	for(; lmate_it != lmate[idx_x][idx_y].end(); lmate_it++) {
		relevant_covers.insert(lmate_it->second);
	}
	rmate_it = rmate[idx_x][idx_y].begin();
	for(; rmate_it != rmate[idx_x][idx_y].end(); rmate_it++)
		relevant_covers.insert(rmate_it->second);

	//b) newly supported after splicing out exon
	idx_x = exon_order[ meta_trans[left_neighbor].second ];
	idx_y = meta_trans[right_neighbor].first - idx_x;
	lmate_it = lmate[idx_x][idx_y].begin();
	for(; lmate_it != lmate[idx_x][idx_y].end(); lmate_it++)
		relevant_covers.insert(lmate_it->second);
	rmate_it = rmate[idx_x][idx_y].begin();
	for(; rmate_it != rmate[idx_x][idx_y].end(); rmate_it++)
		relevant_covers.insert(rmate_it->second);

	//cout << "number of my relevant covers without spanning: " <<  relevant_covers.size() << endl;

	//c) relevant spanning mates
	int read_length = Parameters::read_length_global;
	int fragment_length = Parameters::insert_size_global;
	double s_dev = Parameters::s_dev;
	int lower = max((2 * read_length), (int)floor(gsl_cdf_gaussian_Pinv(Parameters::lower_percentile, Parameters::s_dev)) + fragment_length);
	int upper = ceil(gsl_cdf_gaussian_Pinv(Parameters::upper_percentile, s_dev)) + fragment_length;

	int skipped_exon_length = 0;
	for(UInt k=meta_trans[i].first; k<locus.size() && locus[k]<=meta_trans[i].second; k++)
    skipped_exon_length += segments[locus[k]].length;

	//first find range of right mates if left mate ends at left neighbor of skipped exon
	int rmate_leftmost = -1;
	int rmate_rightmost = -1;
	int acc_length_right = 0;
	int acc_length_right_leftmost;
	int prev_k = -2;
	int prev_k_exon = -2;
  int min_length_approx = lower - 1 - segments[meta_trans[left_neighbor].second].length + 1 - (2*read_length) - 1;
	int max_length_approx = upper - (2*read_length);
	for(UInt j = right_neighbor; j < meta_trans.size(); j++)
	{
		if(ex_skipped[j])
			continue;

		for(UInt k=meta_trans[j].first; k<locus.size() && locus[k]<=meta_trans[j].second; k++)
		{
			if(rmate_leftmost == -1) {
        int min_length_approx2 =  min_length_approx - segments[locus[k]].length + 1;
				if(skipped_exon_length + acc_length_right >= max(0,min_length_approx2)) { //exceeds lower limit first time
					rmate_leftmost = k;
					acc_length_right_leftmost = acc_length_right;
				}
			}
			if(acc_length_right > max_length_approx) {
				rmate_rightmost = prev_k;
				if(prev_k != -2)
          acc_length_right -= segments[locus[prev_k]].length;
				break;
			}
			prev_k = k;
			prev_k_exon = j;
      acc_length_right += segments[locus[k]].length;
		}
		if(rmate_rightmost != -1)
			break;
	}
	assert(!(rmate_rightmost != -1 && rmate_leftmost == -1));
	assert(rmate_rightmost == -1 || rmate_rightmost >= rmate_leftmost);
	//cout << "rmate results: " << meta_trans[i].second << " " << locus[rmate_leftmost] << " " << locus[rmate_rightmost] << endl;


	//simplified variant that does not adapt range when moving to the left
	int acc_length_left = 0;
	bool done = false;
	int prev_exon;
	for(int j = left_neighbor; j >= 0; j--)
	{
		if(ex_skipped[j])
			continue;

		if(j < left_neighbor)
		{
			int idx_x = exon_order[meta_trans[j].second];
			int idx_y = meta_trans[prev_exon].first - idx_x;
			//cout << meta_trans[j].second << " " << locus[meta_trans[prev_exon].first] << endl;
			vector<pair<UInt,UInt> >::const_iterator low = std::lower_bound(lmate[idx_x][idx_y].begin(), lmate[idx_x][idx_y].end(),
					pair<UInt,UInt>(locus[meta_trans[right_neighbor].first], 0));
			while(low != lmate[idx_x][idx_y].end() && (rmate_rightmost == -1 || low->first <= locus[rmate_rightmost])) {
				relevant_covers.insert(low->second);
				low++;
			}
		}

		if(acc_length_left > max_length_approx) {
			break;
		}

		for(int k=exon_order[meta_trans[j].second]; k>=0 && k>=meta_trans[j].first; k--)
		{
			if(acc_length_left > max_length_approx) {
				done = true;
				break;
			}
			//left mate is single exon
			vector<pair<UInt,UInt> >::const_iterator low = std::lower_bound(lmate[k][0].begin(), lmate[k][0].end(),
					pair<UInt,UInt>(locus[meta_trans[right_neighbor].first], 0));
			while(low != lmate[k][0].end() && (rmate_rightmost == -1 || low->first <= locus[rmate_rightmost])) {
				relevant_covers.insert(low->second);
				low++;
			}
			//left mate is exon juction
			if(k>meta_trans[j].first) {
				low = std::lower_bound(lmate[k-1][1].begin(), lmate[k-1][1].end(),
						pair<UInt,UInt>(locus[meta_trans[right_neighbor].first], 0));
				while(low != lmate[k-1][1].end() && (rmate_rightmost == -1 || low->first <= locus[rmate_rightmost])) {
					relevant_covers.insert(low->second);
					low++;
				}
			}
      acc_length_left += segments[locus[k]].length;
		}
		if(done)
			break;
		prev_exon = j;
	}
}

bool is_mate_compatible(const vector<UInt>& mate, UInt left_boundary, UInt right_boundary, UInt current_cluster, const map<UInt, UInt>& locid2exidx, const vector<UInt>& locus)
{
	//check whether overlapping mate is consistent with current exon
	bool mate_compatible = true;
	vector<UInt>::const_iterator mate_begin = mate.begin();
	vector<UInt>::const_iterator mate_end = mate.end();
	vector<UInt>::const_iterator exon_lend_in_mate = lower_bound(mate_begin, mate_end, left_boundary);
	if(exon_lend_in_mate == mate_end) {//mate completely left of exon
		mate_compatible = false;
	}
	else if(*exon_lend_in_mate == left_boundary)
	{
		if(exon_lend_in_mate != mate_begin && locid2exidx.at(*(exon_lend_in_mate-1)) == current_cluster)
			mate_compatible = false; //should have been spliced to the left
	} else if(*mate_begin < left_boundary) //mate skipped left boundary of exon
		mate_compatible = false;

	//if lmate_compatible = true here then no alternative splice site on the left exon boundary
	if(mate_compatible == true) //check right boundary only if necessary
	{
		vector<UInt>::const_iterator exon_rend_in_mate = lower_bound(mate_begin, mate_end, right_boundary);
		if(exon_rend_in_mate != mate_end) //otherwise right splice site not affected
		{
			if(*mate_begin > right_boundary)
				mate_compatible = false;
			else if(*exon_rend_in_mate == right_boundary)
			{
				if(exon_rend_in_mate != mate_end-1 && locid2exidx.at(*(exon_rend_in_mate+1)) == current_cluster)
					mate_compatible = false;
			} else if(*(mate_end-1) > right_boundary) //skipped right exon junction
				mate_compatible = false;
		}
	}

	//finally, in case of e.g. intron retention internal segments might have been skipped
	if(mate_compatible == true) //check right boundary only if necessary
	{
		vector<UInt>::const_iterator internal_mate_it = exon_lend_in_mate;
		vector<UInt>::const_iterator internal_exon_it = lower_bound(locus.begin(), locus.end(), *exon_lend_in_mate);
		for(; internal_mate_it != mate_end && *internal_exon_it <= right_boundary; internal_mate_it++, internal_exon_it++)
		{
			if(*internal_mate_it != *internal_exon_it)
			{
				mate_compatible = false;
				break;
			}
		}
	}

	return mate_compatible;
}

void /*PricingGraph::*/ createGraph(SpliceGraph &sg,
                              const vector<SegmentCover>& selectedCovers,
                              const TAllSegmentsMap &allSegments,
                              const std::pair<unsigned, unsigned> &fragLenBounds,
                              UInt maxUncovered,
                              UInt maxSkip,
                              bool exonAware
                              )
{
  typedef std::vector<UInt> TNode;
  typedef std::set<TNode> TNodeList;
  TNodeList nodes;
  std::map<UInt, UInt> forbiddenEdges;

  //create all nodes of the pricing graph. For every paired end cover and every combination of subexons between the endpoints of
  //this cover with getNormFactor != 0 there must be some node

  std::vector<std::vector<UInt> >paths;
  std::vector<SegmentCover>::const_iterator covIt;
  for (covIt = selectedCovers.begin(); covIt != selectedCovers.end(); ++covIt)
  {
    UInt uncovered = 0;
    if (maxUncovered != -1u)
    {
      for (size_t i = 0; i+1 < covIt->exons_1.size(); ++i)
      {
        if (!sg.findEdge(covIt->exons_1[i], covIt->exons_1[i+1]))
          ++uncovered;
      }
      for (size_t i = 0; i+1 < covIt->exons_2.size(); ++i)
      {
        if (!sg.findEdge(covIt->exons_2[i], covIt->exons_2[i+1]))
          ++uncovered;
      }
    }

    if (uncovered > maxUncovered)
      continue;

    //get all possible paths between the endpoints of this cover
    paths.clear();
    sg.getExonPaths(allSegments, *covIt, fragLenBounds, maxUncovered, maxSkip, exonAware, paths);    

    if (paths.empty() && covIt->exons_1.back() != covIt->exons_2.front() && !sg.findEdge(covIt->exons_1.back(), covIt->exons_2.front(), true) && covIt->intensity < 0.001)
      std::cerr << "WARNING EMPTY PATH! " << *covIt << std::endl;

    const UInt offset = covIt->exons_1.size();
    const UInt endSpace = covIt->exons_2.size();

    std::vector<UInt> tmpNode(covIt->exons_1.begin(), covIt->exons_1.end());
    tmpNode.reserve(32);
    if (covIt->exons_1.back() == covIt->exons_2.front()) // x-i^i-y
    {
      tmpNode.insert(tmpNode.end(), covIt->exons_2.begin()+1, covIt->exons_2.end());
      nodes.insert(tmpNode);
    }
    else if (sg.findEdge(covIt->exons_1.back(), covIt->exons_2.front(), maxUncovered - uncovered))
    {
      //if direct connection between endpoints
      paths.push_back(std::vector<UInt>()); //empty path
    }
    //TODO modify getExonPaths to also include the boundaries to get rid of that loop
    std::cerr << *covIt << std::endl;
    for (size_t i = 0; i < paths.size(); ++i)
    {
//      for (size_t k = 0; k < paths[i].size(); ++k)
//        std::cerr << paths[i][k] << " P ";
//      std::cerr << std::endl;

      tmpNode.resize(offset);
      tmpNode.insert(tmpNode.end(), paths[i].begin(), paths[i].end());
      tmpNode.insert(tmpNode.end(), covIt->exons_2.begin(), covIt->exons_2.end());
//      for (size_t k = 0; k < tmpNode.size(); ++k)
//        std::cerr << tmpNode[k] << " ";
//      std::cerr << std::endl;
      nodes.insert(tmpNode);
    }
  }

  //create the subnodes such that every factor of all nodes is contained.
  TNodeList nodesPref;
  for (TNodeList::const_iterator nIt = nodes.begin(); nIt != nodes.end(); ++nIt)
  {
    for (size_t l = 0; l + 1 < nIt->size(); ++l)
    {
      nodesPref.insert(TNode(nIt->begin(), nIt->begin()+l));

//      for (size_t r = l; r < nIt->size(); ++r)
//      {
//        nodes.insert(TNode(nIt->begin()+l, nIt->begin()+r));
//      }
    }
  }
  nodes.insert(nodesPref.begin(), nodesPref.end());
  std::cerr << "Size of PricingGraph: " << nodes.size() << std::endl;

  if (nodes.size() < 100)
  {
    for (covIt = selectedCovers.begin(); covIt != selectedCovers.end(); ++covIt)
      std::cerr << *covIt << std::endl;
    std::cerr << " ---- " << std::endl;

    for (TNodeList::const_iterator nIt = nodes.begin(); nIt != nodes.end(); ++nIt)
    {
      for (size_t j = 0; j < nIt->size(); ++j)
        std::cerr << (*nIt)[j] << " ";
      std::cerr << std::endl;
    }
  }

}

